"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "version_module": true, "schemas": { "AccessApprovalSettings": { "type": "object", "properties": { "notificationEmails": { "description": "A list of email addresses to which notifications relating to approval\nrequests should be sent. Notifications relating to a resource will be sent\nto all emails in the settings of ancestor resources of that resource.", "type": "array", "items": { "type": "string" } }, "name": { "description": "The resource name of the settings. Format is one of:\n<ol>\n  <li>\"projects/{project_id}/accessApprovalSettings\"</li>\n  <li>\"folders/{folder_id}/accessApprovalSettings\"</li>\n  <li>\"organizations/{organization_id}/accessApprovalSettings\"</li>\n<ol>", "type": "string" } }, "id": "AccessApprovalSettings", "description": "Settings on a Project/Folder/Organization related to Access Approval." }, "AccessReason": { "type": "object", "properties": { "type": { "enumDescriptions": ["Default value for proto, shouldn't be used.", "Customer made a request or raised an issue that required the principal to\naccess customer data. `detail` is of the form (\"#####\" is the issue ID):\n<ol>\n  <li>\"Feedback Report: #####\"</li>\n  <li>\"Case Number: #####\"</li>\n  <li>\"Case ID: #####\"</li>\n  <li>\"E-PIN Reference: #####\"</li>\n  <li>\"Google-#####\"</li>\n  <li>\"T-#####\"</li>\n</ol>", "The principal accessed customer data in order to diagnose or resolve a\nsuspected issue in services or a known outage. Often this access is used\nto confirm that customers are not affected by a suspected service issue\nor to remediate a reversible system issue.", "Google initiated service for security, fraud, abuse, or compliance\npurposes."], "enum": ["TYPE_UNSPECIFIED", "CUSTOMER_INITIATED_SUPPORT", "GOOGLE_INITIATED_SERVICE", "GOOGLE_INITIATED_REVIEW"], "description": "Type of access justification.", "type": "string" }, "detail": { "description": "More detail about certain reason types. See comments for each type above.", "type": "string" } }, "id": "AccessReason" }, "ApproveDecision": { "description": "A decision that has been made to approve access to a resource.", "type": "object", "properties": { "approveTime": { "type": "string", "description": "The time at which approval was granted.", "format": "google-datetime" }, "expireTime": { "description": "The time at which the approval expires.", "format": "google-datetime", "type": "string" } }, "id": "ApproveDecision" }, "ApprovalRequest": { "id": "ApprovalRequest", "description": "A request for the customer to approve access to a resource.", "type": "object", "properties": { "dismiss": { "$ref": "DismissDecision", "description": "The request was dismissed." }, "requestedResourceName": { "description": "The resource for which approval is being requested. The format of the\nresource name is defined at\nhttps://cloud.google.com/apis/design/resource_names. The resource name here\nmay either be a \"full\" resource name (e.g.\n\"//library.googleapis.com/shelves/shelf1/books/book2\") or a \"relative\"\nresource name (e.g. \"shelves/shelf1/books/book2\") as described in the\nresource name specification.", "type": "string" }, "name": { "description": "The resource name of the request. Format is\n\"{projects|folders|organizations}/{id}/approvalRequests/{approval_request_id}\".", "type": "string" }, "requestedExpiration": { "description": "The requested expiration for the approval. If the request is approved,\naccess will be granted from the time of approval until the expiration time.", "format": "google-datetime", "type": "string" }, "approve": { "description": "Access was approved.", "$ref": "ApproveDecision" }, "requestedResourceProperties": { "description": "Properties related to the resource represented by requested_resource_name.", "$ref": "ResourceProperties" }, "requestedReason": { "description": "The justification for which approval is being requested.", "$ref": "AccessReason" }, "requestTime": { "description": "The time at which approval was requested.", "format": "google-datetime", "type": "string" }, "requestedLocations": { "$ref": "AccessLocations", "description": "The locations for which approval is being requested." } } }, "ListApprovalRequestsResponse": { "description": "Response to listing of ApprovalRequest objects.", "type": "object", "properties": { "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no more." }, "approvalRequests": { "description": "Approval request details.", "type": "array", "items": { "$ref": "ApprovalRequest" } } }, "id": "ListApprovalRequestsResponse" }, "ApproveApprovalRequestMessage": { "description": "Request to approve an ApprovalRequest.", "type": "object", "properties": { "expireTime": { "description": "The expiration time of this approval.", "format": "google-datetime", "type": "string" } }, "id": "ApproveApprovalRequestMessage" }, "DismissApprovalRequestMessage": { "description": "Request to dismiss an approval request.", "type": "object", "properties": {}, "id": "DismissApprovalRequestMessage" }, "ResourceProperties": { "properties": { "excludesDescendants": { "description": "Whether an approval will exclude the descendants of the resource being\nrequested.", "type": "boolean" } }, "id": "ResourceProperties", "description": "The properties associated with the resource of the request.", "type": "object" }, "AccessLocations": { "description": "Home office and physical location of the principal.", "type": "object", "properties": { "principalOfficeCountry": { "description": "The \"home office\" location of the principal. A two-letter country code\n(ISO 3166-1 alpha-2), such as \"US\", \"DE\" or \"GB\" or a region code. In some\nlimited situations Google systems may refer refer to a region code instead\nof a country code.\nPossible Region Codes:\n<ol>\n  <li>ASI: Asia</li>\n  <li>EUR: Europe</li>\n  <li>OCE: Oceania</li>\n  <li>AFR: Africa</li>\n  <li>NAM: North America</li>\n  <li>SAM: South America</li>\n  <li>ANT: Antarctica</li>\n  <li>ANY: Any location</li>\n</ol>", "type": "string" }, "principalPhysicalLocationCountry": { "description": "Physical location of the principal at the time of the access. A\ntwo-letter country code (ISO 3166-1 alpha-2), such as \"US\", \"DE\" or \"GB\" or\na region code. In some limited situations Google systems may refer refer to\na region code instead of a country code.\nPossible Region Codes:\n<ol>\n  <li>ASI: Asia</li>\n  <li>EUR: Europe</li>\n  <li>OCE: Oceania</li>\n  <li>AFR: Africa</li>\n  <li>NAM: North America</li>\n  <li>SAM: South America</li>\n  <li>ANT: Antarctica</li>\n  <li>ANY: Any location</li>\n</ol>", "type": "string" } }, "id": "AccessLocations" }, "DismissDecision": { "description": "A decision that has been made to dismiss an approval request.", "type": "object", "properties": { "dismissTime": { "description": "The time at which the approval request was dismissed.", "format": "google-datetime", "type": "string" } }, "id": "DismissDecision" } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "Access Approval", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://accessapproval.googleapis.com/", "ownerDomain": "google.com", "name": "accessapproval", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Access Approval API", "ownerName": "Google", "resources": { "folders": { "methods": { "getAccessApprovalSettings": { "response": { "$ref": "AccessApprovalSettings" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^folders/[^/]+/accessApprovalSettings$", "location": "path", "description": "Name of the AccessApprovalSettings to retrieve." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/folders/{foldersId}/accessApprovalSettings", "path": "v1beta1/{+name}", "id": "accessapproval.folders.getAccessApprovalSettings", "description": "Gets the settings associated with a project, folder, or organization." }, "updateAccessApprovalSettings": { "path": "v1beta1/{+name}", "id": "accessapproval.folders.updateAccessApprovalSettings", "description": "Updates the settings associated with a project, folder, or organization.\nCompletely replaces the existing settings.", "request": { "$ref": "AccessApprovalSettings" }, "response": { "$ref": "AccessApprovalSettings" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "name": { "required": true, "type": "string", "pattern": "^folders/[^/]+/accessApprovalSettings$", "location": "path", "description": "The resource name of the settings. Format is one of:\n<ol>\n  <li>\"projects/{project_id}/accessApprovalSettings\"</li>\n  <li>\"folders/{folder_id}/accessApprovalSettings\"</li>\n  <li>\"organizations/{organization_id}/accessApprovalSettings\"</li>\n<ol>" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/folders/{foldersId}/accessApprovalSettings" } }, "resources": { "approvalRequests": { "methods": { "list": { "flatPath": "v1beta1/folders/{foldersId}/approvalRequests", "id": "accessapproval.folders.approvalRequests.list", "path": "v1beta1/{+parent}/approvalRequests", "description": "Lists approval requests associated with a project, folder, or organization.\nApproval requests can be filtered by state (pending, active, dismissed).\nThe order is reverse chronological.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListApprovalRequestsResponse" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "The parent resource. This may be \"projects/{project_id}\",\n\"folders/{folder_id}\", or \"organizations/{organization_id}\".", "required": true, "type": "string", "pattern": "^folders/[^/]+$" }, "filter": { "description": "A filter on the type of approval requests to retrieve. Must be one of the\nfollowing values:\n<ol>\n  <li>[not set]: Requests that are pending or have active approvals.</li>\n  <li>ALL: All requests.</li>\n  <li>PENDING: Only pending requests.</li>\n  <li>ACTIVE: Only active (i.e. currently approved) requests.</li>\n  <li>DISMISSED: Only dismissed (including expired) requests.</li>\n</ol>", "type": "string", "location": "query" }, "pageToken": { "location": "query", "description": "A token identifying the page of results to return.", "type": "string" }, "pageSize": { "location": "query", "description": "Requested page size.", "format": "int32", "type": "integer" } } }, "get": { "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^folders/[^/]+/approvalRequests/[^/]+$", "location": "path", "description": "Name of the approval request to retrieve." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/folders/{foldersId}/approvalRequests/{approvalRequestsId}", "path": "v1beta1/{+name}", "id": "accessapproval.folders.approvalRequests.get", "description": "Gets an approval request. Returns NOT_FOUND if the request does not exist." }, "dismiss": { "path": "v1beta1/{+name}:dismiss", "id": "accessapproval.folders.approvalRequests.dismiss", "description": "Dismisses a request. Returns the updated ApprovalRequest.\n\nNOTE: This does not deny access to the resource if another request has been\nmade and approved. It is equivalent in effect to ignoring the request\naltogether.\n\nReturns NOT_FOUND if the request does not exist.\n\nReturns FAILED_PRECONDITION if the request exists but is not in a pending\nstate.", "request": { "$ref": "DismissApprovalRequestMessage" }, "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "pattern": "^folders/[^/]+/approvalRequests/[^/]+$", "location": "path", "description": "Name of the ApprovalRequest to dismiss.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/folders/{foldersId}/approvalRequests/{approvalRequestsId}:dismiss" }, "approve": { "description": "Approves a request and returns the updated ApprovalRequest.\n\nReturns NOT_FOUND if the request does not exist. Returns\nFAILED_PRECONDITION if the request exists but is not in a pending state.", "request": { "$ref": "ApproveApprovalRequestMessage" }, "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "description": "Name of the approval request to approve.", "required": true, "type": "string", "pattern": "^folders/[^/]+/approvalRequests/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/folders/{foldersId}/approvalRequests/{approvalRequestsId}:approve", "path": "v1beta1/{+name}:approve", "id": "accessapproval.folders.approvalRequests.approve" } } } } }, "projects": { "methods": { "getAccessApprovalSettings": { "description": "Gets the settings associated with a project, folder, or organization.", "response": { "$ref": "AccessApprovalSettings" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Name of the AccessApprovalSettings to retrieve.", "required": true, "type": "string", "pattern": "^projects/[^/]+/accessApprovalSettings$", "location": "path" } }, "flatPath": "v1beta1/projects/{projectsId}/accessApprovalSettings", "path": "v1beta1/{+name}", "id": "accessapproval.projects.getAccessApprovalSettings" }, "updateAccessApprovalSettings": { "description": "Updates the settings associated with a project, folder, or organization.\nCompletely replaces the existing settings.", "request": { "$ref": "AccessApprovalSettings" }, "response": { "$ref": "AccessApprovalSettings" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "name": { "description": "The resource name of the settings. Format is one of:\n<ol>\n  <li>\"projects/{project_id}/accessApprovalSettings\"</li>\n  <li>\"folders/{folder_id}/accessApprovalSettings\"</li>\n  <li>\"organizations/{organization_id}/accessApprovalSettings\"</li>\n<ol>", "required": true, "type": "string", "pattern": "^projects/[^/]+/accessApprovalSettings$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/projects/{projectsId}/accessApprovalSettings", "path": "v1beta1/{+name}", "id": "accessapproval.projects.updateAccessApprovalSettings" } }, "resources": { "approvalRequests": { "methods": { "approve": { "description": "Approves a request and returns the updated ApprovalRequest.\n\nReturns NOT_FOUND if the request does not exist. Returns\nFAILED_PRECONDITION if the request exists but is not in a pending state.", "request": { "$ref": "ApproveApprovalRequestMessage" }, "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "location": "path", "description": "Name of the approval request to approve.", "required": true, "type": "string", "pattern": "^projects/[^/]+/approvalRequests/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/projects/{projectsId}/approvalRequests/{approvalRequestsId}:approve", "path": "v1beta1/{+name}:approve", "id": "accessapproval.projects.approvalRequests.approve" }, "list": { "description": "Lists approval requests associated with a project, folder, or organization.\nApproval requests can be filtered by state (pending, active, dismissed).\nThe order is reverse chronological.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListApprovalRequestsResponse" }, "parameters": { "pageSize": { "location": "query", "description": "Requested page size.", "format": "int32", "type": "integer" }, "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "The parent resource. This may be \"projects/{project_id}\",\n\"folders/{folder_id}\", or \"organizations/{organization_id}\".", "required": true, "type": "string" }, "filter": { "description": "A filter on the type of approval requests to retrieve. Must be one of the\nfollowing values:\n<ol>\n  <li>[not set]: Requests that are pending or have active approvals.</li>\n  <li>ALL: All requests.</li>\n  <li>PENDING: Only pending requests.</li>\n  <li>ACTIVE: Only active (i.e. currently approved) requests.</li>\n  <li>DISMISSED: Only dismissed (including expired) requests.</li>\n</ol>", "type": "string", "location": "query" }, "pageToken": { "location": "query", "description": "A token identifying the page of results to return.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/projects/{projectsId}/approvalRequests", "id": "accessapproval.projects.approvalRequests.list", "path": "v1beta1/{+parent}/approvalRequests" }, "get": { "description": "Gets an approval request. Returns NOT_FOUND if the request does not exist.", "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Name of the approval request to retrieve.", "required": true, "type": "string", "pattern": "^projects/[^/]+/approvalRequests/[^/]+$", "location": "path" } }, "flatPath": "v1beta1/projects/{projectsId}/approvalRequests/{approvalRequestsId}", "path": "v1beta1/{+name}", "id": "accessapproval.projects.approvalRequests.get" }, "dismiss": { "flatPath": "v1beta1/projects/{projectsId}/approvalRequests/{approvalRequestsId}:dismiss", "path": "v1beta1/{+name}:dismiss", "id": "accessapproval.projects.approvalRequests.dismiss", "description": "Dismisses a request. Returns the updated ApprovalRequest.\n\nNOTE: This does not deny access to the resource if another request has been\nmade and approved. It is equivalent in effect to ignoring the request\naltogether.\n\nReturns NOT_FOUND if the request does not exist.\n\nReturns FAILED_PRECONDITION if the request exists but is not in a pending\nstate.", "request": { "$ref": "DismissApprovalRequestMessage" }, "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "location": "path", "description": "Name of the ApprovalRequest to dismiss.", "required": true, "type": "string", "pattern": "^projects/[^/]+/approvalRequests/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } } } } }, "organizations": { "methods": { "updateAccessApprovalSettings": { "id": "accessapproval.organizations.updateAccessApprovalSettings", "path": "v1beta1/{+name}", "description": "Updates the settings associated with a project, folder, or organization.\nCompletely replaces the existing settings.", "request": { "$ref": "AccessApprovalSettings" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "AccessApprovalSettings" }, "parameters": { "name": { "description": "The resource name of the settings. Format is one of:\n<ol>\n  <li>\"projects/{project_id}/accessApprovalSettings\"</li>\n  <li>\"folders/{folder_id}/accessApprovalSettings\"</li>\n  <li>\"organizations/{organization_id}/accessApprovalSettings\"</li>\n<ol>", "required": true, "type": "string", "pattern": "^organizations/[^/]+/accessApprovalSettings$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/organizations/{organizationsId}/accessApprovalSettings" }, "getAccessApprovalSettings": { "flatPath": "v1beta1/organizations/{organizationsId}/accessApprovalSettings", "path": "v1beta1/{+name}", "id": "accessapproval.organizations.getAccessApprovalSettings", "description": "Gets the settings associated with a project, folder, or organization.", "response": { "$ref": "AccessApprovalSettings" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^organizations/[^/]+/accessApprovalSettings$", "location": "path", "description": "Name of the AccessApprovalSettings to retrieve.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } }, "resources": { "approvalRequests": { "methods": { "approve": { "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "ApprovalRequest" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "Name of the approval request to approve.", "required": true, "type": "string", "pattern": "^organizations/[^/]+/approvalRequests/[^/]+$" } }, "flatPath": "v1beta1/organizations/{organizationsId}/approvalRequests/{approvalRequestsId}:approve", "id": "accessapproval.organizations.approvalRequests.approve", "path": "v1beta1/{+name}:approve", "request": { "$ref": "ApproveApprovalRequestMessage" }, "description": "Approves a request and returns the updated ApprovalRequest.\n\nReturns NOT_FOUND if the request does not exist. Returns\nFAILED_PRECONDITION if the request exists but is not in a pending state." }, "list": { "path": "v1beta1/{+parent}/approvalRequests", "id": "accessapproval.organizations.approvalRequests.list", "description": "Lists approval requests associated with a project, folder, or organization.\nApproval requests can be filtered by state (pending, active, dismissed).\nThe order is reverse chronological.", "response": { "$ref": "ListApprovalRequestsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "pageToken": { "location": "query", "description": "A token identifying the page of results to return.", "type": "string" }, "pageSize": { "description": "Requested page size.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "description": "The parent resource. This may be \"projects/{project_id}\",\n\"folders/{folder_id}\", or \"organizations/{organization_id}\".", "required": true, "type": "string", "pattern": "^organizations/[^/]+$", "location": "path" }, "filter": { "location": "query", "description": "A filter on the type of approval requests to retrieve. Must be one of the\nfollowing values:\n<ol>\n  <li>[not set]: Requests that are pending or have active approvals.</li>\n  <li>ALL: All requests.</li>\n  <li>PENDING: Only pending requests.</li>\n  <li>ACTIVE: Only active (i.e. currently approved) requests.</li>\n  <li>DISMISSED: Only dismissed (including expired) requests.</li>\n</ol>", "type": "string" } }, "flatPath": "v1beta1/organizations/{organizationsId}/approvalRequests" }, "get": { "httpMethod": "GET", "response": { "$ref": "ApprovalRequest" }, "parameterOrder": ["name"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^organizations/[^/]+/approvalRequests/[^/]+$", "location": "path", "description": "Name of the approval request to retrieve." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta1/organizations/{organizationsId}/approvalRequests/{approvalRequestsId}", "id": "accessapproval.organizations.approvalRequests.get", "path": "v1beta1/{+name}", "description": "Gets an approval request. Returns NOT_FOUND if the request does not exist." }, "dismiss": { "flatPath": "v1beta1/organizations/{organizationsId}/approvalRequests/{approvalRequestsId}:dismiss", "id": "accessapproval.organizations.approvalRequests.dismiss", "path": "v1beta1/{+name}:dismiss", "description": "Dismisses a request. Returns the updated ApprovalRequest.\n\nNOTE: This does not deny access to the resource if another request has been\nmade and approved. It is equivalent in effect to ignoring the request\naltogether.\n\nReturns NOT_FOUND if the request does not exist.\n\nReturns FAILED_PRECONDITION if the request exists but is not in a pending\nstate.", "request": { "$ref": "DismissApprovalRequestMessage" }, "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "ApprovalRequest" }, "parameters": { "name": { "location": "path", "description": "Name of the ApprovalRequest to dismiss.", "required": true, "type": "string", "pattern": "^organizations/[^/]+/approvalRequests/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } } } } } }, "parameters": { "$.xgafv": { "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "callback": { "description": "JSONP", "type": "string", "location": "query" }, "alt": { "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" } }, "version": "v1beta1", "baseUrl": "https://accessapproval.googleapis.com/", "kind": "discovery#restDescription", "description": "An API for controlling access to data by Google personnel.", "servicePath": "", "basePath": "", "id": "accessapproval:v1beta1", "documentationLink": "https://cloud.google.com/access-approval/docs", "revision": "20190614", "discoveryVersion": "v1" };
//# sourceMappingURL=accessapproval-v1beta1.js.map