"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "id": "alertcenter:v1beta1", "documentationLink": "https://developers.google.com/admin-sdk/alertcenter/", "revision": "20190622", "discoveryVersion": "v1", "version_module": true, "schemas": { "UndeleteAlertRequest": { "id": "UndeleteAlertRequest", "description": "A request to undelete a specific alert that was marked for deletion.", "type": "object", "properties": { "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert is associated with.\nInferred from the caller identity if not provided.", "type": "string" } } }, "Settings": { "description": "Customer-level settings.", "type": "object", "properties": { "notifications": { "description": "The list of notifications.", "type": "array", "items": { "$ref": "Notification" } } }, "id": "Settings" }, "Csv": { "description": "A representation of a CSV file attachment, as a list of column headers and\na list of data rows.", "type": "object", "properties": { "headers": { "description": "The list of headers for data columns in a CSV file.", "type": "array", "items": { "type": "string" } }, "dataRows": { "description": "The list of data rows in a CSV file, as string arrays rather than as a\nsingle comma-separated string.", "type": "array", "items": { "$ref": "CsvRow" } } }, "id": "Csv" }, "PhishingSpike": { "description": "Alert for a spike in user reported phishing.\n<aside class=\"warning\"><b>Warning</b>: This type has been deprecated. Use\n[MailPhishing](/admin-sdk/alertcenter/reference/rest/v1beta1/MailPhishing)\ninstead.</aside>", "type": "object", "properties": { "messages": { "description": "The list of messages contained by this alert.", "type": "array", "items": { "$ref": "GmailMessageInfo" } }, "domainId": { "description": "The domain ID.", "$ref": "DomainId" }, "maliciousEntity": { "$ref": "MaliciousEntity", "description": "The entity whose actions triggered a Gmail phishing alert." }, "isInternal": { "description": "If `true`, the email originated from within the organization.", "type": "boolean" } }, "id": "PhishingSpike" }, "DeviceCompromised": { "description": "A mobile device compromised alert. Derived from audit logs.", "type": "object", "properties": { "email": { "description": "The email of the user this alert was created for.", "type": "string" }, "events": { "description": "Required. The list of security events.", "type": "array", "items": { "$ref": "DeviceCompromisedSecurityDetail" } } }, "id": "DeviceCompromised" }, "MaliciousEntity": { "description": "Entity whose actions triggered a Gmail phishing alert.", "type": "object", "properties": { "fromHeader": { "description": "The sender email address.", "type": "string" }, "displayName": { "description": "The header from display name.", "type": "string" } }, "id": "MaliciousEntity" }, "ListAlertFeedbackResponse": { "description": "Response message for an alert feedback listing request.", "type": "object", "properties": { "feedback": { "description": "The list of alert feedback.\nFeedback entries for each alert are ordered by creation time descending.", "type": "array", "items": { "$ref": "AlertFeedback" } } }, "id": "ListAlertFeedbackResponse" }, "CloudPubsubTopic": { "description": "A reference to a Cloud Pubsub topic.\n\nTo register for notifications, the owner of the topic must grant\n`alerts-api-push-notifications@system.gserviceaccount.com` the\n `projects.topics.publish` permission.", "type": "object", "properties": { "payloadFormat": { "enumDescriptions": ["Payload format is not specified (will use JSON as default).", "Use JSON."], "enum": ["PAYLOAD_FORMAT_UNSPECIFIED", "JSON"], "description": "Optional. The format of the payload that would be sent.\nIf not specified the format will be JSON.", "type": "string" }, "topicName": { "description": "The `name` field of a Cloud Pubsub [Topic]\n(https://cloud.google.com/pubsub/docs/reference/rest/v1/projects.topics#Topic).", "type": "string" } }, "id": "CloudPubsubTopic" }, "Attachment": { "description": "Attachment with application-specific information about an alert.", "type": "object", "properties": { "csv": { "description": "A CSV file attachment.", "$ref": "Csv" } }, "id": "Attachment" }, "BadWhitelist": { "description": "Alert for setting the domain or IP that malicious email comes from as\nwhitelisted domain or IP in Gmail advanced settings.", "type": "object", "properties": { "messages": { "type": "array", "items": { "$ref": "GmailMessageInfo" }, "description": "The list of messages contained by this alert." }, "sourceIp": { "description": "The source IP address of the malicious email, for example,\n`127.0.0.1`.", "type": "string" }, "domainId": { "$ref": "DomainId", "description": "The domain ID." }, "maliciousEntity": { "$ref": "MaliciousEntity", "description": "The entity whose actions triggered a Gmail phishing alert." } }, "id": "BadWhitelist" }, "AlertFeedback": { "description": "A customer feedback about an alert.", "type": "object", "properties": { "customerId": { "description": "Output only. The unique identifier of the Google account of the customer.", "type": "string" }, "createTime": { "description": "Output only. The time this feedback was created.", "format": "google-datetime", "type": "string" }, "email": { "description": "Output only. The email of the user that provided the feedback.", "type": "string" }, "alertId": { "description": "Output only. The alert identifier.", "type": "string" }, "type": { "description": "Required. The type of the feedback.", "type": "string", "enumDescriptions": ["The feedback type is not specified.", "The alert report is not useful.", "The alert report is somewhat useful.", "The alert report is very useful."], "enum": ["ALERT_FEEDBACK_TYPE_UNSPECIFIED", "NOT_USEFUL", "SOMEWHAT_USEFUL", "VERY_USEFUL"] }, "feedbackId": { "description": "Output only. The unique identifier for the feedback.", "type": "string" } }, "id": "AlertFeedback" }, "ListAlertsResponse": { "type": "object", "properties": { "alerts": { "description": "The list of alerts.", "type": "array", "items": { "$ref": "Alert" } }, "nextPageToken": { "description": "The token for the next page. If not empty, indicates that there may be more\nalerts that match the listing request; this value can be used in a\nsubsequent ListAlertsRequest to get alerts continuing from last result\nof the current list call.", "type": "string" } }, "id": "ListAlertsResponse", "description": "Response message for an alert listing request." }, "Notification": { "description": "Settings for callback notifications.\nFor more details see [G Suite Alert\nNotification](/admin-sdk/alertcenter/guides/notifications).", "type": "object", "properties": { "cloudPubsubTopic": { "$ref": "CloudPubsubTopic", "description": "A Google Cloud Pub/sub topic destination." } }, "id": "Notification" }, "CsvRow": { "type": "object", "properties": { "entries": { "description": "The data entries in a CSV file row, as a string array rather than a\nsingle comma-separated string.", "type": "array", "items": { "type": "string" } } }, "id": "CsvRow", "description": "A representation of a single data row in a CSV file." }, "AccountWarning": { "id": "AccountWarning", "description": "Alerts for user account warning events.", "type": "object", "properties": { "email": { "type": "string", "description": "Required. The email of the user that this event belongs to." }, "loginDetails": { "$ref": "LoginDetails", "description": "Optional. Details of the login action associated with the warning event.\nThis is only available for:\n\n* Suspicious login\n* Suspicious login (less secure app)\n* Suspicious programmatic login\n* User suspended (suspicious activity)" } } }, "MailPhishing": { "description": "Proto for all phishing alerts with common payload.\nSupported types are any of the following:\n\n* User reported phishing\n* User reported spam spike\n* Suspicious message reported\n* Phishing reclassification\n* Malware reclassification", "type": "object", "properties": { "messages": { "description": "The list of messages contained by this alert.", "type": "array", "items": { "$ref": "GmailMessageInfo" } }, "domainId": { "$ref": "DomainId", "description": "The domain ID." }, "maliciousEntity": { "$ref": "MaliciousEntity", "description": "The entity whose actions triggered a Gmail phishing alert." }, "isInternal": { "description": "If `true`, the email originated from within the organization.", "type": "boolean" } }, "id": "MailPhishing" }, "StateSponsoredAttack": { "type": "object", "properties": { "email": { "description": "The email of the user this incident was created for.", "type": "string" } }, "id": "StateSponsoredAttack", "description": "A state-sponsored attack alert. Derived from audit logs." }, "Alert": { "id": "Alert", "description": "An alert affecting a customer.", "type": "object", "properties": { "deleted": { "description": "Output only. `True` if this alert is marked for deletion.", "type": "boolean" }, "type": { "description": "Required. The type of the alert.\nThis is output only after alert is created.\nFor a list of available alert types see\n[G Suite Alert types](/admin-sdk/alertcenter/reference/alert-types).", "type": "string" }, "securityInvestigationToolLink": { "description": "Output only. An optional\n[Security Investigation Tool](https://support.google.com/a/answer/7575955)\nquery for this alert.", "type": "string" }, "endTime": { "description": "Optional. The time the event that caused this alert ceased being active.\nIf provided, the end time must not be earlier than the start time.\nIf not provided, it indicates an ongoing alert.", "format": "google-datetime", "type": "string" }, "data": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Optional. The data associated with this alert, for example\ngoogle.apps.alertcenter.type.DeviceCompromised.", "type": "object" }, "startTime": { "description": "Required. The time the event that caused this alert was started or\ndetected.", "format": "google-datetime", "type": "string" }, "customerId": { "description": "Output only. The unique identifier of the Google account of the customer.", "type": "string" }, "source": { "type": "string", "description": "Required. A unique identifier for the system that reported the alert.\nThis is output only after alert is created.\n\nSupported sources are any of the following:\n\n* Google Operations\n* Mobile device management\n* Gmail phishing\n* Domain wide takeout\n* Government attack warning\n* Google identity" }, "createTime": { "description": "Output only. The time this alert was created.", "format": "google-datetime", "type": "string" }, "updateTime": { "description": "Output only. The time this alert was last updated.", "format": "google-datetime", "type": "string" }, "alertId": { "description": "Output only. The unique identifier for the alert.", "type": "string" } } }, "LoginDetails": { "id": "LoginDetails", "description": "The details of the login action.", "type": "object", "properties": { "loginTime": { "description": "Optional. The successful login time that is associated with the warning\nevent. This will not be present for blocked login attempts.", "format": "google-datetime", "type": "string" }, "ipAddress": { "description": "Optional. The human-readable IP address (for example,\n`11.22.33.44`) that is associated with the warning event.", "type": "string" } } }, "DeviceCompromisedSecurityDetail": { "description": "Detailed information of a single MDM device compromised event.", "type": "object", "properties": { "deviceCompromisedState": { "description": "The device compromised state. Possible values are \"`Compromised`\" or\n\"`Not Compromised`\".", "type": "string" }, "iosVendorId": { "description": "Required for iOS, empty for others.", "type": "string" }, "deviceModel": { "description": "The model of the device.", "type": "string" }, "deviceType": { "description": "The type of the device.", "type": "string" }, "deviceId": { "type": "string", "description": "Required. The device ID." }, "resourceId": { "description": "The device resource ID.", "type": "string" }, "serialNumber": { "description": "The serial number of the device.", "type": "string" } }, "id": "DeviceCompromisedSecurityDetail" }, "Empty": { "type": "object", "properties": {}, "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`." }, "GoogleOperations": { "properties": { "title": { "description": "A one-line incident description.", "type": "string" }, "description": { "description": "A detailed, freeform incident description.", "type": "string" }, "affectedUserEmails": { "description": "The list of emails which correspond to the users directly affected by the\nincident.", "type": "array", "items": { "type": "string" } }, "attachmentData": { "$ref": "Attachment", "description": "Optional. Application-specific data for an incident, provided when the\nG Suite application which reported the incident cannot be completely\nrestored to a valid state." } }, "id": "GoogleOperations", "description": "An incident reported by Google Operations for a G Suite application.", "type": "object" }, "SuspiciousActivitySecurityDetail": { "properties": { "deviceModel": { "description": "The model of the device.", "type": "string" }, "iosVendorId": { "type": "string", "description": "Required for iOS, empty for others." }, "deviceType": { "description": "The type of the device.", "type": "string" }, "deviceId": { "description": "Required. The device ID.", "type": "string" }, "resourceId": { "description": "The device resource ID.", "type": "string" }, "oldValue": { "description": "The old value of the device property before the change.", "type": "string" }, "serialNumber": { "description": "The serial number of the device.", "type": "string" }, "deviceProperty": { "description": "The device property which was changed.", "type": "string" }, "newValue": { "description": "The new value of the device property after the change.", "type": "string" } }, "id": "SuspiciousActivitySecurityDetail", "description": "Detailed information of a single MDM suspicious activity event.", "type": "object" }, "SuspiciousActivity": { "description": "A mobile suspicious activity alert. Derived from audit logs.", "type": "object", "properties": { "email": { "description": "The email of the user this alert was created for.", "type": "string" }, "events": { "description": "Required. The list of security events.", "type": "array", "items": { "$ref": "SuspiciousActivitySecurityDetail" } } }, "id": "SuspiciousActivity" }, "DomainWideTakeoutInitiated": { "description": "A takeout operation for the entire domain was initiated by an admin. Derived\nfrom audit logs.", "type": "object", "properties": { "email": { "description": "The email of the admin who initiated the takeout.", "type": "string" }, "takeoutRequestId": { "description": "The takeout request ID.", "type": "string" } }, "id": "DomainWideTakeoutInitiated" }, "GmailMessageInfo": { "description": "Details of a message in phishing spike alert.", "type": "object", "properties": { "subjectText": { "description": "The email subject text (only available for reported emails).", "type": "string" }, "messageId": { "description": "The message ID.", "type": "string" }, "attachmentsSha256Hash": { "description": "The `SHA256` hash of email's attachment and all MIME parts.", "type": "array", "items": { "type": "string" } }, "messageBodySnippet": { "description": "The snippet of the message body text (only available for reported emails).", "type": "string" }, "date": { "type": "string", "description": "The date the malicious email was sent.", "format": "google-datetime" }, "recipient": { "description": "The recipient of this email.", "type": "string" }, "md5HashSubject": { "type": "string", "description": "The MD5 Hash of email's subject (only available for reported emails)." }, "md5HashMessageBody": { "description": "The hash of the message body text.", "type": "string" } }, "id": "GmailMessageInfo" }, "ActivityRule": { "properties": { "createTime": { "description": "Rule create timestamp.", "format": "google-datetime", "type": "string" }, "actionNames": { "type": "array", "items": { "type": "string" }, "description": "List of action names associated with the rule threshold." }, "updateTime": { "description": "The timestamp of the last update to the rule.", "format": "google-datetime", "type": "string" }, "supersedingAlert": { "description": "Alert id superseding this alert. It is used to indicate that superseding\nalert is essentially extension of this alert and we found the relationship\nafter creating both alerts.", "type": "string" }, "supersededAlerts": { "description": "List of alert ids superseded by this alert. It is used to indicate that\nthis alert is essentially extension of superseded alerts and we found the\nrelationship after creating these alerts.", "type": "array", "items": { "type": "string" } }, "description": { "description": "Description of the rule.", "type": "string" }, "windowSize": { "description": "Rule window size. Possible values are 1 hour or 24 hours.", "format": "google-duration", "type": "string" }, "name": { "description": "Rule name.", "type": "string" }, "threshold": { "description": "Alert threshold is for example “COUNT > 5”.", "type": "string" }, "displayName": { "description": "Alert display name.", "type": "string" }, "triggerSource": { "description": "The trigger sources for this rule.\n\n* GMAIL_EVENTS\n* DEVICE_EVENTS\n* USER_EVENTS", "type": "string" }, "query": { "description": "Query that is used to get the data from the associated source.", "type": "string" } }, "id": "ActivityRule", "description": "Alerts from G Suite Security Center rules service configured by admin.", "type": "object" }, "DomainId": { "properties": { "customerPrimaryDomain": { "description": "The primary domain for the customer.", "type": "string" } }, "id": "DomainId", "description": "Domain ID of Gmail phishing alerts.", "type": "object" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "canonicalName": "AlertCenter", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/apps.alerts": { "description": "See and delete your domain's G Suite alerts, and send alert feedback" } } } }, "rootUrl": "https://alertcenter.googleapis.com/", "ownerDomain": "google.com", "name": "alertcenter", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "G Suite Alert Center API", "ownerName": "Google", "resources": { "alerts": { "methods": { "list": { "description": "Lists the alerts.", "response": { "$ref": "ListAlertsResponse" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "parameters": { "pageToken": { "location": "query", "description": "Optional. A token identifying a page of results the server should return.\nIf empty, a new iteration is started. To continue an iteration, pass in\nthe value from the previous ListAlertsResponse's\nnext_page_token field.", "type": "string" }, "orderBy": { "location": "query", "description": "Optional. The sort order of the list results.\nIf not specified results may be returned in arbitrary order.\nYou can sort the results in descending order based on the creation\ntimestamp using `order_by=\"create_time desc\"`.\nCurrently, supported sorting are `create_time asc`, `create_time desc`,\n`update_time desc`", "type": "string" }, "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alerts are associated with.\nInferred from the caller identity if not provided.", "type": "string", "location": "query" }, "pageSize": { "description": "Optional. The requested page size. Server may return fewer items than\nrequested. If unspecified, server picks an appropriate default.", "format": "int32", "type": "integer", "location": "query" }, "filter": { "location": "query", "description": "Optional. A query string for filtering alert results.\nFor more details, see [Query\nfilters](/admin-sdk/alertcenter/guides/query-filters) and [Supported\nquery filter\nfields](/admin-sdk/alertcenter/reference/filter-fields#alerts.list).", "type": "string" } }, "flatPath": "v1beta1/alerts", "path": "v1beta1/alerts", "id": "alertcenter.alerts.list" }, "get": { "response": { "$ref": "Alert" }, "parameterOrder": ["alertId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "parameters": { "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert is associated with.\nInferred from the caller identity if not provided.", "type": "string", "location": "query" }, "alertId": { "location": "path", "description": "Required. The identifier of the alert to retrieve.", "required": true, "type": "string" } }, "flatPath": "v1beta1/alerts/{alertId}", "path": "v1beta1/alerts/{alertId}", "id": "alertcenter.alerts.get", "description": "Gets the specified alert. Attempting to get a nonexistent alert returns\n`NOT_FOUND` error." }, "undelete": { "request": { "$ref": "UndeleteAlertRequest" }, "description": "Restores, or \"undeletes\", an alert that was marked for deletion within the\npast 30 days. Attempting to undelete an alert which was marked for deletion\nover 30 days ago (which has been removed from the Alert Center database) or\na nonexistent alert returns a `NOT_FOUND` error. Attempting to\nundelete an alert which has not been marked for deletion has no effect.", "response": { "$ref": "Alert" }, "parameterOrder": ["alertId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "parameters": { "alertId": { "location": "path", "description": "Required. The identifier of the alert to undelete.", "required": true, "type": "string" } }, "flatPath": "v1beta1/alerts/{alertId}:undelete", "path": "v1beta1/alerts/{alertId}:undelete", "id": "alertcenter.alerts.undelete" }, "delete": { "parameters": { "alertId": { "location": "path", "description": "Required. The identifier of the alert to delete.", "required": true, "type": "string" }, "customerId": { "location": "query", "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert is associated with.\nInferred from the caller identity if not provided.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "flatPath": "v1beta1/alerts/{alertId}", "path": "v1beta1/alerts/{alertId}", "id": "alertcenter.alerts.delete", "description": "Marks the specified alert for deletion. An alert that has been marked for\ndeletion is removed from Alert Center after 30 days.\nMarking an alert for deletion has no effect on an alert which has\nalready been marked for deletion. Attempting to mark a nonexistent alert\nfor deletion results in a `NOT_FOUND` error.", "response": { "$ref": "Empty" }, "parameterOrder": ["alertId"], "httpMethod": "DELETE" } }, "resources": { "feedback": { "methods": { "list": { "response": { "$ref": "ListAlertFeedbackResponse" }, "parameterOrder": ["alertId"], "httpMethod": "GET", "parameters": { "alertId": { "location": "path", "description": "Required. The alert identifier.\nThe \"-\" wildcard could be used to represent all alerts.", "required": true, "type": "string" }, "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert feedback are associated with.\nInferred from the caller identity if not provided.", "type": "string", "location": "query" }, "filter": { "location": "query", "description": "Optional. A query string for filtering alert feedback results.\nFor more details, see [Query\nfilters](/admin-sdk/alertcenter/guides/query-filters) and [Supported\nquery filter\nfields](/admin-sdk/alertcenter/reference/filter-fields#alerts.feedback.list).", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "flatPath": "v1beta1/alerts/{alertId}/feedback", "path": "v1beta1/alerts/{alertId}/feedback", "id": "alertcenter.alerts.feedback.list", "description": "Lists all the feedback for an alert. Attempting to list feedbacks for\na non-existent alert returns `NOT_FOUND` error." }, "create": { "description": "Creates new feedback for an alert. Attempting to create a feedback for\na non-existent alert returns `NOT_FOUND` error.", "request": { "$ref": "AlertFeedback" }, "response": { "$ref": "AlertFeedback" }, "parameterOrder": ["alertId"], "httpMethod": "POST", "parameters": { "alertId": { "required": true, "type": "string", "location": "path", "description": "Required. The identifier of the alert this feedback belongs to." }, "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert is associated with.\nInferred from the caller identity if not provided.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "flatPath": "v1beta1/alerts/{alertId}/feedback", "path": "v1beta1/alerts/{alertId}/feedback", "id": "alertcenter.alerts.feedback.create" } } } } }, "v1beta1": { "methods": { "getSettings": { "response": { "$ref": "Settings" }, "parameterOrder": [], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "parameters": { "customerId": { "location": "query", "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert settings are associated with.\nInferred from the caller identity if not provided.", "type": "string" } }, "flatPath": "v1beta1/settings", "path": "v1beta1/settings", "id": "alertcenter.getSettings", "description": "Returns customer-level settings." }, "updateSettings": { "id": "alertcenter.updateSettings", "path": "v1beta1/settings", "request": { "$ref": "Settings" }, "description": "Updates the customer-level settings.", "httpMethod": "PATCH", "parameterOrder": [], "response": { "$ref": "Settings" }, "scopes": ["https://www.googleapis.com/auth/apps.alerts"], "parameters": { "customerId": { "description": "Optional. The unique identifier of the G Suite organization account of the\ncustomer the alert settings are associated with.\nInferred from the caller identity if not provided.", "type": "string", "location": "query" } }, "flatPath": "v1beta1/settings" } } } }, "parameters": { "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "$.xgafv": { "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" } }, "version": "v1beta1", "baseUrl": "https://alertcenter.googleapis.com/", "kind": "discovery#restDescription", "description": "Manages alerts on issues affecting your domain.", "servicePath": "", "basePath": "" };
//# sourceMappingURL=alertcenter-v1beta1.js.map