"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "id": "cloudbuild:v1alpha1", "documentationLink": "https://cloud.google.com/cloud-build/docs/", "revision": "20190622", "discoveryVersion": "v1", "version_module": true, "schemas": { "Empty": { "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {} }, "Build": { "type": "object", "properties": { "status": { "enumDescriptions": ["Status of the build is unknown.", "Build or step is queued; work has not yet begun.", "Build or step is being executed.", "Build or step finished successfully.", "Build or step failed to complete successfully.", "Build or step failed due to an internal cause.", "Build or step took longer than was allowed.", "Build or step was canceled by a user."], "enum": ["STATUS_UNKNOWN", "QUEUED", "WORKING", "SUCCESS", "FAILURE", "INTERNAL_ERROR", "TIMEOUT", "CANCELLED"], "description": "Output only. Status of the build.", "type": "string" }, "statusDetail": { "type": "string", "description": "Output only. Customer-readable message about the current status." }, "artifacts": { "$ref": "Artifacts", "description": "Artifacts produced by the build that should be uploaded upon\nsuccessful completion of all build steps." }, "timeout": { "description": "Amount of time that this build should be allowed to run, to second\ngranularity. If this amount of time elapses, work on the build will cease\nand the build status will be `TIMEOUT`.\n\nDefault time is ten minutes.", "format": "google-duration", "type": "string" }, "secrets": { "type": "array", "items": { "$ref": "Secret" }, "description": "Secrets to decrypt using Cloud Key Management Service." }, "logsBucket": { "description": "Google Cloud Storage bucket where logs should be written (see\n[Bucket Name\nRequirements](https://cloud.google.com/storage/docs/bucket-naming#requirements)).\nLogs file names will be of the format `${logs_bucket}/log-${build_id}.txt`.", "type": "string" }, "results": { "$ref": "Results", "description": "Output only. Results of the build." }, "steps": { "description": "Required. The operations to be performed on the workspace.", "type": "array", "items": { "$ref": "BuildStep" } }, "buildTriggerId": { "description": "Output only. The ID of the `BuildTrigger` that triggered this build, if it\nwas triggered automatically.", "type": "string" }, "id": { "type": "string", "description": "Output only. Unique identifier of the build." }, "tags": { "type": "array", "items": { "type": "string" }, "description": "Tags for annotation of a `Build`. These are not docker tags." }, "startTime": { "description": "Output only. Time at which execution of the build was started.", "format": "google-datetime", "type": "string" }, "substitutions": { "description": "Substitutions data for `Build` resource.", "type": "object", "additionalProperties": { "type": "string" } }, "timing": { "type": "object", "additionalProperties": { "$ref": "TimeSpan" }, "description": "Output only. Stores timing information for phases of the build. Valid keys\nare:\n\n* BUILD: time to execute all build steps\n* PUSH: time to push all specified images.\n* FETCHSOURCE: time to fetch source.\n\nIf the build does not specify source or images,\nthese keys will not be included." }, "createTime": { "description": "Output only. Time at which the request to create the build was received.", "format": "google-datetime", "type": "string" }, "sourceProvenance": { "description": "Output only. A permanent fixed identifier for source.", "$ref": "SourceProvenance" }, "images": { "type": "array", "items": { "type": "string" }, "description": "A list of images to be pushed upon the successful completion of all build\nsteps.\n\nThe images are pushed using the builder service account's credentials.\n\nThe digests of the pushed images will be stored in the `Build` resource's\nresults field.\n\nIf any of the images fail to be pushed, the build status is marked\n`FAILURE`." }, "projectId": { "description": "Output only. ID of the project.", "type": "string" }, "finishTime": { "type": "string", "description": "Output only. Time at which execution of the build was finished.\n\nThe difference between finish_time and start_time is the duration of the\nbuild's execution.", "format": "google-datetime" }, "logUrl": { "description": "Output only. URL to logs for this build in Google Cloud Console.", "type": "string" }, "source": { "description": "The location of the source files to build.", "$ref": "Source" }, "options": { "$ref": "BuildOptions", "description": "Special options for this build." } }, "id": "Build", "description": "A build resource in the Cloud Build API.\n\nAt a high level, a `Build` describes where to find source code, how to build\nit (for example, the builder image to run on the source), and where to store\nthe built artifacts.\n\nFields can include the following variables, which will be expanded when the\nbuild is created:\n\n- $PROJECT_ID: the project ID of the build.\n- $BUILD_ID: the autogenerated ID of the build.\n- $REPO_NAME: the source repository name specified by RepoSource.\n- $BRANCH_NAME: the branch name specified by RepoSource.\n- $TAG_NAME: the tag name specified by RepoSource.\n- $REVISION_ID or $COMMIT_SHA: the commit SHA specified by RepoSource or\n  resolved from the specified branch or tag.\n- $SHORT_SHA: first 7 characters of $REVISION_ID or $COMMIT_SHA." }, "Volume": { "description": "Volume describes a Docker container volume which is mounted into build steps\nin order to persist files across build step execution.", "type": "object", "properties": { "path": { "description": "Path at which to mount the volume.\n\nPaths must be absolute and cannot conflict with other volume paths on the\nsame build step or with certain reserved volume paths.", "type": "string" }, "name": { "description": "Name of the volume to mount.\n\nVolume names must be unique per build step and must be valid names for\nDocker volumes. Each named volume must be used by at least two build steps.", "type": "string" } }, "id": "Volume" }, "Source": { "type": "object", "properties": { "storageSource": { "$ref": "StorageSource", "description": "If provided, get the source from this location in Google Cloud Storage." }, "repoSource": { "$ref": "RepoSource", "description": "If provided, get the source from this location in a Cloud Source\nRepository." } }, "id": "Source", "description": "Location of the source in a supported storage service." }, "TimeSpan": { "type": "object", "properties": { "endTime": { "description": "End of time span.", "format": "google-datetime", "type": "string" }, "startTime": { "type": "string", "description": "Start of time span.", "format": "google-datetime" } }, "id": "TimeSpan", "description": "Start and end times for a build execution phase." }, "WorkerPool": { "type": "object", "properties": { "createTime": { "type": "string", "description": "Output only. Time at which the request to create the `WorkerPool` was\nreceived.", "format": "google-datetime" }, "status": { "enum": ["STATUS_UNSPECIFIED", "CREATING", "RUNNING", "DELETING", "DELETED"], "description": "Output only. WorkerPool Status.", "type": "string", "enumDescriptions": ["Status of the `WorkerPool` is unknown.", "`WorkerPool` is being created.", "`WorkerPool` is running.", "`WorkerPool` is being deleting: cancelling builds and draining workers.", "`WorkerPool` is deleted."] }, "updateTime": { "description": "Output only. Time at which the request to update the `WorkerPool` was\nreceived.", "format": "google-datetime", "type": "string" }, "name": { "description": "User-defined name of the `WorkerPool`.", "type": "string" }, "projectId": { "description": "The project ID of the GCP project for which the `WorkerPool` is created.", "type": "string" }, "workerCount": { "type": "string", "description": "Total number of workers to be created across all requested regions.", "format": "int64" }, "serviceAccountEmail": { "description": "Output only. The service account used to manage the `WorkerPool`. The\nservice account must have the Compute Instance Admin (Beta) permission at\nthe project level.", "type": "string" }, "regions": { "enumDescriptions": ["no region", "us-central1 region", "us-west1 region", "us-east1 region", "us-east4 region"], "description": "List of regions to create the `WorkerPool`. Regions can't be empty.\nIf Cloud Build adds a new GCP region in the future, the existing\n`WorkerPool` will not be enabled in the new region automatically;\nyou must add the new region to the `regions` field to enable the\n`WorkerPool` in that region.", "type": "array", "items": { "enum": ["REGION_UNSPECIFIED", "us-central1", "us-west1", "us-east1", "us-east4"], "type": "string" } }, "workerConfig": { "$ref": "WorkerConfig", "description": "Configuration to be used for a creating workers in the `WorkerPool`." }, "deleteTime": { "description": "Output only. Time at which the request to delete the `WorkerPool` was\nreceived.", "format": "google-datetime", "type": "string" } }, "id": "WorkerPool", "description": "Configuration for a WorkerPool to run the builds.\n\nWorkers are machines that Cloud Build uses to run your builds. By default,\nall workers run in a project owned by Cloud Build. To have full control over\nthe workers that execute your builds -- such as enabling them to access\nprivate resources on your private network -- you can request Cloud Build to\nrun the workers in your own project by creating a custom workers pool." }, "BuildOptions": { "description": "Optional arguments to enable specific features of builds.", "type": "object", "properties": { "substitutionOption": { "enumDescriptions": ["Fails the build if error in substitutions checks, like missing\na substitution in the template or in the map.", "Do not fail the build if error in substitutions checks."], "enum": ["MUST_MATCH", "ALLOW_LOOSE"], "description": "Option to specify behavior when there is an error in the substitution\nchecks.", "type": "string" }, "requestedVerifyOption": { "description": "Requested verifiability options.", "type": "string", "enumDescriptions": ["Not a verifiable build. (default)", "Verified build."], "enum": ["NOT_VERIFIED", "VERIFIED"] }, "diskSizeGb": { "description": "Requested disk size for the VM that runs the build. Note that this is *NOT*\n\"disk free\"; some of the space will be used by the operating system and\nbuild utilities. Also note that this is the minimum disk size that will be\nallocated for the build -- the build may run with a larger disk than\nrequested. At present, the maximum disk size is 1000GB; builds that request\nmore than the maximum are rejected with an error.", "format": "int64", "type": "string" }, "sourceProvenanceHash": { "description": "Requested hash for SourceProvenance.", "type": "array", "items": { "type": "string", "enum": ["NONE", "SHA256", "MD5"] }, "enumDescriptions": ["No hash requested.", "Use a sha256 hash.", "Use a md5 hash."] }, "secretEnv": { "description": "A list of global environment variables, which are encrypted using a Cloud\nKey Management Service crypto key. These values must be specified in the\nbuild's `Secret`. These variables will be available to all build steps\nin this build.", "type": "array", "items": { "type": "string" } }, "machineType": { "description": "Compute Engine machine type on which to run the build.", "type": "string", "enumDescriptions": ["Standard machine type.", "Highcpu machine with 8 CPUs.", "Highcpu machine with 32 CPUs."], "enum": ["UNSPECIFIED", "N1_HIGHCPU_8", "N1_HIGHCPU_32"] }, "volumes": { "type": "array", "items": { "$ref": "Volume" }, "description": "Global list of volumes to mount for ALL build steps\n\nEach volume is created as an empty volume prior to starting the build\nprocess. Upon completion of the build, volumes and their contents are\ndiscarded. Global volume names and paths cannot conflict with the volumes\ndefined a build step.\n\nUsing a global volume in a build with only one step is not valid as\nit is indicative of a build request with an incorrect configuration." }, "logStreamingOption": { "type": "string", "enumDescriptions": ["Service may automatically determine build log streaming behavior.", "Build logs should be streamed to Google Cloud Storage.", "Build logs should not be streamed to Google Cloud Storage; they will be\nwritten when the build is completed."], "enum": ["STREAM_DEFAULT", "STREAM_ON", "STREAM_OFF"], "description": "Option to define build log streaming behavior to Google Cloud\nStorage." }, "env": { "type": "array", "items": { "type": "string" }, "description": "A list of global environment variable definitions that will exist for all\nbuild steps in this build. If a variable is defined in both globally and in\na build step, the variable will use the build step value.\n\nThe elements are of the form \"KEY=VALUE\" for the environment variable \"KEY\"\nbeing given the value \"VALUE\"." }, "workerPool": { "description": "Option to specify a `WorkerPool` for the build. User specifies the pool\nwith the format \"[WORKERPOOL_PROJECT_ID]/[WORKERPOOL_NAME]\".\nThis is an experimental field.", "type": "string" }, "logging": { "type": "string", "enumDescriptions": ["The service determines the logging mode. The default is `LEGACY`. Do not\nrely on the default logging behavior as it may change in the future.", "Stackdriver logging and Cloud Storage logging are enabled.", "Only Cloud Storage logging is enabled."], "enum": ["LOGGING_UNSPECIFIED", "LEGACY", "GCS_ONLY"], "description": "Option to specify the logging mode, which determines where the logs are\nstored." } }, "id": "BuildOptions" }, "StorageSource": { "description": "Location of the source in an archive file in Google Cloud Storage.", "type": "object", "properties": { "bucket": { "type": "string", "description": "Google Cloud Storage bucket containing the source (see\n[Bucket Name\nRequirements](https://cloud.google.com/storage/docs/bucket-naming#requirements))." }, "object": { "description": "Google Cloud Storage object containing the source.\n\nThis object must be a gzipped archive file (`.tar.gz`) containing source to\nbuild.", "type": "string" }, "generation": { "description": "Google Cloud Storage generation for the object. If the generation is\nomitted, the latest generation will be used.", "format": "int64", "type": "string" } }, "id": "StorageSource" }, "ArtifactResult": { "id": "ArtifactResult", "description": "An artifact that was uploaded during a build. This\nis a single record in the artifact manifest JSON file.", "type": "object", "properties": { "location": { "description": "The path of an artifact in a Google Cloud Storage bucket, with the\ngeneration number. For example,\n`gs://mybucket/path/to/output.jar#generation`.", "type": "string" }, "fileHash": { "description": "The file hash of the artifact.", "type": "array", "items": { "$ref": "FileHashes" } } } }, "Artifacts": { "description": "Artifacts produced by a build that should be uploaded upon\nsuccessful completion of all build steps.", "type": "object", "properties": { "images": { "description": "A list of images to be pushed upon the successful completion of all build\nsteps.\n\nThe images will be pushed using the builder service account's credentials.\n\nThe digests of the pushed images will be stored in the Build resource's\nresults field.\n\nIf any of the images fail to be pushed, the build is marked FAILURE.", "type": "array", "items": { "type": "string" } }, "objects": { "$ref": "ArtifactObjects", "description": "A list of objects to be uploaded to Cloud Storage upon successful\ncompletion of all build steps.\n\nFiles in the workspace matching specified paths globs will be uploaded to\nthe specified Cloud Storage location using the builder service account's\ncredentials.\n\nThe location and generation of the uploaded objects will be stored in the\nBuild resource's results field.\n\nIf any objects fail to be pushed, the build is marked FAILURE." } }, "id": "Artifacts" }, "Results": { "id": "Results", "description": "Artifacts created by the build pipeline.", "type": "object", "properties": { "artifactTiming": { "$ref": "TimeSpan", "description": "Time to push all non-container artifacts." }, "buildStepOutputs": { "type": "array", "items": { "format": "byte", "type": "string" }, "description": "List of build step outputs, produced by builder images, in the order\ncorresponding to build step indices.\n\n[Cloud Builders](https://cloud.google.com/cloud-build/docs/cloud-builders)\ncan produce this output by writing to `$BUILDER_OUTPUT/output`.\nOnly the first 4KB of data is stored." }, "images": { "description": "Container images that were built as a part of the build.", "type": "array", "items": { "$ref": "BuiltImage" } }, "numArtifacts": { "description": "Number of artifacts uploaded. Only populated when artifacts are uploaded.", "format": "int64", "type": "string" }, "artifactManifest": { "description": "Path to the artifact manifest. Only populated when artifacts are uploaded.", "type": "string" }, "buildStepImages": { "description": "List of build step digests, in the order corresponding to build step\nindices.", "type": "array", "items": { "type": "string" } } } }, "BuildOperationMetadata": { "id": "BuildOperationMetadata", "description": "Metadata for build operations.", "type": "object", "properties": { "build": { "$ref": "Build", "description": "The build that the operation is tracking." } } }, "ArtifactObjects": { "description": "Files in the workspace to upload to Cloud Storage upon successful\ncompletion of all build steps.", "type": "object", "properties": { "timing": { "$ref": "TimeSpan", "description": "Output only. Stores timing information for pushing all artifact objects." }, "location": { "type": "string", "description": "Cloud Storage bucket and optional object path, in the form\n\"gs://bucket/path/to/somewhere/\". (see [Bucket Name\nRequirements](https://cloud.google.com/storage/docs/bucket-naming#requirements)).\n\nFiles in the workspace matching any path pattern will be uploaded to\nCloud Storage with this location as a prefix." }, "paths": { "description": "Path globs used to match files in the build's workspace.", "type": "array", "items": { "type": "string" } } }, "id": "ArtifactObjects" }, "SourceProvenance": { "type": "object", "properties": { "resolvedRepoSource": { "$ref": "RepoSource", "description": "A copy of the build's `source.repo_source`, if exists, with any\nrevisions resolved." }, "resolvedStorageSource": { "$ref": "StorageSource", "description": "A copy of the build's `source.storage_source`, if exists, with any\ngenerations resolved." }, "fileHashes": { "type": "object", "additionalProperties": { "$ref": "FileHashes" }, "description": "Output only. Hash(es) of the build source, which can be used to verify that\nthe original source integrity was maintained in the build. Note that\n`FileHashes` will only be populated if `BuildOptions` has requested a\n`SourceProvenanceHash`.\n\nThe keys to this map are file paths used as build source and the values\ncontain the hash values for those files.\n\nIf the build source came in a single package such as a gzipped tarfile\n(`.tar.gz`), the `FileHash` will be for the single path to that file." } }, "id": "SourceProvenance", "description": "Provenance of the source. Ways to find the original source, or verify that\nsome source was used for this build." }, "BuiltImage": { "type": "object", "properties": { "pushTiming": { "description": "Output only. Stores timing information for pushing the specified image.", "$ref": "TimeSpan" }, "name": { "type": "string", "description": "Name used to push the container image to Google Container Registry, as\npresented to `docker push`." }, "digest": { "description": "Docker Registry 2.0 digest.", "type": "string" } }, "id": "BuiltImage", "description": "An image built by the pipeline." }, "BuildStep": { "type": "object", "properties": { "status": { "description": "Output only. Status of the build step. At this time, build step status is\nonly updated on build completion; step status is not updated in real-time\nas the build progresses.", "type": "string", "enumDescriptions": ["Status of the build is unknown.", "Build or step is queued; work has not yet begun.", "Build or step is being executed.", "Build or step finished successfully.", "Build or step failed to complete successfully.", "Build or step failed due to an internal cause.", "Build or step took longer than was allowed.", "Build or step was canceled by a user."], "enum": ["STATUS_UNKNOWN", "QUEUED", "WORKING", "SUCCESS", "FAILURE", "INTERNAL_ERROR", "TIMEOUT", "CANCELLED"] }, "timeout": { "description": "Time limit for executing this build step. If not defined, the step has no\ntime limit and will be allowed to continue to run until either it completes\nor the build itself times out.", "format": "google-duration", "type": "string" }, "pullTiming": { "$ref": "TimeSpan", "description": "Output only. Stores timing information for pulling this build step's\nbuilder image only." }, "name": { "description": "Required. The name of the container image that will run this particular\nbuild step.\n\nIf the image is available in the host's Docker daemon's cache, it\nwill be run directly. If not, the host will attempt to pull the image\nfirst, using the builder service account's credentials if necessary.\n\nThe Docker daemon's cache will already have the latest versions of all of\nthe officially supported build steps\n([https://github.com/GoogleCloudPlatform/cloud-builders](https://github.com/GoogleCloudPlatform/cloud-builders)).\nThe Docker daemon will also have cached many of the layers for some popular\nimages, like \"ubuntu\", \"debian\", but they will be refreshed at the time you\nattempt to use them.\n\nIf you built an image in a previous build step, it will be stored in the\nhost's Docker daemon's cache and is available to use as the name for a\nlater build step.", "type": "string" }, "secretEnv": { "description": "A list of environment variables which are encrypted using a Cloud Key\nManagement Service crypto key. These values must be specified in the\nbuild's `Secret`.", "type": "array", "items": { "type": "string" } }, "id": { "type": "string", "description": "Unique identifier for this build step, used in `wait_for` to\nreference this build step as a dependency." }, "dir": { "description": "Working directory to use when running this step's container.\n\nIf this value is a relative path, it is relative to the build's working\ndirectory. If this value is absolute, it may be outside the build's working\ndirectory, in which case the contents of the path may not be persisted\nacross build step executions, unless a `volume` for that path is specified.\n\nIf the build specifies a `RepoSource` with `dir` and a step with a `dir`,\nwhich specifies an absolute path, the `RepoSource` `dir` is ignored for\nthe step's execution.", "type": "string" }, "timing": { "$ref": "TimeSpan", "description": "Output only. Stores timing information for executing this build step." }, "waitFor": { "type": "array", "items": { "type": "string" }, "description": "The ID(s) of the step(s) that this build step depends on.\nThis build step will not start until all the build steps in `wait_for`\nhave completed successfully. If `wait_for` is empty, this build step will\nstart when all previous build steps in the `Build.Steps` list have\ncompleted successfully." }, "env": { "description": "A list of environment variable definitions to be used when running a step.\n\nThe elements are of the form \"KEY=VALUE\" for the environment variable \"KEY\"\nbeing given the value \"VALUE\".", "type": "array", "items": { "type": "string" } }, "entrypoint": { "description": "Entrypoint to be used instead of the build step image's default entrypoint.\nIf unset, the image's default entrypoint is used.", "type": "string" }, "volumes": { "description": "List of volumes to mount into the build step.\n\nEach volume is created as an empty volume prior to execution of the\nbuild step. Upon completion of the build, volumes and their contents are\ndiscarded.\n\nUsing a named volume in only one step is not valid as it is indicative\nof a build request with an incorrect configuration.", "type": "array", "items": { "$ref": "Volume" } }, "args": { "type": "array", "items": { "type": "string" }, "description": "A list of arguments that will be presented to the step when it is started.\n\nIf the image used to run the step's container has an entrypoint, the `args`\nare used as arguments to that entrypoint. If the image does not define\nan entrypoint, the first element in args is used as the entrypoint,\nand the remainder will be used as arguments." } }, "id": "BuildStep", "description": "A step in the build pipeline." }, "RepoSource": { "type": "object", "properties": { "tagName": { "description": "Name of the tag to build.", "type": "string" }, "projectId": { "description": "ID of the project that owns the Cloud Source Repository. If omitted, the\nproject ID requesting the build is assumed.", "type": "string" }, "repoName": { "type": "string", "description": "Name of the Cloud Source Repository. If omitted, the name \"default\" is\nassumed." }, "commitSha": { "type": "string", "description": "Explicit commit SHA to build." }, "dir": { "type": "string", "description": "Directory, relative to the source root, in which to run the build.\n\nThis must be a relative path. If a step's `dir` is specified and is an\nabsolute path, this value is ignored for that step's execution." }, "branchName": { "description": "Name of the branch to build.", "type": "string" } }, "id": "RepoSource", "description": "Location of the source in a Google Cloud Source Repository." }, "Hash": { "description": "Container message for hash values.", "type": "object", "properties": { "value": { "type": "string", "description": "The hash value.", "format": "byte" }, "type": { "type": "string", "enumDescriptions": ["No hash requested.", "Use a sha256 hash.", "Use a md5 hash."], "enum": ["NONE", "SHA256", "MD5"], "description": "The type of hash that was performed." } }, "id": "Hash" }, "FileHashes": { "description": "Container message for hashes of byte content of files, used in\nSourceProvenance messages to verify integrity of source input to the build.", "type": "object", "properties": { "fileHash": { "description": "Collection of file hashes.", "type": "array", "items": { "$ref": "Hash" } } }, "id": "FileHashes" }, "WorkerConfig": { "type": "object", "properties": { "machineType": { "description": "Machine Type of the worker, such as n1-standard-1.\nSee https://cloud.google.com/compute/docs/machine-types.\nIf left blank, Cloud Build will use a standard unspecified machine to\ncreate the worker pool.\n`machine_type` is overridden if you specify a different machine type in\n`build_options`. In this case, the VM specified in the `build_options`\nwill be created on demand at build time. For more information see\nhttps://cloud.google.com/cloud-build/docs/speeding-up-builds#using_custom_virtual_machine_sizes", "type": "string" }, "network": { "$ref": "Network", "description": "The network definition used to create the worker.\nIf this section is left empty, the workers will be created in\nWorkerPool.project_id on the default network." }, "tag": { "description": "The tag applied to the worker, and the same tag used by the firewall rule.\nIt is used to identify the Cloud Build workers among other VMs.\nThe default value for tag is `worker`.", "type": "string" }, "diskSizeGb": { "description": "Size of the disk attached to the worker, in GB.\nSee https://cloud.google.com/compute/docs/disks/\nIf `0` is specified, Cloud Build will use a standard disk size.\n`disk_size` is overridden if you specify a different disk size in\n`build_options`. In this case, a VM with a disk size specified in the\n`build_options` will be created on demand at build time. For more\ninformation see\nhttps://cloud.google.com/cloud-build/docs/api/reference/rest/v1/projects.builds#buildoptions", "format": "int64", "type": "string" } }, "id": "WorkerConfig", "description": "WorkerConfig defines the configuration to be used for a creating workers in\nthe pool." }, "Network": { "type": "object", "properties": { "projectId": { "description": "Project id containing the defined network and subnetwork. For a peered VPC,\nthis will be the same as the project_id in which the workers are created.\nFor a shared VPC, this will be the project sharing the network with the\nproject_id project in which workers will be created. For custom workers\nwith no VPC, this will be the same as project_id.", "type": "string" }, "subnetwork": { "description": "Subnetwork on which the workers are created.\n\"default\" subnetwork is used if empty.", "type": "string" }, "network": { "description": "Network on which the workers are created.\n\"default\" network is used if empty.", "type": "string" } }, "id": "Network", "description": "Network describes the GCP network used to create workers in." }, "Secret": { "description": "Pairs a set of secret environment variables containing encrypted\nvalues with the Cloud KMS key to use to decrypt the value.", "type": "object", "properties": { "kmsKeyName": { "type": "string", "description": "Cloud KMS key name to use to decrypt these envs." }, "secretEnv": { "additionalProperties": { "format": "byte", "type": "string" }, "description": "Map of environment variable name to its encrypted value.\n\nSecret environment variables must be unique across all of a build's\nsecrets, and must be used by at least one build step. Values can be at most\n64 KB in size. There can be at most 100 secret values across all of a\nbuild's secrets.", "type": "object" } }, "id": "Secret" }, "ListWorkerPoolsResponse": { "id": "ListWorkerPoolsResponse", "description": "Response containing existing `WorkerPools`.", "type": "object", "properties": { "workerPools": { "description": "`WorkerPools` for the project.", "type": "array", "items": { "$ref": "WorkerPool" } } } } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "Cloud Build", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://cloudbuild.googleapis.com/", "ownerDomain": "google.com", "name": "cloudbuild", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Cloud Build API", "ownerName": "Google", "resources": { "projects": { "resources": { "workerPools": { "methods": { "get": { "httpMethod": "GET", "response": { "$ref": "WorkerPool" }, "parameterOrder": ["name"], "parameters": { "name": { "location": "path", "description": "The field will contain name of the resource requested, for example:\n\"projects/project-1/workerPools/workerpool-name\"", "required": true, "type": "string", "pattern": "^projects/[^/]+/workerPools/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha1/projects/{projectsId}/workerPools/{workerPoolsId}", "id": "cloudbuild.projects.workerPools.get", "path": "v1alpha1/{+name}", "description": "Returns information about a `WorkerPool`.\n\nThis API is experimental." }, "patch": { "description": "Update a `WorkerPool`.\n\nThis API is experimental.", "request": { "$ref": "WorkerPool" }, "response": { "$ref": "WorkerPool" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "name": { "location": "path", "description": "The field will contain name of the resource requested, for example:\n\"projects/project-1/workerPools/workerpool-name\"", "required": true, "type": "string", "pattern": "^projects/[^/]+/workerPools/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha1/projects/{projectsId}/workerPools/{workerPoolsId}", "path": "v1alpha1/{+name}", "id": "cloudbuild.projects.workerPools.patch" }, "list": { "description": "List project's `WorkerPool`s.\n\nThis API is experimental.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListWorkerPoolsResponse" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "ID of the parent project.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "flatPath": "v1alpha1/projects/{projectsId}/workerPools", "id": "cloudbuild.projects.workerPools.list", "path": "v1alpha1/{+parent}/workerPools" }, "create": { "response": { "$ref": "WorkerPool" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "ID of the parent project." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha1/projects/{projectsId}/workerPools", "path": "v1alpha1/{+parent}/workerPools", "id": "cloudbuild.projects.workerPools.create", "description": "Creates a `WorkerPool` to run the builds, and returns the new worker pool.\n\nThis API is experimental.", "request": { "$ref": "WorkerPool" } }, "delete": { "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "parameters": { "name": { "description": "The field will contain name of the resource requested, for example:\n\"projects/project-1/workerPools/workerpool-name\"", "required": true, "type": "string", "pattern": "^projects/[^/]+/workerPools/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha1/projects/{projectsId}/workerPools/{workerPoolsId}", "id": "cloudbuild.projects.workerPools.delete", "path": "v1alpha1/{+name}", "description": "Deletes a `WorkerPool` by its project ID and WorkerPool name.\n\nThis API is experimental." } } } } } }, "parameters": { "alt": { "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query" }, "key": { "type": "string", "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "type": "string", "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\")." }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true", "location": "query" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "$.xgafv": { "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"] }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" } }, "version": "v1alpha1", "baseUrl": "https://cloudbuild.googleapis.com/", "kind": "discovery#restDescription", "description": "Creates and manages builds on Google Cloud Platform.", "servicePath": "", "basePath": "" };
//# sourceMappingURL=cloudbuild-v1alpha1.js.map