"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Dialogflow API", "ownerName": "Google", "resources": { "projects": { "methods": { "agent": { "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleCloudDialogflowV2Agent" }, "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project of this agent.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string" }, "updateMask": { "type": "string", "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent", "id": "dialogflow.projects.agent", "path": "v2/{+parent}/agent", "description": "Creates/updates the specified agent.", "request": { "$ref": "GoogleCloudDialogflowV2Agent" } }, "getAgent": { "response": { "$ref": "GoogleCloudDialogflowV2Agent" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to fetch is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent", "path": "v2/{+parent}/agent", "id": "dialogflow.projects.getAgent", "description": "Retrieves the specified agent." }, "deleteAgent": { "description": "Deletes the specified agent.", "httpMethod": "DELETE", "parameterOrder": ["parent"], "response": { "$ref": "GoogleProtobufEmpty" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to delete is associated with.\nFormat: `projects/<Project ID>`." } }, "flatPath": "v2/projects/{projectsId}/agent", "id": "dialogflow.projects.deleteAgent", "path": "v2/{+parent}/agent" } }, "resources": { "operations": { "methods": { "get": { "description": "Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "The name of the operation resource.", "required": true, "type": "string", "pattern": "^projects/[^/]+/operations/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/operations/{operationsId}", "path": "v2/{+name}", "id": "dialogflow.projects.operations.get" } } }, "agent": { "methods": { "train": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The project that the agent to train is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent:train", "path": "v2/{+parent}/agent:train", "id": "dialogflow.projects.agent.train", "description": "Trains the specified agent.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2TrainAgentRequest" } }, "export": { "request": { "$ref": "GoogleCloudDialogflowV2ExportAgentRequest" }, "description": "Exports the specified agent to a ZIP file.\n\nOperation <response: ExportAgentResponse>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to export is associated with.\nFormat: `projects/<Project ID>`." } }, "flatPath": "v2/projects/{projectsId}/agent:export", "path": "v2/{+parent}/agent:export", "id": "dialogflow.projects.agent.export" }, "restore": { "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project that the agent to restore is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent:restore", "id": "dialogflow.projects.agent.restore", "path": "v2/{+parent}/agent:restore", "request": { "$ref": "GoogleCloudDialogflowV2RestoreAgentRequest" }, "description": "Restores the specified agent from a ZIP file.\n\nReplaces the current agent version with a new one. All the intents and\nentity types in the older version are deleted.\n\nOperation <response: google.protobuf.Empty>", "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" } }, "import": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "Required. The project that the agent to import is associated with.\nFormat: `projects/<Project ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent:import", "path": "v2/{+parent}/agent:import", "id": "dialogflow.projects.agent.import", "description": "Imports the specified agent from a ZIP file.\n\nUploads new intents and entity types without deleting the existing ones.\nIntents and entity types with the same name are replaced with the new\nversions from ImportAgentRequest.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2ImportAgentRequest" } }, "search": { "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required. The project to list agents from.\nFormat: `projects/<Project ID or '-'>`.", "required": true, "type": "string" }, "pageToken": { "type": "string", "location": "query", "description": "Optional. The next_page_token value returned from a previous list request." }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent:search", "id": "dialogflow.projects.agent.search", "path": "v2/{+parent}/agent:search", "description": "Returns the list of agents.\n\nSince there is at most one conversational agent per project, this method is\nuseful primarily for listing all agents across projects the caller has\naccess to. One can achieve that with a wildcard project collection id \"-\".\nRefer to [List\nSub-Collections](https://cloud.google.com/apis/design/design_patterns#list_sub-collections).", "httpMethod": "GET", "response": { "$ref": "GoogleCloudDialogflowV2SearchAgentsResponse" }, "parameterOrder": ["parent"] } }, "resources": { "entityTypes": { "methods": { "patch": { "path": "v2/{+name}", "id": "dialogflow.projects.agent.entityTypes.patch", "request": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "description": "Updates the specified entity type.", "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path", "description": "The unique identifier of the entity type.\nRequired for EntityTypes.UpdateEntityType and\nEntityTypes.BatchUpdateEntityTypes methods.\nFormat: `projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string" }, "languageCode": { "location": "query", "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string", "location": "query" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}" }, "get": { "description": "Retrieves the specified entity type.", "httpMethod": "GET", "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["name"], "parameters": { "languageCode": { "location": "query", "description": "Optional. The language to retrieve entity synonyms for. If not specified,\nthe agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "name": { "description": "Required. The name of the entity type.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.entityTypes.get", "path": "v2/{+name}" }, "batchUpdate": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "pattern": "^projects/[^/]+/agent$", "location": "path", "description": "Required. The name of the agent to update or create entity types in.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes:batchUpdate", "path": "v2/{+parent}/entityTypes:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.batchUpdate", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest" }, "description": "Updates/Creates multiple entity types in the specified agent.\n\nOperation <response: BatchUpdateEntityTypesResponse>" }, "delete": { "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "GoogleProtobufEmpty" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "Required. The name of the entity type to delete.\nFormat: `projects/<Project ID>/agent/entityTypes/<EntityType ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.entityTypes.delete", "path": "v2/{+name}", "description": "Deletes the specified entity type." }, "list": { "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The agent to list all entity types from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" }, "languageCode": { "location": "query", "description": "Optional. The language to list entity synonyms for. If not specified,\nthe agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.list", "description": "Returns the list of all entity types in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2ListEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET" }, "batchDelete": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes:batchDelete", "path": "v2/{+parent}/entityTypes:batchDelete", "id": "dialogflow.projects.agent.entityTypes.batchDelete", "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest" }, "description": "Deletes entity types in the specified agent.\n\nOperation <response: google.protobuf.Empty>" }, "create": { "response": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The agent to create a entity type for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path" }, "languageCode": { "location": "query", "description": "Optional. The language of entity synonyms defined in `entity_type`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.entityTypes.create", "request": { "$ref": "GoogleCloudDialogflowV2EntityType" }, "description": "Creates an entity type in the specified agent." } }, "resources": { "entities": { "methods": { "batchUpdate": { "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "location": "path", "description": "Required. The name of the entity type to update or create entities in.\nFormat: `projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchUpdate", "id": "dialogflow.projects.agent.entityTypes.entities.batchUpdate", "path": "v2/{+parent}/entities:batchUpdate", "description": "Updates or creates multiple entities in the specified entity type. This\nmethod does not affect entities in the entity type that aren't explicitly\nspecified in the request.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest" } }, "batchDelete": { "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest" }, "description": "Deletes entities in the specified entity type.\n\nOperation <response: google.protobuf.Empty>", "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "description": "Required. The name of the entity type to delete entries for. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path" } }, "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchDelete", "path": "v2/{+parent}/entities:batchDelete", "id": "dialogflow.projects.agent.entityTypes.entities.batchDelete" }, "batchCreate": { "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "pattern": "^projects/[^/]+/agent/entityTypes/[^/]+$", "location": "path", "description": "Required. The name of the entity type to create entities in. Format:\n`projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/entityTypes/{entityTypesId}/entities:batchCreate", "id": "dialogflow.projects.agent.entityTypes.entities.batchCreate", "path": "v2/{+parent}/entities:batchCreate", "description": "Creates multiple new entities in the specified entity type.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2BatchCreateEntitiesRequest" } } } } } }, "intents": { "methods": { "patch": { "path": "v2/{+name}", "id": "dialogflow.projects.agent.intents.patch", "request": { "$ref": "GoogleCloudDialogflowV2Intent" }, "description": "Updates the specified intent.", "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "location": "path", "description": "The unique identifier of this intent.\nRequired for Intents.UpdateIntent and Intents.BatchUpdateIntents\nmethods.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$" }, "intentView": { "description": "Optional. The resource view to apply to the returned intent.", "type": "string", "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"] }, "languageCode": { "type": "string", "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used." }, "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}" }, "get": { "httpMethod": "GET", "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["name"], "parameters": { "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "languageCode": { "description": "Optional. The language to retrieve training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string", "location": "query" }, "name": { "description": "Required. The name of the intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}", "id": "dialogflow.projects.agent.intents.get", "path": "v2/{+name}", "description": "Retrieves the specified intent." }, "batchUpdate": { "response": { "$ref": "GoogleLongrunningOperation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$", "location": "path", "description": "Required. The name of the agent to update or create intents in.\nFormat: `projects/<Project ID>/agent`." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/intents:batchUpdate", "path": "v2/{+parent}/intents:batchUpdate", "id": "dialogflow.projects.agent.intents.batchUpdate", "description": "Updates/Creates multiple intents in the specified agent.\n\nOperation <response: BatchUpdateIntentsResponse>", "request": { "$ref": "GoogleCloudDialogflowV2BatchUpdateIntentsRequest" } }, "delete": { "flatPath": "v2/projects/{projectsId}/agent/intents/{intentsId}", "id": "dialogflow.projects.agent.intents.delete", "path": "v2/{+name}", "description": "Deletes the specified intent and its direct or indirect followup intents.", "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "GoogleProtobufEmpty" }, "parameters": { "name": { "pattern": "^projects/[^/]+/agent/intents/[^/]+$", "location": "path", "description": "Required. The name of the intent to delete. If this intent has direct or\nindirect followup intents, we also delete them.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] }, "list": { "parameters": { "pageToken": { "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string", "location": "query" }, "pageSize": { "type": "integer", "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32" }, "intentView": { "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "parent": { "location": "path", "description": "Required. The agent to list all intents from.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" }, "languageCode": { "type": "string", "location": "query", "description": "Optional. The language to list training phrases, parameters and rich\nmessages for. If not specified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/intents", "path": "v2/{+parent}/intents", "id": "dialogflow.projects.agent.intents.list", "description": "Returns the list of all intents in the specified agent.", "response": { "$ref": "GoogleCloudDialogflowV2ListIntentsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET" }, "batchDelete": { "id": "dialogflow.projects.agent.intents.batchDelete", "path": "v2/{+parent}/intents:batchDelete", "description": "Deletes intents in the specified agent.\n\nOperation <response: google.protobuf.Empty>", "request": { "$ref": "GoogleCloudDialogflowV2BatchDeleteIntentsRequest" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "GoogleLongrunningOperation" }, "parameters": { "parent": { "pattern": "^projects/[^/]+/agent$", "location": "path", "description": "Required. The name of the agent to delete all entities types for. Format:\n`projects/<Project ID>/agent`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/intents:batchDelete" }, "create": { "description": "Creates an intent in the specified agent.", "request": { "$ref": "GoogleCloudDialogflowV2Intent" }, "response": { "$ref": "GoogleCloudDialogflowV2Intent" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "location": "path", "description": "Required. The agent to create a intent for.\nFormat: `projects/<Project ID>/agent`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent$" }, "languageCode": { "location": "query", "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intent`. If not specified, the agent's default language is\nused. [Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "intentView": { "type": "string", "location": "query", "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/intents", "path": "v2/{+parent}/intents", "id": "dialogflow.projects.agent.intents.create" } } }, "sessions": { "methods": { "deleteContexts": { "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["parent"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The name of the session to delete all contexts from. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`." } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.deleteContexts", "description": "Deletes all active contexts in the specified session." }, "detectIntent": { "id": "dialogflow.projects.agent.sessions.detectIntent", "path": "v2/{+session}:detectIntent", "request": { "$ref": "GoogleCloudDialogflowV2DetectIntentRequest" }, "description": "Processes a natural language query and returns structured, actionable data\nas a result. This method is not idempotent, because it may cause contexts\nand session entity types to be updated, which in turn might affect\nresults of future queries.", "httpMethod": "POST", "parameterOrder": ["session"], "response": { "$ref": "GoogleCloudDialogflowV2DetectIntentResponse" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "session": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The name of the session this query is sent to. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>`. It's up to the API\ncaller to choose an appropriate session ID. It can be a random number or\nsome type of user identifier (preferably hashed). The length of the session\nID must not exceed 36 bytes." } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}:detectIntent" } }, "resources": { "contexts": { "methods": { "list": { "response": { "$ref": "GoogleCloudDialogflowV2ListContextsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "location": "query", "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer" }, "parent": { "location": "path", "description": "Required. The session to list all contexts from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.list", "description": "Returns the list of all contexts in the specified session." }, "get": { "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.get", "description": "Retrieves the specified context.", "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path", "description": "Required. The name of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}" }, "patch": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.patch", "request": { "$ref": "GoogleCloudDialogflowV2Context" }, "description": "Updates the specified context.", "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "location": "path", "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in [a-zA-Z0-9_-%] and may be at most 250 bytes long.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$" } } }, "create": { "response": { "$ref": "GoogleCloudDialogflowV2Context" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The session to create a context for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts", "path": "v2/{+parent}/contexts", "id": "dialogflow.projects.agent.sessions.contexts.create", "description": "Creates a context.\n\nIf the specified context already exists, overrides the context.", "request": { "$ref": "GoogleCloudDialogflowV2Context" } }, "delete": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/contexts/{contextsId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.contexts.delete", "description": "Deletes the specified context.", "response": { "$ref": "GoogleProtobufEmpty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "name": { "description": "Required. The name of the context to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/contexts/[^/]+$", "location": "path" } } } } }, "entityTypes": { "methods": { "delete": { "description": "Deletes the specified session entity type.", "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "GoogleProtobufEmpty" }, "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$", "location": "path", "description": "Required. The name of the entity type to delete. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.sessions.entityTypes.delete", "path": "v2/{+name}" }, "list": { "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The session to list all session entity types from.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`." }, "pageToken": { "location": "query", "description": "Optional. The next_page_token value returned from a previous list request.", "type": "string" }, "pageSize": { "description": "Optional. The maximum number of items to return in a single page. By\ndefault 100 and at most 1000.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.sessions.entityTypes.list", "description": "Returns the list of all session entity types in the specified session.", "response": { "$ref": "GoogleCloudDialogflowV2ListSessionEntityTypesResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET" }, "get": { "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "location": "path", "description": "Required. The name of the session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "path": "v2/{+name}", "id": "dialogflow.projects.agent.sessions.entityTypes.get", "description": "Retrieves the specified session entity type." }, "patch": { "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameters": { "updateMask": { "location": "query", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/agent/sessions/[^/]+/entityTypes/[^/]+$", "location": "path", "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.\n\n`<Entity Type Display Name>` must be the display name of an existing entity\ntype in the same agent that will be overridden or supplemented." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"], "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes/{entityTypesId}", "id": "dialogflow.projects.agent.sessions.entityTypes.patch", "path": "v2/{+name}", "description": "Updates the specified session entity type.", "request": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" } }, "create": { "flatPath": "v2/projects/{projectsId}/agent/sessions/{sessionsId}/entityTypes", "path": "v2/{+parent}/entityTypes", "id": "dialogflow.projects.agent.sessions.entityTypes.create", "description": "Creates a session entity type.\n\nIf the specified session entity type already exists, overrides the session\nentity type.", "request": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "response": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "pattern": "^projects/[^/]+/agent/sessions/[^/]+$", "location": "path", "description": "Required. The session to create a session entity type for.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/dialogflow"] } } } } } } } } } }, "parameters": { "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "fields": { "type": "string", "location": "query", "description": "Selector specifying which fields to include in a partial response." }, "$.xgafv": { "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"] }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "callback": { "type": "string", "location": "query", "description": "JSONP" }, "alt": { "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"] } }, "version": "v2", "baseUrl": "https://dialogflow.googleapis.com/", "kind": "discovery#restDescription", "description": "Builds conversational interfaces (for example, chatbots, and voice-powered apps and devices).", "servicePath": "", "basePath": "", "revision": "20190616", "documentationLink": "https://cloud.google.com/dialogflow/", "id": "dialogflow:v2", "discoveryVersion": "v1", "version_module": true, "schemas": { "GoogleCloudDialogflowV2SynthesizeSpeechConfig": { "type": "object", "properties": { "effectsProfileId": { "description": "Optional. An identifier which selects 'audio effects' profiles that are\napplied on (post synthesized) text to speech. Effects are applied on top of\neach other in the order they are given.", "type": "array", "items": { "type": "string" } }, "volumeGainDb": { "description": "Optional. Volume gain (in dB) of the normal native volume supported by the\nspecific voice, in the range [-96.0, 16.0]. If unset, or set to a value of\n0.0 (dB), will play at normal native signal amplitude. A value of -6.0 (dB)\nwill play at approximately half the amplitude of the normal native signal\namplitude. A value of +6.0 (dB) will play at approximately twice the\namplitude of the normal native signal amplitude. We strongly recommend not\nto exceed +10 (dB) as there's usually no effective increase in loudness for\nany value greater than that.", "format": "double", "type": "number" }, "pitch": { "description": "Optional. Speaking pitch, in the range [-20.0, 20.0]. 20 means increase 20\nsemitones from the original pitch. -20 means decrease 20 semitones from the\noriginal pitch.", "format": "double", "type": "number" }, "voice": { "$ref": "GoogleCloudDialogflowV2VoiceSelectionParams", "description": "Optional. The desired voice of the synthesized audio." }, "speakingRate": { "type": "number", "description": "Optional. Speaking rate/speed, in the range [0.25, 4.0]. 1.0 is the normal\nnative speed supported by the specific voice. 2.0 is twice as fast, and\n0.5 is half as fast. If unset(0.0), defaults to the native 1.0 speed. Any\nother values < 0.25 or > 4.0 will return an error.", "format": "double" } }, "id": "GoogleCloudDialogflowV2SynthesizeSpeechConfig", "description": "Configuration of how speech should be synthesized." }, "GoogleCloudDialogflowV2OutputAudioConfig": { "description": "Instructs the speech synthesizer on how to generate the output audio content.", "type": "object", "properties": { "sampleRateHertz": { "description": "Optional. The synthesis sample rate (in hertz) for this audio. If not\nprovided, then the synthesizer will use the default sample rate based on\nthe audio encoding. If this is different from the voice's natural sample\nrate, then the synthesizer will honor this request by converting to the\ndesired sample rate (which might result in worse audio quality).", "format": "int32", "type": "integer" }, "audioEncoding": { "enumDescriptions": ["Not specified.", "Uncompressed 16-bit signed little-endian samples (Linear PCM).\nAudio content returned as LINEAR16 also contains a WAV header.", "MP3 audio.", "Opus encoded audio wrapped in an ogg container. The result will be a\nfile which can be played natively on Android, and in browsers (at least\nChrome and Firefox). The quality of the encoding is considerably higher\nthan MP3 while using approximately the same bitrate."], "enum": ["OUTPUT_AUDIO_ENCODING_UNSPECIFIED", "OUTPUT_AUDIO_ENCODING_LINEAR_16", "OUTPUT_AUDIO_ENCODING_MP3", "OUTPUT_AUDIO_ENCODING_OGG_OPUS"], "description": "Required. Audio encoding of the synthesized audio content.", "type": "string" }, "synthesizeSpeechConfig": { "$ref": "GoogleCloudDialogflowV2SynthesizeSpeechConfig", "description": "Optional. Configuration of how speech should be synthesized." } }, "id": "GoogleCloudDialogflowV2OutputAudioConfig" }, "GoogleCloudDialogflowV2IntentMessageCard": { "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" }, "imageUri": { "description": "Optional. The public URI to an image file for the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCard", "description": "The card response message." }, "GoogleCloudDialogflowV2beta1IntentMessageListSelect": { "description": "The card for presenting a list of options to select from.", "type": "object", "properties": { "items": { "description": "Required. List items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem" } }, "title": { "type": "string", "description": "Optional. The overall title of the list." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelect" }, "GoogleCloudDialogflowV2IntentBatch": { "description": "This message is a wrapper around a collection of intents.", "type": "object", "properties": { "intents": { "description": "A collection of intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2IntentBatch" }, "GoogleCloudDialogflowV2DetectIntentRequest": { "description": "The request to detect user's intent.", "type": "object", "properties": { "outputAudioConfig": { "$ref": "GoogleCloudDialogflowV2OutputAudioConfig", "description": "Optional. Instructs the speech synthesizer how to generate the output\naudio. If this field is not set and agent-level speech synthesizer is not\nconfigured, no output audio is generated." }, "inputAudio": { "description": "Optional. The natural language speech audio to be processed. This field\nshould be populated iff `query_input` is set to an input audio config.\nA single request can contain up to 1 minute of speech audio data.", "format": "byte", "type": "string" }, "queryInput": { "$ref": "GoogleCloudDialogflowV2QueryInput", "description": "Required. The input specification. It can be set to:\n\n1.  an audio config\n    which instructs the speech recognizer how to process the speech audio,\n\n2.  a conversational query in the form of text, or\n\n3.  an event that specifies which intent to trigger." }, "queryParams": { "description": "Optional. The parameters of this query.", "$ref": "GoogleCloudDialogflowV2QueryParameters" } }, "id": "GoogleCloudDialogflowV2DetectIntentRequest" }, "GoogleCloudDialogflowV2IntentMessageBasicCardButton": { "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButton", "description": "The button object that appears at the bottom of a card.", "type": "object", "properties": { "title": { "description": "Required. The title of the button.", "type": "string" }, "openUriAction": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction", "description": "Required. Action to take when a user taps on the button." } } }, "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse": { "id": "GoogleCloudDialogflowV2beta1BatchUpdateIntentsResponse", "description": "The response message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Intent" } } } }, "GoogleCloudDialogflowV2beta1Context": { "description": "Represents a context.", "type": "object", "properties": { "lifespanCount": { "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 20 minutes if there\nare no matching queries.", "format": "int32", "type": "integer" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`,\nor `projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in a-zA-Z0-9_-% and may be at most 250 bytes long.\n\nIf `Environment ID` is not specified, we assume default 'draft'\nenvironment. If `User ID` is not specified, we assume default '-' user.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. The collection of parameters associated with this context.\nRefer to [this\ndoc](https://cloud.google.com/dialogflow/docs/intents-actions-parameters)\nfor syntax.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1Context" }, "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo": { "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object", "properties": { "key": { "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given.", "type": "string" }, "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo" }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses": { "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object", "properties": { "simpleResponses": { "description": "Required. The list of simple responses.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses" }, "GoogleCloudDialogflowV2VoiceSelectionParams": { "description": "Description of which voice to use for speech synthesis.", "type": "object", "properties": { "name": { "description": "Optional. The name of the voice. If not set, the service will choose a\nvoice based on the other parameters such as language_code and gender.", "type": "string" }, "ssmlGender": { "type": "string", "enumDescriptions": ["An unspecified gender, which means that the client doesn't care which\ngender the selected voice will have.", "A male voice.", "A female voice.", "A gender-neutral voice."], "enum": ["SSML_VOICE_GENDER_UNSPECIFIED", "SSML_VOICE_GENDER_MALE", "SSML_VOICE_GENDER_FEMALE", "SSML_VOICE_GENDER_NEUTRAL"], "description": "Optional. The preferred gender of the voice. If not set, the service will\nchoose a voice based on the other parameters such as language_code and\nname. Note that this is only a preference, not requirement. If a\nvoice of the appropriate gender is not available, the synthesizer should\nsubstitute a voice with a different gender rather than failing the request." } }, "id": "GoogleCloudDialogflowV2VoiceSelectionParams" }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect": { "description": "The card for presenting a carousel of options to select from.", "type": "object", "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect" }, "GoogleCloudDialogflowV2Sentiment": { "id": "GoogleCloudDialogflowV2Sentiment", "description": "The sentiment, such as positive/negative feeling or association, for a unit\nof analysis, such as the query text.", "type": "object", "properties": { "score": { "type": "number", "description": "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive\nsentiment).", "format": "float" }, "magnitude": { "description": "A non-negative number in the [0, +inf) range, which represents the absolute\nmagnitude of sentiment, regardless of score (positive or negative).", "format": "float", "type": "number" } } }, "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest": { "type": "object", "properties": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "entityValues": { "description": "Required. The canonical `values` of the entities to delete. Note that\nthese are not fully-qualified names, i.e. they don't start with\n`projects/<Project ID>`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2BatchDeleteEntitiesRequest", "description": "The request message for EntityTypes.BatchDeleteEntities." }, "GoogleCloudDialogflowV2SessionEntityType": { "type": "object", "properties": { "name": { "type": "string", "description": "Required. The unique identifier of this session entity type. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type\nDisplay Name>`.\n\n`<Entity Type Display Name>` must be the display name of an existing entity\ntype in the same agent that will be overridden or supplemented." }, "entityOverrideMode": { "description": "Required. Indicates whether the additional data should override or\nsupplement the developer entity type definition.", "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "The collection of session entities overrides the collection of entities\nin the corresponding developer entity type.", "The collection of session entities extends the collection of entities in\nthe corresponding developer entity type.\n\nNote: Even in this override mode calls to `ListSessionEntityTypes`,\n`GetSessionEntityType`, `CreateSessionEntityType` and\n`UpdateSessionEntityType` only return the additional entities added in\nthis session entity type. If you want to get the supplemented list,\nplease call EntityTypes.GetEntityType on the developer entity type\nand merge."], "enum": ["ENTITY_OVERRIDE_MODE_UNSPECIFIED", "ENTITY_OVERRIDE_MODE_OVERRIDE", "ENTITY_OVERRIDE_MODE_SUPPLEMENT"] }, "entities": { "description": "Required. The collection of entities associated with this session entity\ntype.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } } }, "id": "GoogleCloudDialogflowV2SessionEntityType", "description": "Represents a session entity type.\n\nExtends or replaces a developer entity type at the user session level (we\nrefer to the entity types defined at the agent level as \"developer entity\ntypes\").\n\nNote: session entity types apply to all queries, regardless of the language." }, "GoogleCloudDialogflowV2SentimentAnalysisRequestConfig": { "id": "GoogleCloudDialogflowV2SentimentAnalysisRequestConfig", "description": "Configures the types of sentiment analysis to perform.", "type": "object", "properties": { "analyzeQueryTextSentiment": { "type": "boolean", "description": "Optional. Instructs the service to perform sentiment analysis on\n`query_text`. If not provided, sentiment analysis is not performed on\n`query_text`." } } }, "GoogleCloudDialogflowV2beta1IntentMessageCard": { "description": "The card response message.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" }, "imageUri": { "description": "Optional. The public URI to an image file for the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCard" }, "GoogleCloudDialogflowV2EventInput": { "type": "object", "properties": { "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "description": "Optional. The collection of parameters associated with the event.", "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" } }, "languageCode": { "type": "string", "description": "Required. The language of this query. See [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes. Note that queries in\nthe same session do not necessarily need to specify the same language." } }, "id": "GoogleCloudDialogflowV2EventInput", "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: \"welcome_event\",\nparameters: { name: \"Sam\" } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`\"Hello #welcome_event.name! What can I do for you today?\"`." }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestion": { "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion", "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation.", "type": "object", "properties": { "title": { "type": "string", "description": "Required. The text shown the in the suggestion chip." } } }, "GoogleCloudDialogflowV2IntentMessageSuggestions": { "description": "The collection of suggestions.", "type": "object", "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2IntentMessageSuggestions" }, "GoogleCloudDialogflowV2ListContextsResponse": { "type": "object", "properties": { "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list." }, "contexts": { "description": "The list of contexts. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } } }, "id": "GoogleCloudDialogflowV2ListContextsResponse", "description": "The response message for Contexts.ListContexts." }, "GoogleCloudDialogflowV2QueryInput": { "type": "object", "properties": { "event": { "$ref": "GoogleCloudDialogflowV2EventInput", "description": "The event to be processed." }, "text": { "description": "The natural language text to be processed.", "$ref": "GoogleCloudDialogflowV2TextInput" }, "audioConfig": { "$ref": "GoogleCloudDialogflowV2InputAudioConfig", "description": "Instructs the speech recognizer how to process the speech audio." } }, "id": "GoogleCloudDialogflowV2QueryInput", "description": "Represents the query input. It can contain either:\n\n1.  An audio config which\n    instructs the speech recognizer how to process the speech audio.\n\n2.  A conversational query in the form of text,.\n\n3.  An event that specifies which intent to trigger." }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrase": { "type": "object", "properties": { "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "description": "Optional. Indicates how many times this example was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32", "type": "integer" }, "type": { "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings.\nTemplate mode has been deprecated. Example mode is the only supported\nway to create new training phrases. If you have existing training\nphrases that you've created in template mode, those will continue to\nwork."], "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"], "description": "Required. The type of the training phrase.", "type": "string" }, "parts": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart" }, "description": "Required. The ordered list of training phrase parts.\nThe parts are concatenated in order to form the training phrase.\n\nNote: The API does not automatically annotate training phrases like the\nDialogflow Console does.\n\nNote: Do not forget to include whitespace at part boundaries,\nso the training phrase is well formatted when the parts are concatenated.\n\nIf the training phrase does not need to be annotated with parameters,\nyou just need a single part with only the Part.text field set.\n\nIf you want to annotate the training phrase, you must create multiple\nparts, where the fields of each part are populated in one of two ways:\n\n-   `Part.text` is set to a part of the phrase that has no parameters.\n-   `Part.text` is set to a part of the phrase that you want to annotate,\n    and the `entity_type`, `alias`, and `user_defined` fields are all\n    set." } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase", "description": "Represents an example that the agent is trained on." }, "GoogleCloudDialogflowV2IntentMessageSimpleResponses": { "description": "The collection of simple response candidates.\nThis message in `QueryResult.fulfillment_messages` and\n`WebhookResponse.fulfillment_messages` should contain only one\n`SimpleResponse`.", "type": "object", "properties": { "simpleResponses": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponse" }, "description": "Required. The list of simple responses." } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponses" }, "GoogleCloudDialogflowV2IntentMessageImage": { "description": "The image response message.", "type": "object", "properties": { "imageUri": { "type": "string", "description": "Optional. The public URI to an image file." }, "accessibilityText": { "type": "string", "description": "Optional. A text description of the image to be used for accessibility,\ne.g., screen readers." } }, "id": "GoogleCloudDialogflowV2IntentMessageImage" }, "GoogleCloudDialogflowV2IntentMessageText": { "description": "The text response message.", "type": "object", "properties": { "text": { "type": "array", "items": { "type": "string" }, "description": "Optional. The collection of the agent's responses." } }, "id": "GoogleCloudDialogflowV2IntentMessageText" }, "GoogleCloudDialogflowV2BatchDeleteIntentsRequest": { "description": "The request message for Intents.BatchDeleteIntents.", "type": "object", "properties": { "intents": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" }, "description": "Required. The collection of intents to delete. Only intent `name` must be\nfilled in." } }, "id": "GoogleCloudDialogflowV2BatchDeleteIntentsRequest" }, "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion": { "id": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion", "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent.", "type": "object", "properties": { "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" }, "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" } } }, "GoogleCloudDialogflowV2EntityTypeEntity": { "id": "GoogleCloudDialogflowV2EntityTypeEntity", "description": "An **entity entry** for an associated entity type.", "type": "object", "properties": { "value": { "description": "Required. The primary value associated with this entity entry.\nFor example, if the entity type is *vegetable*, the value could be\n*scallions*.\n\nFor `KIND_MAP` entity types:\n\n*   A canonical value to be used in place of synonyms.\n\nFor `KIND_LIST` entity types:\n\n*   A string that can contain references to other entity types (with or\n    without aliases).", "type": "string" }, "synonyms": { "description": "Required. A collection of value synonyms. For example, if the entity type\nis *vegetable*, and `value` is *scallions*, a synonym could be *green\nonions*.\n\nFor `KIND_LIST` entity types:\n\n*   This collection must contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } } } }, "GoogleCloudDialogflowV2QueryResult": { "type": "object", "properties": { "sentimentAnalysisResult": { "$ref": "GoogleCloudDialogflowV2SentimentAnalysisResult", "description": "The sentiment analysis result, which depends on the\n`sentiment_analysis_request_config` specified in the request." }, "intentDetectionConfidence": { "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float", "type": "number" }, "allRequiredParamsPresent": { "description": "This field is set to:\n\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "speechRecognitionConfidence": { "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float", "type": "number" }, "queryText": { "description": "The original conversational query text:\n\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If automatic spell correction is enabled, `query_text` will contain the\n  corrected user input.", "type": "string" }, "diagnosticInfo": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "The free-form diagnostic info. For example, this field could contain\nwebhook call latency. The string keys of the Struct's fields map can change\nwithout notice." }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "intent": { "$ref": "GoogleCloudDialogflowV2Intent", "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`." }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "webhookPayload": { "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response.", "type": "object" }, "fulfillmentMessages": { "description": "The collection of rich messages to present to the user.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "action": { "description": "The action name from the matched intent.", "type": "string" }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" }, "fulfillmentText": { "type": "string", "description": "The text to be pronounced to the user or shown on the screen.\nNote: This is a legacy field, `fulfillment_messages` should be preferred." }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The collection of extracted parameters.", "type": "object" } }, "id": "GoogleCloudDialogflowV2QueryResult", "description": "Represents the result of conversational query or event processing." }, "GoogleCloudDialogflowV2beta1IntentMessageText": { "type": "object", "properties": { "text": { "description": "Optional. The collection of the agent's responses.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageText", "description": "The text response message." }, "GoogleCloudDialogflowV2IntentMessageCarouselSelect": { "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelect", "description": "The card for presenting a carousel of options to select from.", "type": "object", "properties": { "items": { "description": "Required. Carousel items.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem" } } } }, "GoogleTypeLatLng": { "id": "GoogleTypeLatLng", "description": "An object representing a latitude/longitude pair. This is expressed as a pair\nof doubles representing degrees latitude and degrees longitude. Unless\nspecified otherwise, this must conform to the\n<a href=\"http://www.unoosa.org/pdf/icg/2012/template/WGS_84.pdf\">WGS84\nstandard</a>. Values must be within normalized ranges.", "type": "object", "properties": { "latitude": { "description": "The latitude in degrees. It must be in the range [-90.0, +90.0].", "format": "double", "type": "number" }, "longitude": { "description": "The longitude in degrees. It must be in the range [-180.0, +180.0].", "format": "double", "type": "number" } } }, "GoogleCloudDialogflowV2IntentFollowupIntentInfo": { "description": "Represents a single followup intent in the chain.", "type": "object", "properties": { "followupIntentName": { "type": "string", "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`." }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent's parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentFollowupIntentInfo" }, "GoogleCloudDialogflowV2beta1IntentMessageSuggestions": { "type": "object", "properties": { "suggestions": { "description": "Required. The list of suggested replies.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestion" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions", "description": "The collection of suggestions." }, "GoogleCloudDialogflowV2EntityType": { "id": "GoogleCloudDialogflowV2EntityType", "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries.", "type": "object", "properties": { "name": { "description": "The unique identifier of the entity type.\nRequired for EntityTypes.UpdateEntityType and\nEntityTypes.BatchUpdateEntityTypes methods.\nFormat: `projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "description": "Required. The name of the entity type.", "type": "string" }, "kind": { "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"], "description": "Required. Indicates the kind of entity type.", "type": "string" }, "autoExpansionMode": { "description": "Optional. Indicates whether the entity type can be automatically\nexpanded.", "type": "string", "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"] }, "entities": { "description": "Optional. The collection of entity entries associated with the entity type.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } } } }, "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies": { "type": "object", "properties": { "title": { "description": "Optional. The title of the collection of quick replies.", "type": "string" }, "quickReplies": { "type": "array", "items": { "type": "string" }, "description": "Optional. The collection of quick replies." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies", "description": "The quick replies response message." }, "GoogleCloudDialogflowV2WebhookRequest": { "description": "The request message for a webhook call.", "type": "object", "properties": { "queryResult": { "$ref": "GoogleCloudDialogflowV2QueryResult", "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`." }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." }, "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" }, "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2WebhookRequest" }, "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo": { "description": "Represents a single followup intent in the chain.", "type": "object", "properties": { "followupIntentName": { "type": "string", "description": "The unique identifier of the followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`." }, "parentFollowupIntentName": { "description": "The unique identifier of the followup intent's parent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo" }, "GoogleCloudDialogflowV2TrainAgentRequest": { "description": "The request message for Agents.TrainAgent.", "type": "object", "properties": {}, "id": "GoogleCloudDialogflowV2TrainAgentRequest" }, "GoogleCloudDialogflowV2ExportAgentResponse": { "type": "object", "properties": { "agentUri": { "type": "string", "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`." }, "agentContent": { "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte", "type": "string" } }, "id": "GoogleCloudDialogflowV2ExportAgentResponse", "description": "The response message for Agents.ExportAgent." }, "GoogleCloudDialogflowV2beta1EntityTypeEntity": { "id": "GoogleCloudDialogflowV2beta1EntityTypeEntity", "description": "An **entity entry** for an associated entity type.", "type": "object", "properties": { "value": { "description": "Required. The primary value associated with this entity entry.\nFor example, if the entity type is *vegetable*, the value could be\n*scallions*.\n\nFor `KIND_MAP` entity types:\n\n*   A canonical value to be used in place of synonyms.\n\nFor `KIND_LIST` entity types:\n\n*   A string that can contain references to other entity types (with or\n    without aliases).", "type": "string" }, "synonyms": { "description": "Required. A collection of value synonyms. For example, if the entity type\nis *vegetable*, and `value` is *scallions*, a synonym could be *green\nonions*.\n\nFor `KIND_LIST` entity types:\n\n*   This collection must contain exactly one synonym equal to `value`.", "type": "array", "items": { "type": "string" } } } }, "GoogleCloudDialogflowV2QueryParameters": { "description": "Represents the parameters of the conversational query.", "type": "object", "properties": { "resetContexts": { "description": "Optional. Specifies whether to delete all contexts in the current session\nbefore the new ones are activated.", "type": "boolean" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field can be used to pass custom data into the webhook\nassociated with the agent. Arbitrary JSON objects are supported.", "type": "object" }, "geoLocation": { "$ref": "GoogleTypeLatLng", "description": "Optional. The geo location of this conversational query." }, "contexts": { "description": "Optional. The collection of contexts to be activated before this query is\nexecuted.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "sentimentAnalysisRequestConfig": { "$ref": "GoogleCloudDialogflowV2SentimentAnalysisRequestConfig", "description": "Optional. Configures the type of sentiment analysis to perform. If not\nprovided, sentiment analysis is not performed." }, "timeZone": { "type": "string", "description": "Optional. The time zone of this conversational query from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris. If not provided, the time zone specified in\nagent settings is used." }, "sessionEntityTypes": { "description": "Optional. Additional session entity types to replace or extend developer\nentity types with. The entity synonyms apply to all languages and persist\nfor the session of this query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" } } }, "id": "GoogleCloudDialogflowV2QueryParameters" }, "GoogleCloudDialogflowV2WebhookResponse": { "id": "GoogleCloudDialogflowV2WebhookResponse", "description": "The response message for a webhook call.", "type": "object", "properties": { "fulfillmentText": { "type": "string", "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`." }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "payload": { "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>" }, "source": { "description": "Optional. This value is passed directly to `QueryResult.webhook_source`.", "type": "string" }, "followupEventInput": { "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input.\nWhen this field is set, Dialogflow ignores the `fulfillment_text`,\n`fulfillment_messages`, and `payload` fields.", "$ref": "GoogleCloudDialogflowV2EventInput" }, "outputContexts": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" }, "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`." } } }, "GoogleCloudDialogflowV2BatchCreateEntitiesRequest": { "id": "GoogleCloudDialogflowV2BatchCreateEntitiesRequest", "description": "The request message for EntityTypes.BatchCreateEntities.", "type": "object", "properties": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "entities": { "description": "Required. The entities to create.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } } } }, "GoogleCloudDialogflowV2IntentMessageCardButton": { "description": "Optional. Contains information about a button.", "type": "object", "properties": { "text": { "description": "Optional. The text to show on the button.", "type": "string" }, "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageCardButton" }, "GoogleCloudDialogflowV2beta1KnowledgeAnswers": { "type": "object", "properties": { "answers": { "description": "A list of answers from Knowledge Connector.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" } } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswers", "description": "Represents the result of querying a Knowledge base." }, "GoogleCloudDialogflowV2beta1SentimentAnalysisResult": { "type": "object", "properties": { "queryTextSentiment": { "$ref": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment analysis result for `query_text`." } }, "id": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult", "description": "The result of sentiment analysis as configured by\n`sentiment_analysis_request_config`." }, "GoogleCloudDialogflowV2ListIntentsResponse": { "description": "The response message for Intents.ListIntents.", "type": "object", "properties": { "intents": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" }, "description": "The list of agent intents. There will be a maximum number of items\nreturned based on the page_size field in the request." }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ListIntentsResponse" }, "GoogleCloudDialogflowV2beta1ExportAgentResponse": { "description": "The response message for Agents.ExportAgent.", "type": "object", "properties": { "agentUri": { "description": "The URI to a file containing the exported agent. This field is populated\nonly if `agent_uri` is specified in `ExportAgentRequest`.", "type": "string" }, "agentContent": { "description": "The exported agent.\n\nExample for how to export an agent to a zip file via a command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2beta1/projects/&lt;project_name&gt;/agent:export'\\\n  -X POST \\\n  -H 'Authorization: Bearer '$(gcloud auth application-default\n  print-access-token) \\\n  -H 'Accept: application/json' \\\n  -H 'Content-Type: application/json' \\\n  --compressed \\\n  --data-binary '{}' \\\n| grep agentContent | sed -e 's/.*\"agentContent\": \"\\([^\"]*\\)\".*/\\1/' \\\n| base64 --decode > &lt;agent zip file&gt;</pre>", "format": "byte", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1ExportAgentResponse" }, "GoogleCloudDialogflowV2OriginalDetectIntentRequest": { "type": "object", "properties": { "payload": { "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents." }, "source": { "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers.", "type": "string" }, "version": { "type": "string", "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific." } }, "id": "GoogleCloudDialogflowV2OriginalDetectIntentRequest", "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call." }, "GoogleLongrunningOperation": { "description": "This resource represents a long-running operation that is the result of a\nnetwork API call.", "type": "object", "properties": { "done": { "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.", "type": "boolean" }, "response": { "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`." }, "name": { "type": "string", "description": "The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`." }, "error": { "$ref": "GoogleRpcStatus", "description": "The error result of the operation in case of failure or cancellation." }, "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.", "type": "object" } }, "id": "GoogleLongrunningOperation" }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall": { "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall", "description": "Transfers the call in Telephony Gateway.", "type": "object", "properties": { "phoneNumber": { "description": "Required. The phone number to transfer the call to\nin [E.164 format](https://en.wikipedia.org/wiki/E.164).\n\nWe currently only allow transferring to US numbers (+1xxxyyyzzzz).", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageImage": { "description": "The image response message.", "type": "object", "properties": { "imageUri": { "description": "Optional. The public URI to an image file.", "type": "string" }, "accessibilityText": { "type": "string", "description": "A text description of the image to be used for accessibility,\ne.g., screen readers. Required if image_uri is set for CarouselSelect." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "GoogleCloudDialogflowV2ListEntityTypesResponse": { "type": "object", "properties": { "entityTypes": { "description": "The list of agent entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } }, "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list." } }, "id": "GoogleCloudDialogflowV2ListEntityTypesResponse", "description": "The response message for EntityTypes.ListEntityTypes." }, "GoogleCloudDialogflowV2IntentMessageSimpleResponse": { "description": "The simple response message containing speech or text.", "type": "object", "properties": { "textToSpeech": { "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml.", "type": "string" }, "ssml": { "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech.", "type": "string" }, "displayText": { "description": "Optional. The text to display.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageSimpleResponse" }, "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem": { "id": "GoogleCloudDialogflowV2IntentMessageCarouselSelectItem", "description": "An item in the carousel.", "type": "object", "properties": { "info": { "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo", "description": "Required. Additional info about the option item." }, "title": { "description": "Required. Title of the carousel item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The body text of the card.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton": { "description": "The button object that appears at the bottom of a card.", "type": "object", "properties": { "title": { "description": "Required. The title of the button.", "type": "string" }, "openUriAction": { "description": "Required. Action to take when a user taps on the button.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" }, "GoogleCloudDialogflowV2IntentTrainingPhrase": { "type": "object", "properties": { "parts": { "description": "Required. The ordered list of training phrase parts.\nThe parts are concatenated in order to form the training phrase.\n\nNote: The API does not automatically annotate training phrases like the\nDialogflow Console does.\n\nNote: Do not forget to include whitespace at part boundaries,\nso the training phrase is well formatted when the parts are concatenated.\n\nIf the training phrase does not need to be annotated with parameters,\nyou just need a single part with only the Part.text field set.\n\nIf you want to annotate the training phrase, you must create multiple\nparts, where the fields of each part are populated in one of two ways:\n\n-   `Part.text` is set to a part of the phrase that has no parameters.\n-   `Part.text` is set to a part of the phrase that you want to annotate,\n    and the `entity_type`, `alias`, and `user_defined` fields are all\n    set.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrasePart" } }, "name": { "description": "Output only. The unique identifier of this training phrase.", "type": "string" }, "timesAddedCount": { "type": "integer", "description": "Optional. Indicates how many times this example was added to\nthe intent. Each time a developer adds an existing sample by editing an\nintent or training, this counter is increased.", "format": "int32" }, "type": { "enumDescriptions": ["Not specified. This value should never be used.", "Examples do not contain @-prefixed entity type names, but example parts\ncan be annotated with entity types.", "Templates are not annotated with entity types, but they can contain\n@-prefixed entity type names as substrings.\nTemplate mode has been deprecated. Example mode is the only supported\nway to create new training phrases. If you have existing training\nphrases that you've created in template mode, those will continue to\nwork."], "enum": ["TYPE_UNSPECIFIED", "EXAMPLE", "TEMPLATE"], "description": "Required. The type of the training phrase.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentTrainingPhrase", "description": "Represents an example that the agent is trained on." }, "GoogleCloudDialogflowV2SearchAgentsResponse": { "description": "The response message for Agents.SearchAgents.", "type": "object", "properties": { "agents": { "description": "The list of agents. There will be a maximum number of items returned based\non the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Agent" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "GoogleCloudDialogflowV2SearchAgentsResponse" }, "GoogleCloudDialogflowV2EntityTypeBatch": { "id": "GoogleCloudDialogflowV2EntityTypeBatch", "description": "This message is a wrapper around a collection of entity types.", "type": "object", "properties": { "entityTypes": { "description": "A collection of entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } } } }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio": { "type": "object", "properties": { "audioUri": { "description": "Required. URI to a Google Cloud Storage object containing the audio to\nplay, e.g., \"gs://bucket/object\". The object must contain a single\nchannel (mono) of linear PCM audio (2 bytes / sample) at 8kHz.\n\nThis object must be readable by the `service-<Project\nNumber>@gcp-sa-dialogflow.iam.gserviceaccount.com` service account\nwhere <Project Number> is the number of the Telephony Gateway project\n(usually the same as the Dialogflow agent project). If the Google Cloud\nStorage bucket is in the Telephony Gateway project, this permission is\nadded by default when enabling the Dialogflow V2 API.\n\nFor audio from other sources, consider using the\n`TelephonySynthesizeSpeech` message with SSML.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio", "description": "Plays audio from a file in Telephony Gateway." }, "GoogleCloudDialogflowV2beta1WebhookRequest": { "id": "GoogleCloudDialogflowV2beta1WebhookRequest", "description": "The request message for a webhook call.", "type": "object", "properties": { "responseId": { "description": "The unique identifier of the response. Contains the same value as\n`[Streaming]DetectIntentResponse.response_id`.", "type": "string" }, "session": { "description": "The unique identifier of detectIntent request session.\nCan be used to identify end-user inside webhook implementation.\nFormat: `projects/<Project ID>/agent/sessions/<Session ID>`, or\n`projects/<Project ID>/agent/environments/<Environment ID>/users/<User\nID>/sessions/<Session ID>`.", "type": "string" }, "queryResult": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult", "description": "The result of the conversational query or event processing. Contains the\nsame value as `[Streaming]DetectIntentResponse.query_result`." }, "originalDetectIntentRequest": { "$ref": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest", "description": "Optional. The contents of the original request that was passed to\n`[Streaming]DetectIntent` call." }, "alternativeQueryResults": { "description": "Alternative query results from KnowledgeService.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1QueryResult" } } } }, "GoogleCloudDialogflowV2IntentMessageListSelect": { "type": "object", "properties": { "title": { "description": "Optional. The overall title of the list.", "type": "string" }, "items": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelectItem" }, "description": "Required. List items." } }, "id": "GoogleCloudDialogflowV2IntentMessageListSelect", "description": "The card for presenting a list of options to select from." }, "GoogleCloudDialogflowV2beta1IntentMessageCardButton": { "id": "GoogleCloudDialogflowV2beta1IntentMessageCardButton", "description": "Optional. Contains information about a button.", "type": "object", "properties": { "text": { "description": "Optional. The text to show on the button.", "type": "string" }, "postback": { "description": "Optional. The text to send back to the Dialogflow API or a URI to\nopen.", "type": "string" } } }, "GoogleProtobufEmpty": { "type": "object", "properties": {}, "id": "GoogleProtobufEmpty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`." }, "GoogleCloudDialogflowV2ImportAgentRequest": { "type": "object", "properties": { "agentContent": { "description": "The agent to import.\n\nExample for how to import an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:import\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n      'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to import.\nNote: The URI must start with \"gs://\".", "type": "string" } }, "id": "GoogleCloudDialogflowV2ImportAgentRequest", "description": "The request message for Agents.ImportAgent." }, "GoogleCloudDialogflowV2IntentMessageListSelectItem": { "type": "object", "properties": { "title": { "description": "Required. The title of the list item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The main text describing the item.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." } }, "id": "GoogleCloudDialogflowV2IntentMessageListSelectItem", "description": "An item in the list." }, "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest": { "type": "object", "properties": { "entityTypeNames": { "description": "Required. The names entity types to delete. All names must point to the\nsame agent as `parent`.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2BatchDeleteEntityTypesRequest", "description": "The request message for EntityTypes.BatchDeleteEntityTypes." }, "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest": { "description": "Represents the contents of the original request that was passed to\nthe `[Streaming]DetectIntent` call.", "type": "object", "properties": { "source": { "description": "The source of this request, e.g., `google`, `facebook`, `slack`. It is set\nby Dialogflow-owned servers.", "type": "string" }, "version": { "description": "Optional. The version of the protocol used for this request.\nThis field is AoG-specific.", "type": "string" }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This field is set to the value of the `QueryParameters.payload`\nfield passed in the request. Some integrations that query a Dialogflow\nagent may provide additional information in the payload.\n\nIn particular for the Telephony Gateway this field has the form:\n<pre>{\n \"telephony\": {\n   \"caller_id\": \"+18558363987\"\n }\n}</pre>\nNote: The caller ID field (`caller_id`) will be redacted for Standard\nEdition agents and populated with the caller ID in [E.164\nformat](https://en.wikipedia.org/wiki/E.164) for Enterprise Edition agents.", "type": "object" } }, "id": "GoogleCloudDialogflowV2beta1OriginalDetectIntentRequest" }, "GoogleCloudDialogflowV2beta1WebhookResponse": { "type": "object", "properties": { "payload": { "type": "object", "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. This value is passed directly to `QueryResult.webhook_payload`.\nSee the related `fulfillment_messages[i].payload field`, which may be used\nas an alternative to this field.\n\nThis field can be used for Actions on Google responses.\nIt should have a structure similar to the JSON message shown here. For more\ninformation, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"google\": {\n    \"expectUserResponse\": true,\n    \"richResponse\": {\n      \"items\": [\n        {\n          \"simpleResponse\": {\n            \"textToSpeech\": \"this is a simple response\"\n          }\n        }\n      ]\n    }\n  }\n}</pre>" }, "source": { "description": "Optional. This value is passed directly to `QueryResult.webhook_source`.", "type": "string" }, "endInteraction": { "type": "boolean", "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false." }, "followupEventInput": { "$ref": "GoogleCloudDialogflowV2beta1EventInput", "description": "Optional. Makes the platform immediately invoke another `DetectIntent` call\ninternally with the specified event as input.\nWhen this field is set, Dialogflow ignores the `fulfillment_text`,\n`fulfillment_messages`, and `payload` fields." }, "outputContexts": { "description": "Optional. The collection of output contexts. This value is passed directly\nto `QueryResult.output_contexts`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "fulfillmentText": { "description": "Optional. The text to be shown on the screen. This value is passed directly\nto `QueryResult.fulfillment_text`.", "type": "string" }, "fulfillmentMessages": { "description": "Optional. The collection of rich messages to present to the user. This\nvalue is passed directly to `QueryResult.fulfillment_messages`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" } } }, "id": "GoogleCloudDialogflowV2beta1WebhookResponse", "description": "The response message for a webhook call." }, "GoogleCloudDialogflowV2IntentMessageSelectItemInfo": { "description": "Additional info about the select item for when it is triggered in a\ndialog.", "type": "object", "properties": { "synonyms": { "description": "Optional. A list of synonyms that can also be used to trigger this\nitem in dialog.", "type": "array", "items": { "type": "string" } }, "key": { "type": "string", "description": "Required. A unique key that will be sent back to the agent if this\nresponse is given." } }, "id": "GoogleCloudDialogflowV2IntentMessageSelectItemInfo" }, "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction": { "id": "GoogleCloudDialogflowV2IntentMessageBasicCardButtonOpenUriAction", "description": "Opens the given URI.", "type": "object", "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } } }, "GoogleCloudDialogflowV2RestoreAgentRequest": { "id": "GoogleCloudDialogflowV2RestoreAgentRequest", "description": "The request message for Agents.RestoreAgent.", "type": "object", "properties": { "agentContent": { "description": "The agent to restore.\n\nExample for how to restore an agent via the command line:\n<pre>curl \\\n  'https://dialogflow.googleapis.com/v2/projects/&lt;project_name&gt;/agent:restore\\\n   -X POST \\\n   -H 'Authorization: Bearer '$(gcloud auth application-default\n   print-access-token) \\\n   -H 'Accept: application/json' \\\n   -H 'Content-Type: application/json' \\\n   --compressed \\\n   --data-binary \"{\n       'agentContent': '$(cat &lt;agent zip file&gt; | base64 -w 0)'\n   }\"</pre>", "format": "byte", "type": "string" }, "agentUri": { "description": "The URI to a Google Cloud Storage file containing the agent to restore.\nNote: The URI must start with \"gs://\".", "type": "string" } } }, "GoogleCloudDialogflowV2DetectIntentResponse": { "description": "The message returned from the DetectIntent method.", "type": "object", "properties": { "responseId": { "description": "The unique identifier of the response. It can be used to\nlocate a response in the training example set or for reporting issues.", "type": "string" }, "outputAudioConfig": { "$ref": "GoogleCloudDialogflowV2OutputAudioConfig", "description": "The config used by the speech synthesizer to generate the output audio." }, "queryResult": { "$ref": "GoogleCloudDialogflowV2QueryResult", "description": "The selected results of the conversational query or event processing.\nSee `alternative_query_results` for additional potential results." }, "outputAudio": { "description": "The audio data bytes encoded as specified in the request.\nNote: The output audio is generated based on the values of default platform\ntext responses found in the `query_result.fulfillment_messages` field. If\nmultiple default text responses exist, they will be concatenated when\ngenerating audio. If no default platform text responses exist, the\ngenerated audio content will be empty.", "format": "byte", "type": "string" }, "webhookStatus": { "$ref": "GoogleRpcStatus", "description": "Specifies the status of the webhook request." } }, "id": "GoogleCloudDialogflowV2DetectIntentResponse" }, "GoogleCloudDialogflowV2IntentMessageQuickReplies": { "type": "object", "properties": { "title": { "description": "Optional. The title of the collection of quick replies.", "type": "string" }, "quickReplies": { "description": "Optional. The collection of quick replies.", "type": "array", "items": { "type": "string" } } }, "id": "GoogleCloudDialogflowV2IntentMessageQuickReplies", "description": "The quick replies response message." }, "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse": { "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityType" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateEntityTypesResponse" }, "GoogleCloudDialogflowV2SentimentAnalysisResult": { "id": "GoogleCloudDialogflowV2SentimentAnalysisResult", "description": "The result of sentiment analysis as configured by\n`sentiment_analysis_request_config`.", "type": "object", "properties": { "queryTextSentiment": { "$ref": "GoogleCloudDialogflowV2Sentiment", "description": "The sentiment analysis result for `query_text`." } } }, "GoogleCloudDialogflowV2beta1EntityType": { "id": "GoogleCloudDialogflowV2beta1EntityType", "description": "Represents an entity type.\nEntity types serve as a tool for extracting parameter values from natural\nlanguage queries.", "type": "object", "properties": { "name": { "description": "The unique identifier of the entity type.\nRequired for EntityTypes.UpdateEntityType and\nEntityTypes.BatchUpdateEntityTypes methods.\nFormat: `projects/<Project ID>/agent/entityTypes/<Entity Type ID>`.", "type": "string" }, "displayName": { "type": "string", "description": "Required. The name of the entity type." }, "kind": { "description": "Required. Indicates the kind of entity type.", "type": "string", "enumDescriptions": ["Not specified. This value should be never used.", "Map entity types allow mapping of a group of synonyms to a canonical\nvalue.", "List entity types contain a set of entries that do not map to canonical\nvalues. However, list entity types can contain references to other entity\ntypes (with or without aliases)."], "enum": ["KIND_UNSPECIFIED", "KIND_MAP", "KIND_LIST"] }, "autoExpansionMode": { "enumDescriptions": ["Auto expansion disabled for the entity.", "Allows an agent to recognize values that have not been explicitly\nlisted in the entity."], "enum": ["AUTO_EXPANSION_MODE_UNSPECIFIED", "AUTO_EXPANSION_MODE_DEFAULT"], "description": "Optional. Indicates whether the entity type can be automatically\nexpanded.", "type": "string" }, "entities": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityTypeEntity" }, "description": "Optional. The collection of entity entries associated with the entity type." } } }, "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse": { "type": "object", "properties": { "textToSpeech": { "type": "string", "description": "One of text_to_speech or ssml must be provided. The plain text of the\nspeech output. Mutually exclusive with ssml." }, "ssml": { "type": "string", "description": "One of text_to_speech or ssml must be provided. Structured spoken\nresponse to the user in the SSML format. Mutually exclusive with\ntext_to_speech." }, "displayText": { "description": "Optional. The text to display.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponse", "description": "The simple response message containing speech or text." }, "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest": { "id": "GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest", "description": "The request message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "languageCode": { "description": "Optional. The language of entity synonyms defined in `entity_types`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" }, "entityTypeBatchUri": { "type": "string", "description": "The URI to a Google Cloud Storage file containing entity types to update\nor create. The file format can either be a serialized proto (of\nEntityBatch type) or a JSON object. Note: The URI must start with\n\"gs://\"." }, "entityTypeBatchInline": { "$ref": "GoogleCloudDialogflowV2EntityTypeBatch", "description": "The collection of entity types to update or create." } } }, "GoogleCloudDialogflowV2beta1QueryResult": { "id": "GoogleCloudDialogflowV2beta1QueryResult", "description": "Represents the result of conversational query or event processing.", "type": "object", "properties": { "sentimentAnalysisResult": { "$ref": "GoogleCloudDialogflowV2beta1SentimentAnalysisResult", "description": "The sentiment analysis result, which depends on the\n`sentiment_analysis_request_config` specified in the request." }, "intentDetectionConfidence": { "type": "number", "description": "The intent detection confidence. Values range from 0.0\n(completely uncertain) to 1.0 (completely certain).\nIf there are `multiple knowledge_answers` messages, this value is set to\nthe greatest `knowledgeAnswers.match_confidence` value in the list.", "format": "float" }, "allRequiredParamsPresent": { "description": "This field is set to:\n\n- `false` if the matched intent has required parameters and not all of\n   the required parameter values have been collected.\n- `true` if all required parameter values have been collected, or if the\n   matched intent doesn't contain any required parameters.", "type": "boolean" }, "queryText": { "description": "The original conversational query text:\n\n- If natural language text was provided as input, `query_text` contains\n  a copy of the input.\n- If natural language speech audio was provided as input, `query_text`\n  contains the speech recognition result. If speech recognizer produced\n  multiple alternatives, a particular one is picked.\n- If automatic spell correction is enabled, `query_text` will contain the\n  corrected user input.", "type": "string" }, "speechRecognitionConfidence": { "type": "number", "description": "The Speech recognition confidence between 0.0 and 1.0. A higher number\nindicates an estimated greater likelihood that the recognized words are\ncorrect. The default of 0.0 is a sentinel value indicating that confidence\nwas not set.\n\nThis field is not guaranteed to be accurate or set. In particular this\nfield isn't set for StreamingDetectIntent since the streaming endpoint has\nseparate confidence estimates per portion of the audio in\nStreamingRecognitionResult.", "format": "float" }, "diagnosticInfo": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The free-form diagnostic info. For example, this field could contain\nwebhook call latency. The string keys of the Struct's fields map can change\nwithout notice.", "type": "object" }, "intent": { "$ref": "GoogleCloudDialogflowV2beta1Intent", "description": "The intent that matched the conversational query. Some, not\nall fields are filled in this message, including but not limited to:\n`name`, `display_name` and `webhook_state`." }, "languageCode": { "description": "The language that was triggered during intent detection.\nSee [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes.", "type": "string" }, "outputContexts": { "description": "The collection of output contexts. If applicable,\n`output_contexts.parameters` contains entries with name\n`<parameter name>.original` containing the original parameter values\nbefore the query.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "fulfillmentMessages": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" }, "description": "The collection of rich messages to present to the user." }, "webhookPayload": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `payload` field returned in the webhook response." }, "action": { "type": "string", "description": "The action name from the matched intent." }, "webhookSource": { "description": "If the query was fulfilled by a webhook call, this field is set to the\nvalue of the `source` field returned in the webhook response.", "type": "string" }, "fulfillmentText": { "description": "The text to be pronounced to the user or shown on the screen.\nNote: This is a legacy field, `fulfillment_messages` should be preferred.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "The collection of extracted parameters.", "type": "object" }, "knowledgeAnswers": { "$ref": "GoogleCloudDialogflowV2beta1KnowledgeAnswers", "description": "The result from Knowledge Connector (if any), ordered by decreasing\n`KnowledgeAnswers.match_confidence`." } } }, "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech": { "description": "Synthesizes speech and plays back the synthesized audio to the caller in\nTelephony Gateway.\n\nTelephony Gateway takes the synthesizer settings from\n`DetectIntentResponse.output_audio_config` which can either be set\nat request-level or can come from the agent-level synthesizer config.", "type": "object", "properties": { "text": { "description": "The raw text to be synthesized.", "type": "string" }, "ssml": { "description": "The SSML to be synthesized. For more information, see\n[SSML](https://developers.google.com/actions/reference/ssml).", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech" }, "GoogleCloudDialogflowV2ExportAgentRequest": { "description": "The request message for Agents.ExportAgent.", "type": "object", "properties": { "agentUri": { "description": "Optional. The\n[Google Cloud Storage](https://cloud.google.com/storage/docs/)\nURI to export the agent to.\nThe format of this URI must be `gs://<bucket-name>/<object-name>`.\nIf left unspecified, the serialized agent is returned inline.", "type": "string" } }, "id": "GoogleCloudDialogflowV2ExportAgentRequest" }, "GoogleCloudDialogflowV2TextInput": { "description": "Represents the natural language text to be processed.", "type": "object", "properties": { "text": { "description": "Required. The UTF-8 encoded natural language text to be processed.\nText length must not exceed 256 characters.", "type": "string" }, "languageCode": { "description": "Required. The language of this conversational query. See [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes. Note that queries in\nthe same session do not necessarily need to specify the same language.", "type": "string" } }, "id": "GoogleCloudDialogflowV2TextInput" }, "GoogleCloudDialogflowV2Context": { "id": "GoogleCloudDialogflowV2Context", "description": "Represents a context.", "type": "object", "properties": { "lifespanCount": { "type": "integer", "description": "Optional. The number of conversational query requests after which the\ncontext expires. If set to `0` (the default) the context expires\nimmediately. Contexts expire automatically after 20 minutes if there\nare no matching queries.", "format": "int32" }, "name": { "description": "Required. The unique identifier of the context. Format:\n`projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>`.\n\nThe `Context ID` is always converted to lowercase, may only contain\ncharacters in [a-zA-Z0-9_-%] and may be at most 250 bytes long.", "type": "string" }, "parameters": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Optional. The collection of parameters associated with this context.\nRefer to [this\ndoc](https://cloud.google.com/dialogflow/docs/intents-actions-parameters)\nfor syntax.", "type": "object" } } }, "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem": { "description": "An item in the carousel.", "type": "object", "properties": { "title": { "description": "Required. Title of the carousel item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The body text of the card.", "type": "string" }, "info": { "description": "Required. Additional info about the option item.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelectItem" }, "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer": { "description": "An answer from Knowledge Connector.", "type": "object", "properties": { "source": { "type": "string", "description": "Indicates which Knowledge Document this answer was extracted from.\nFormat: `projects/<Project ID>/knowledgeBases/<Knowledge Base\nID>/documents/<Document ID>`." }, "answer": { "description": "The piece of text from the `source` knowledge base document that answers\nthis conversational query.", "type": "string" }, "faqQuestion": { "type": "string", "description": "The corresponding FAQ question if the answer was extracted from a FAQ\nDocument, empty otherwise." }, "matchConfidenceLevel": { "description": "The system's confidence level that this knowledge answer is a good match\nfor this conversational query.\nNOTE: The confidence level for a given `<query, answer>` pair may change\nwithout notice, as it depends on models that are constantly being\nimproved. However, it will change less frequently than the confidence\nscore below, and should be preferred for referencing the quality of an\nanswer.", "type": "string", "enumDescriptions": ["Not specified.", "Indicates that the confidence is low.", "Indicates our confidence is medium.", "Indicates our confidence is high."], "enum": ["MATCH_CONFIDENCE_LEVEL_UNSPECIFIED", "LOW", "MEDIUM", "HIGH"] }, "matchConfidence": { "type": "number", "description": "The system's confidence score that this Knowledge answer is a good match\nfor this conversational query.\nThe range is from 0.0 (completely uncertain) to 1.0 (completely certain).\nNote: The confidence score is likely to vary somewhat (possibly even for\nidentical requests), as the underlying model is under constant\nimprovement. It may be deprecated in the future. We recommend using\n`match_confidence_level` which should be generally more stable.", "format": "float" } }, "id": "GoogleCloudDialogflowV2beta1KnowledgeAnswersAnswer" }, "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest": { "type": "object", "properties": { "languageCode": { "type": "string", "description": "Optional. The language of entity synonyms defined in `entities`. If not\nspecified, the agent's default language is used.\n[Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used." }, "updateMask": { "type": "string", "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask" }, "entities": { "description": "Required. The entities to update or create.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2EntityTypeEntity" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateEntitiesRequest", "description": "The request message for EntityTypes.BatchUpdateEntities." }, "GoogleCloudDialogflowV2BatchUpdateIntentsResponse": { "description": "The response message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intents": { "description": "The collection of updated or created intents.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Intent" } } }, "id": "GoogleCloudDialogflowV2BatchUpdateIntentsResponse" }, "GoogleCloudDialogflowV2Agent": { "id": "GoogleCloudDialogflowV2Agent", "description": "Represents a conversational agent.", "type": "object", "properties": { "description": { "description": "Optional. The description of this agent.\nThe maximum length is 500 characters. If exceeded, the request is rejected.", "type": "string" }, "parent": { "description": "Required. The project of this agent.\nFormat: `projects/<Project ID>`.", "type": "string" }, "supportedLanguageCodes": { "description": "Optional. The list of all languages supported by this agent (except for the\n`default_language_code`).", "type": "array", "items": { "type": "string" } }, "avatarUri": { "description": "Optional. The URI of the agent's avatar.\nAvatars are used throughout the Dialogflow console and in the self-hosted\n[Web\nDemo](https://cloud.google.com/dialogflow/docs/integrations/web-demo)\nintegration.", "type": "string" }, "defaultLanguageCode": { "description": "Required. The default language of the agent as a language tag. See\n[Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes. This field cannot be\nset by the `Update` method.", "type": "string" }, "tier": { "type": "string", "enumDescriptions": ["Not specified. This value should never be used.", "Standard tier.", "Enterprise tier (Essentials).", "Enterprise tier (Plus)."], "enum": ["TIER_UNSPECIFIED", "TIER_STANDARD", "TIER_ENTERPRISE", "TIER_ENTERPRISE_PLUS"], "description": "Optional. The agent tier. If not specified, TIER_STANDARD is assumed." }, "displayName": { "description": "Required. The name of this agent.", "type": "string" }, "matchMode": { "enum": ["MATCH_MODE_UNSPECIFIED", "MATCH_MODE_HYBRID", "MATCH_MODE_ML_ONLY"], "description": "Optional. Determines how intents are detected from user queries.", "type": "string", "enumDescriptions": ["Not specified.", "Best for agents with a small number of examples in intents and/or wide\nuse of templates syntax and composite entities.", "Can be used for agents with a large number of examples in intents,\nespecially the ones using @sys.any or very large developer entities."] }, "enableLogging": { "description": "Optional. Determines whether this agent should log conversation queries.", "type": "boolean" }, "apiVersion": { "type": "string", "enumDescriptions": ["Not specified.", "Legacy V1 API.", "V2 API.", "V2beta1 API."], "enum": ["API_VERSION_UNSPECIFIED", "API_VERSION_V1", "API_VERSION_V2", "API_VERSION_V2_BETA_1"], "description": "Optional. API version displayed in Dialogflow console. If not specified,\nV2 API is assumed. Clients are free to query different service endpoints\nfor different API versions. However, bots connectors and webhook calls will\nfollow the specified API version." }, "classificationThreshold": { "type": "number", "description": "Optional. To filter out false positive results and still get variety in\nmatched natural language inputs for your agent, you can tune the machine\nlearning classification threshold. If the returned score value is less than\nthe threshold value, then a fallback intent will be triggered or, if there\nare no fallback intents defined, no intent will be triggered. The score\nvalues range from 0.0 (completely uncertain) to 1.0 (completely certain).\nIf set to 0.0, the default of 0.3 is used.", "format": "float" }, "timeZone": { "description": "Required. The time zone of this agent from the\n[time zone database](https://www.iana.org/time-zones), e.g.,\nAmerica/New_York, Europe/Paris.", "type": "string" } } }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction": { "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButtonOpenUriAction", "description": "Opens the given URI.", "type": "object", "properties": { "uri": { "description": "Required. The HTTP or HTTPS scheme URI.", "type": "string" } } }, "GoogleCloudDialogflowV2IntentMessage": { "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object", "properties": { "carouselSelect": { "$ref": "GoogleCloudDialogflowV2IntentMessageCarouselSelect", "description": "The carousel card response for Actions on Google." }, "linkOutSuggestion": { "description": "The link out suggestion chip for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion" }, "simpleResponses": { "description": "The voice and text-only responses for Actions on Google.", "$ref": "GoogleCloudDialogflowV2IntentMessageSimpleResponses" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "The image response." }, "payload": { "additionalProperties": { "description": "Properties of the object.", "type": "any" }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "$ref": "GoogleCloudDialogflowV2IntentMessageText", "description": "The text response." }, "suggestions": { "$ref": "GoogleCloudDialogflowV2IntentMessageSuggestions", "description": "The suggestion chips for Actions on Google." }, "platform": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "GOOGLE_HANGOUTS"], "description": "Optional. The platform that this message is intended for.", "type": "string", "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Google Hangouts."] }, "listSelect": { "$ref": "GoogleCloudDialogflowV2IntentMessageListSelect", "description": "The list card response for Actions on Google." }, "quickReplies": { "$ref": "GoogleCloudDialogflowV2IntentMessageQuickReplies", "description": "The quick replies response." }, "card": { "$ref": "GoogleCloudDialogflowV2IntentMessageCard", "description": "The card response." }, "basicCard": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCard", "description": "The basic card response for Actions on Google." } }, "id": "GoogleCloudDialogflowV2IntentMessage" }, "GoogleCloudDialogflowV2IntentMessageBasicCard": { "description": "The basic card message. Useful for displaying information.", "type": "object", "properties": { "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2IntentMessageImage", "description": "Optional. The image for the card." }, "formattedText": { "type": "string", "description": "Required, unless image is present. The body text of the card." }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessageBasicCardButton" } }, "subtitle": { "description": "Optional. The subtitle of the card.", "type": "string" } }, "id": "GoogleCloudDialogflowV2IntentMessageBasicCard" }, "GoogleCloudDialogflowV2ListSessionEntityTypesResponse": { "description": "The response message for SessionEntityTypes.ListSessionEntityTypes.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "sessionEntityTypes": { "description": "The list of session entity types. There will be a maximum number of items\nreturned based on the page_size field in the request.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2SessionEntityType" } } }, "id": "GoogleCloudDialogflowV2ListSessionEntityTypesResponse" }, "GoogleCloudDialogflowV2beta1Sentiment": { "type": "object", "properties": { "score": { "description": "Sentiment score between -1.0 (negative sentiment) and 1.0 (positive\nsentiment).", "format": "float", "type": "number" }, "magnitude": { "description": "A non-negative number in the [0, +inf) range, which represents the absolute\nmagnitude of sentiment, regardless of score (positive or negative).", "format": "float", "type": "number" } }, "id": "GoogleCloudDialogflowV2beta1Sentiment", "description": "The sentiment, such as positive/negative feeling or association, for a unit\nof analysis, such as the query text." }, "GoogleCloudDialogflowV2beta1Intent": { "id": "GoogleCloudDialogflowV2beta1Intent", "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics.", "type": "object", "properties": { "displayName": { "type": "string", "description": "Required. The name of this intent." }, "rootFollowupIntentName": { "description": "Read-only. The unique identifier of the root intent in the chain of\nfollowup intents. It identifies the correct followup intents chain for\nthis intent. We populate this field only in the output.\n\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "mlDisabled": { "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_disabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.", "type": "boolean" }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "mlEnabled": { "description": "Optional. Indicates whether Machine Learning is enabled for the intent.\nNote: If `ml_enabled` setting is set to false, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.\nDEPRECATED! Please use `ml_disabled` field instead.\nNOTE: If both `ml_enabled` and `ml_disabled` are either not set or false,\nthen the default value is determined as follows:\n- Before April 15th, 2018 the default is:\n  ml_enabled = false / ml_disabled = true.\n- After April 15th, 2018 the default is:\n  ml_enabled = true / ml_disabled = false.", "type": "boolean" }, "parameters": { "description": "Optional. The collection of parameters associated with the intent.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentParameter" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentTrainingPhrase" } }, "parentFollowupIntentName": { "description": "Read-only after creation. The unique identifier of the parent intent in the\nchain of followup intents. You can set this field when creating an intent,\nfor example with CreateIntent or BatchUpdateIntents, in order to\nmake this intent a followup intent.\n\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "priority": { "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. If this is zero or unspecified, we use the default\npriority 500000.\n\nNegative numbers mean that the intent is disabled.", "format": "int32", "type": "integer" }, "endInteraction": { "description": "Optional. Indicates that this intent ends an interaction. Some integrations\n(e.g., Actions on Google or Dialogflow phone gateway) use this information\nto close interaction with an end user. Default is false.", "type": "boolean" }, "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1Context" } }, "defaultResponsePlatforms": { "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway.", "Google Hangouts."], "description": "Optional. The list of platforms for which the first responses will be\ncopied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform).", "type": "array", "items": { "type": "string", "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY", "GOOGLE_HANGOUTS"] } }, "name": { "description": "The unique identifier of this intent.\nRequired for Intents.UpdateIntent and Intents.BatchUpdateIntents\nmethods.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "messages": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessage" }, "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console." }, "inputContextNames": { "type": "array", "items": { "type": "string" }, "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`." }, "webhookState": { "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"], "description": "Optional. Indicates whether webhooks are enabled for the intent.", "type": "string", "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."] }, "followupIntentInfo": { "description": "Read-only. Information about all followup intents that have this intent as\na direct or indirect parent. We populate this field only in the output.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentFollowupIntentInfo" } } } }, "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse": { "id": "GoogleCloudDialogflowV2beta1BatchUpdateEntityTypesResponse", "description": "The response message for EntityTypes.BatchUpdateEntityTypes.", "type": "object", "properties": { "entityTypes": { "description": "The collection of updated or created entity types.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1EntityType" } } } }, "GoogleCloudDialogflowV2IntentMessageSuggestion": { "id": "GoogleCloudDialogflowV2IntentMessageSuggestion", "description": "The suggestion chip message that the user can tap to quickly post a reply\nto the conversation.", "type": "object", "properties": { "title": { "type": "string", "description": "Required. The text shown the in the suggestion chip." } } }, "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart": { "type": "object", "properties": { "alias": { "type": "string", "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.\nThis field is required for annotated parts of the training phrase." }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated.\nThis field is set to true when the Dialogflow Console is used to\nmanually annotate the part. When creating an annotated part with the\nAPI, you must set this to true.", "type": "boolean" }, "text": { "description": "Required. The text for this part.", "type": "string" }, "entityType": { "description": "Optional. The entity type name prefixed with `@`.\nThis field is required for annotated parts of the training phrase.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentTrainingPhrasePart", "description": "Represents a part of a training phrase." }, "GoogleCloudDialogflowV2beta1EventInput": { "id": "GoogleCloudDialogflowV2beta1EventInput", "description": "Events allow for matching intents by event name instead of the natural\nlanguage input. For instance, input `<event: { name: \"welcome_event\",\nparameters: { name: \"Sam\" } }>` can trigger a personalized welcome response.\nThe parameter `name` may be used by the agent in the response:\n`\"Hello #welcome_event.name! What can I do for you today?\"`.", "type": "object", "properties": { "languageCode": { "description": "Required. The language of this query. See [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes. Note that queries in\nthe same session do not necessarily need to specify the same language.", "type": "string" }, "name": { "description": "Required. The unique identifier of the event.", "type": "string" }, "parameters": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "Optional. The collection of parameters associated with the event." } } }, "GoogleCloudDialogflowV2InputAudioConfig": { "type": "object", "properties": { "phraseHints": { "type": "array", "items": { "type": "string" }, "description": "Optional. A list of strings containing words and phrases that the speech\nrecognizer should recognize with higher likelihood.\n\nSee [the Cloud Speech\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics#phrase-hints)\nfor more details." }, "audioEncoding": { "enum": ["AUDIO_ENCODING_UNSPECIFIED", "AUDIO_ENCODING_LINEAR_16", "AUDIO_ENCODING_FLAC", "AUDIO_ENCODING_MULAW", "AUDIO_ENCODING_AMR", "AUDIO_ENCODING_AMR_WB", "AUDIO_ENCODING_OGG_OPUS", "AUDIO_ENCODING_SPEEX_WITH_HEADER_BYTE"], "description": "Required. Audio encoding of the audio content to process.", "type": "string", "enumDescriptions": ["Not specified.", "Uncompressed 16-bit signed little-endian samples (Linear PCM).", "[`FLAC`](https://xiph.org/flac/documentation.html) (Free Lossless Audio\nCodec) is the recommended encoding because it is lossless (therefore\nrecognition is not compromised) and requires only about half the\nbandwidth of `LINEAR16`. `FLAC` stream encoding supports 16-bit and\n24-bit samples, however, not all fields in `STREAMINFO` are supported.", "8-bit samples that compand 14-bit audio samples using G.711 PCMU/mu-law.", "Adaptive Multi-Rate Narrowband codec. `sample_rate_hertz` must be 8000.", "Adaptive Multi-Rate Wideband codec. `sample_rate_hertz` must be 16000.", "Opus encoded audio frames in Ogg container\n([OggOpus](https://wiki.xiph.org/OggOpus)).\n`sample_rate_hertz` must be 16000.", "Although the use of lossy encodings is not recommended, if a very low\nbitrate encoding is required, `OGG_OPUS` is highly preferred over\nSpeex encoding. The [Speex](https://speex.org/) encoding supported by\nDialogflow API has a header byte in each block, as in MIME type\n`audio/x-speex-with-header-byte`.\nIt is a variant of the RTP Speex encoding defined in\n[RFC 5574](https://tools.ietf.org/html/rfc5574).\nThe stream is a sequence of blocks, one block per RTP packet. Each block\nstarts with a byte containing the length of the block, in bytes, followed\nby one or more frames of Speex data, padded to an integral number of\nbytes (octets) as specified in RFC 5574. In other words, each RTP header\nis replaced with a single byte containing the block length. Only Speex\nwideband is supported. `sample_rate_hertz` must be 16000."] }, "sampleRateHertz": { "description": "Required. Sample rate (in Hertz) of the audio content sent in the query.\nRefer to\n[Cloud Speech API\ndocumentation](https://cloud.google.com/speech-to-text/docs/basics) for\nmore details.", "format": "int32", "type": "integer" }, "modelVariant": { "enum": ["SPEECH_MODEL_VARIANT_UNSPECIFIED", "USE_BEST_AVAILABLE", "USE_STANDARD", "USE_ENHANCED"], "description": "Optional. Which variant of the Speech model to use.", "type": "string", "enumDescriptions": ["No model variant specified. In this case Dialogflow defaults to\nUSE_BEST_AVAILABLE.", "Use the best available variant of the Speech\nmodel that the caller is eligible for.\n\nPlease see the [Dialogflow\ndocs](https://cloud.google.com/dialogflow/docs/data-logging) for\nhow to make your project eligible for enhanced models.", "Use standard model variant even if an enhanced model is available.  See the\n[Cloud Speech\ndocumentation](https://cloud.google.com/speech-to-text/docs/enhanced-models)\nfor details about enhanced models.", "Use an enhanced model variant:\n\n* If an enhanced variant does not exist for the given\n  model and request language, Dialogflow falls\n  back to the standard variant.\n\n  The [Cloud Speech\n  documentation](https://cloud.google.com/speech-to-text/docs/enhanced-models)\n  describes which models have enhanced variants.\n\n* If the API caller isn't eligible for enhanced models, Dialogflow returns\n  an error. Please see the [Dialogflow\n  docs](https://cloud.google.com/dialogflow/docs/data-logging)\n  for how to make your project eligible."] }, "languageCode": { "type": "string", "description": "Required. The language of the supplied audio. Dialogflow does not do\ntranslations. See [Language\nSupport](https://cloud.google.com/dialogflow/docs/reference/language)\nfor a list of the currently supported language codes. Note that queries in\nthe same session do not necessarily need to specify the same language." } }, "id": "GoogleCloudDialogflowV2InputAudioConfig", "description": "Instructs the speech recognizer how to process the audio content." }, "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem": { "type": "object", "properties": { "title": { "description": "Required. The title of the list item.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image to display." }, "description": { "description": "Optional. The main text describing the item.", "type": "string" }, "info": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSelectItemInfo", "description": "Required. Additional information about this option." } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageListSelectItem", "description": "An item in the list." }, "GoogleCloudDialogflowV2IntentTrainingPhrasePart": { "id": "GoogleCloudDialogflowV2IntentTrainingPhrasePart", "description": "Represents a part of a training phrase.", "type": "object", "properties": { "alias": { "description": "Optional. The parameter name for the value extracted from the\nannotated part of the example.\nThis field is required for annotated parts of the training phrase.", "type": "string" }, "userDefined": { "description": "Optional. Indicates whether the text was manually annotated.\nThis field is set to true when the Dialogflow Console is used to\nmanually annotate the part. When creating an annotated part with the\nAPI, you must set this to true.", "type": "boolean" }, "text": { "type": "string", "description": "Required. The text for this part." }, "entityType": { "description": "Optional. The entity type name prefixed with `@`.\nThis field is required for annotated parts of the training phrase.", "type": "string" } } }, "GoogleCloudDialogflowV2BatchUpdateIntentsRequest": { "description": "The request message for Intents.BatchUpdateIntents.", "type": "object", "properties": { "intentBatchUri": { "type": "string", "description": "The URI to a Google Cloud Storage file containing intents to update or\ncreate. The file format can either be a serialized proto (of IntentBatch\ntype) or JSON object. Note: The URI must start with \"gs://\"." }, "intentView": { "enumDescriptions": ["Training phrases field is not populated in the response.", "All fields are populated."], "enum": ["INTENT_VIEW_UNSPECIFIED", "INTENT_VIEW_FULL"], "description": "Optional. The resource view to apply to the returned intent.", "type": "string" }, "intentBatchInline": { "$ref": "GoogleCloudDialogflowV2IntentBatch", "description": "The collection of intents to update or create." }, "languageCode": { "description": "Optional. The language of training phrases, parameters and rich messages\ndefined in `intents`. If not specified, the agent's default language is\nused. [Many\nlanguages](https://cloud.google.com/dialogflow/docs/reference/language)\nare supported. Note: languages must be enabled in the agent before they can\nbe used.", "type": "string" }, "updateMask": { "description": "Optional. The mask to control which fields get updated.", "format": "google-fieldmask", "type": "string" } }, "id": "GoogleCloudDialogflowV2BatchUpdateIntentsRequest" }, "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata": { "id": "GoogleCloudDialogflowV2beta1KnowledgeOperationMetadata", "description": "Metadata in google::longrunning::Operation for Knowledge operations.", "type": "object", "properties": { "state": { "description": "Required. The current state of this operation.", "type": "string", "enumDescriptions": ["State unspecified.", "The operation has been created.", "The operation is currently running.", "The operation is done, either cancelled or completed."], "enum": ["STATE_UNSPECIFIED", "PENDING", "RUNNING", "DONE"] } } }, "GoogleCloudDialogflowV2beta1IntentMessage": { "description": "Corresponds to the `Response` field in the Dialogflow console.", "type": "object", "properties": { "quickReplies": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageQuickReplies", "description": "Displays quick replies." }, "telephonySynthesizeSpeech": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonySynthesizeSpeech", "description": "Synthesizes speech in Telephony Gateway." }, "card": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCard", "description": "Displays a card." }, "basicCard": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard", "description": "Displays a basic card for Actions on Google." }, "carouselSelect": { "description": "Displays a carousel card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageCarouselSelect" }, "linkOutSuggestion": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion", "description": "Displays a link out suggestion chip for Actions on Google." }, "simpleResponses": { "description": "Returns a voice or text-only response for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSimpleResponses" }, "telephonyTransferCall": { "description": "Transfers the call in Telephony Gateway.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyTransferCall" }, "image": { "description": "Displays an image.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage" }, "payload": { "additionalProperties": { "type": "any", "description": "Properties of the object." }, "description": "Returns a response containing a custom, platform-specific payload.\nSee the Intent.Message.Platform type for a description of the\nstructure that may be required for your platform.", "type": "object" }, "text": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageText", "description": "Returns a text response." }, "platform": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "TELEPHONY", "GOOGLE_HANGOUTS"], "description": "Optional. The platform that this message is intended for.", "type": "string", "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Telephony Gateway.", "Google Hangouts."] }, "suggestions": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageSuggestions", "description": "Displays suggestion chips for Actions on Google." }, "telephonyPlayAudio": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageTelephonyPlayAudio", "description": "Plays audio from a file in Telephony Gateway." }, "listSelect": { "description": "Displays a list card for Actions on Google.", "$ref": "GoogleCloudDialogflowV2beta1IntentMessageListSelect" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessage" }, "GoogleCloudDialogflowV2Intent": { "id": "GoogleCloudDialogflowV2Intent", "description": "Represents an intent.\nIntents convert a number of user expressions or patterns into an action. An\naction is an extraction of a user command or sentence semantics.", "type": "object", "properties": { "displayName": { "description": "Required. The name of this intent.", "type": "string" }, "rootFollowupIntentName": { "description": "Read-only. The unique identifier of the root intent in the chain of\nfollowup intents. It identifies the correct followup intents chain for\nthis intent. We populate this field only in the output.\n\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "mlDisabled": { "description": "Optional. Indicates whether Machine Learning is disabled for the intent.\nNote: If `ml_diabled` setting is set to true, then this intent is not\ntaken into account during inference in `ML ONLY` match mode. Also,\nauto-markup in the UI is turned off.", "type": "boolean" }, "isFallback": { "description": "Optional. Indicates whether this is a fallback intent.", "type": "boolean" }, "trainingPhrases": { "description": "Optional. The collection of examples that the agent is\ntrained on.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentTrainingPhrase" } }, "resetContexts": { "description": "Optional. Indicates whether to delete all contexts in the current\nsession when this intent is matched.", "type": "boolean" }, "parameters": { "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentParameter" }, "description": "Optional. The collection of parameters associated with the intent." }, "events": { "description": "Optional. The collection of event names that trigger the intent.\nIf the collection of input contexts is not empty, all of the contexts must\nbe present in the active user session for an event to trigger this intent.", "type": "array", "items": { "type": "string" } }, "parentFollowupIntentName": { "description": "Read-only after creation. The unique identifier of the parent intent in the\nchain of followup intents. You can set this field when creating an intent,\nfor example with CreateIntent or BatchUpdateIntents, in order to\nmake this intent a followup intent.\n\nIt identifies the parent followup intent.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "priority": { "type": "integer", "description": "Optional. The priority of this intent. Higher numbers represent higher\npriorities. If this is zero or unspecified, we use the default\npriority 500000.\n\nNegative numbers mean that the intent is disabled.", "format": "int32" }, "outputContexts": { "description": "Optional. The collection of contexts that are activated when the intent\nis matched. Context messages in this collection should not set the\nparameters field. Setting the `lifespan_count` to 0 will reset the context\nwhen the intent is matched.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2Context" } }, "defaultResponsePlatforms": { "type": "array", "items": { "enum": ["PLATFORM_UNSPECIFIED", "FACEBOOK", "SLACK", "TELEGRAM", "KIK", "SKYPE", "LINE", "VIBER", "ACTIONS_ON_GOOGLE", "GOOGLE_HANGOUTS"], "type": "string" }, "enumDescriptions": ["Not specified.", "Facebook.", "Slack.", "Telegram.", "Kik.", "Skype.", "Line.", "Viber.", "Actions on Google.\nWhen using Actions on Google, you can choose one of the specific\nIntent.Message types that mention support for Actions on Google,\nor you can use the advanced Intent.Message.payload field.\nThe payload field provides access to AoG features not available in the\nspecific message types.\nIf using the Intent.Message.payload field, it should have a structure\nsimilar to the JSON message shown here. For more information, see\n[Actions on Google Webhook\nFormat](https://developers.google.com/actions/dialogflow/webhook)\n<pre>{\n  \"expectUserResponse\": true,\n  \"isSsml\": false,\n  \"noInputPrompts\": [],\n  \"richResponse\": {\n    \"items\": [\n      {\n        \"simpleResponse\": {\n          \"displayText\": \"hi\",\n          \"textToSpeech\": \"hello\"\n        }\n      }\n    ],\n    \"suggestions\": [\n      {\n        \"title\": \"Say this\"\n      },\n      {\n        \"title\": \"or this\"\n      }\n    ]\n  },\n  \"systemIntent\": {\n    \"data\": {\n      \"@type\": \"type.googleapis.com/google.actions.v2.OptionValueSpec\",\n      \"listSelect\": {\n        \"items\": [\n          {\n            \"optionInfo\": {\n              \"key\": \"key1\",\n              \"synonyms\": [\n                \"key one\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          },\n          {\n            \"optionInfo\": {\n              \"key\": \"key2\",\n              \"synonyms\": [\n                \"key two\"\n              ]\n            },\n            \"title\": \"must not be empty, but unique\"\n          }\n        ]\n      }\n    },\n    \"intent\": \"actions.intent.OPTION\"\n  }\n}</pre>", "Google Hangouts."], "description": "Optional. The list of platforms for which the first responses will be\ncopied from the messages in PLATFORM_UNSPECIFIED (i.e. default platform)." }, "messages": { "description": "Optional. The collection of rich messages corresponding to the\n`Response` field in the Dialogflow console.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentMessage" } }, "name": { "description": "The unique identifier of this intent.\nRequired for Intents.UpdateIntent and Intents.BatchUpdateIntents\nmethods.\nFormat: `projects/<Project ID>/agent/intents/<Intent ID>`.", "type": "string" }, "action": { "description": "Optional. The name of the action associated with the intent.\nNote: The action name must not contain whitespaces.", "type": "string" }, "webhookState": { "enumDescriptions": ["Webhook is disabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent.", "Webhook is enabled in the agent and in the intent. Also, each slot\nfilling prompt is forwarded to the webhook."], "enum": ["WEBHOOK_STATE_UNSPECIFIED", "WEBHOOK_STATE_ENABLED", "WEBHOOK_STATE_ENABLED_FOR_SLOT_FILLING"], "description": "Optional. Indicates whether webhooks are enabled for the intent.", "type": "string" }, "inputContextNames": { "description": "Optional. The list of context names required for this intent to be\ntriggered.\nFormat: `projects/<Project ID>/agent/sessions/-/contexts/<Context ID>`.", "type": "array", "items": { "type": "string" } }, "followupIntentInfo": { "description": "Read-only. Information about all followup intents that have this intent as\na direct or indirect parent. We populate this field only in the output.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2IntentFollowupIntentInfo" } } } }, "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion": { "type": "object", "properties": { "uri": { "description": "Required. The URI of the app or site to open when the user taps the\nsuggestion chip.", "type": "string" }, "destinationName": { "description": "Required. The name of the app or site this chip is linking to.", "type": "string" } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageLinkOutSuggestion", "description": "The suggestion chip message that allows the user to jump out to the app\nor website associated with this agent." }, "GoogleCloudDialogflowV2beta1IntentParameter": { "id": "GoogleCloudDialogflowV2beta1IntentParameter", "description": "Represents intent parameters.", "type": "object", "properties": { "mandatory": { "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue.", "type": "boolean" }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" }, "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" }, "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" }, "prompts": { "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect a value for the parameter.", "type": "array", "items": { "type": "string" } } } }, "GoogleCloudDialogflowV2IntentParameter": { "description": "Represents intent parameters.", "type": "object", "properties": { "value": { "description": "Optional. The definition of the parameter value. It can be:\n- a constant string,\n- a parameter value defined as `$parameter_name`,\n- an original parameter value defined as `$parameter_name.original`,\n- a parameter value from some context defined as\n  `#context_name.parameter_name`.", "type": "string" }, "displayName": { "description": "Required. The name of the parameter.", "type": "string" }, "entityTypeDisplayName": { "description": "Optional. The name of the entity type, prefixed with `@`, that\ndescribes values of the parameter. If the parameter is\nrequired, this must be provided.", "type": "string" }, "prompts": { "description": "Optional. The collection of prompts that the agent can present to the\nuser in order to collect a value for the parameter.", "type": "array", "items": { "type": "string" } }, "defaultValue": { "description": "Optional. The default value to use when the `value` yields an empty\nresult.\nDefault values can be extracted from contexts by using the following\nsyntax: `#context_name.parameter_name`.", "type": "string" }, "mandatory": { "description": "Optional. Indicates whether the parameter is required. That is,\nwhether the intent cannot be completed without collecting the parameter\nvalue.", "type": "boolean" }, "name": { "description": "The unique identifier of this parameter.", "type": "string" }, "isList": { "description": "Optional. Indicates whether the parameter represents a list of values.", "type": "boolean" } }, "id": "GoogleCloudDialogflowV2IntentParameter" }, "GoogleRpcStatus": { "id": "GoogleRpcStatus", "description": "The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).", "type": "object", "properties": { "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "type": "object", "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." } } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" } } }, "GoogleCloudDialogflowV2beta1IntentMessageBasicCard": { "description": "The basic card message. Useful for displaying information.", "type": "object", "properties": { "subtitle": { "type": "string", "description": "Optional. The subtitle of the card." }, "title": { "description": "Optional. The title of the card.", "type": "string" }, "image": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageImage", "description": "Optional. The image for the card." }, "formattedText": { "description": "Required, unless image is present. The body text of the card.", "type": "string" }, "buttons": { "description": "Optional. The collection of card buttons.", "type": "array", "items": { "$ref": "GoogleCloudDialogflowV2beta1IntentMessageBasicCardButton" } } }, "id": "GoogleCloudDialogflowV2beta1IntentMessageBasicCard" } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "Dialogflow", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/dialogflow": { "description": "View, manage and query your Dialogflow agents" }, "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://dialogflow.googleapis.com/", "ownerDomain": "google.com", "name": "dialogflow" };
//# sourceMappingURL=dialogflow-v2.js.map