"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "schemas": { "ExecuteStreamResponse": { "description": "The response for executing or debugging a function in an Apps Script project.", "type": "object", "properties": { "result": { "description": "The result of the execution.\nTODO (johnlattin): Add debugging and logging.", "$ref": "ScriptExecutionResult" } }, "id": "ExecuteStreamResponse" }, "ListVersionsResponse": { "id": "ListVersionsResponse", "description": "Response with the list of the versions for the specified script project.", "type": "object", "properties": { "versions": { "description": "The list of versions.", "type": "array", "items": { "$ref": "Version" } }, "nextPageToken": { "description": "The token use to fetch the next page of records. if not exist in the\nresponse, that means no more versions to list.", "type": "string" } } }, "Metrics": { "description": "Resource containing usage stats for a given script, based on the supplied\nfilter and mask present in the request.", "type": "object", "properties": { "activeUsers": { "description": "Number of active users.", "type": "array", "items": { "$ref": "MetricsValue" } }, "totalExecutions": { "description": "Number of total executions.", "type": "array", "items": { "$ref": "MetricsValue" } }, "failedExecutions": { "type": "array", "items": { "$ref": "MetricsValue" }, "description": "Number of failed executions." } }, "id": "Metrics" }, "GoogleAppsScriptTypeFunctionSet": { "type": "object", "properties": { "values": { "description": "A list of functions composing the set.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeFunction" } } }, "id": "GoogleAppsScriptTypeFunctionSet", "description": "A set of functions. No duplicates are permitted." }, "Content": { "description": "The Content resource.", "type": "object", "properties": { "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "files": { "description": "The list of script project files.\nOne of the files is a script manifest; it must be named \"appsscript\",\nmust have type of JSON, and include the manifest configurations for the\nproject.", "type": "array", "items": { "$ref": "File" } } }, "id": "Content" }, "GoogleAppsScriptTypeWebAppEntryPoint": { "type": "object", "properties": { "url": { "description": "The URL for the web application.", "type": "string" }, "entryPointConfig": { "$ref": "GoogleAppsScriptTypeWebAppConfig", "description": "The entry point's configuration." } }, "id": "GoogleAppsScriptTypeWebAppEntryPoint", "description": "A web application entry point." }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "ListValue": { "description": "`ListValue` is a wrapper around a repeated field of values.\nBased on LustValue at:\ngoogle3/apps/maestro/api/struct.proto?q=message%5c%20ListValue", "type": "object", "properties": { "values": { "description": "Repeated field of dynamically typed values.", "type": "array", "items": { "$ref": "Value" } } }, "id": "ListValue" }, "UpdateDeploymentRequest": { "description": "Request with deployment information to update an existing deployment.", "type": "object", "properties": { "deploymentConfig": { "$ref": "DeploymentConfig", "description": "The deployment configuration." } }, "id": "UpdateDeploymentRequest" }, "GoogleAppsScriptTypeExecutionApiEntryPoint": { "description": "An API executable entry point.", "type": "object", "properties": { "entryPointConfig": { "$ref": "GoogleAppsScriptTypeExecutionApiConfig", "description": "The entry point's configuration." } }, "id": "GoogleAppsScriptTypeExecutionApiEntryPoint" }, "ExecutionError": { "description": "An object that provides information about the nature of an error resulting\nfrom an attempted execution of a script function using the Apps Script API.\nIf a run call\nsucceeds but the script function (or Apps Script itself) throws an exception,\nthe response body's error field\ncontains a\nStatus object. The `Status` object's `details` field\ncontains an array with a single one of these `ExecutionError` objects.", "type": "object", "properties": { "errorType": { "description": "The error type, for example `TypeError` or `ReferenceError`. If the error\ntype is unavailable, this field is not included.", "type": "string" }, "errorMessage": { "description": "The error message thrown by Apps Script, usually localized into the user's\nlanguage.", "type": "string" }, "scriptStackTraceElements": { "description": "An array of objects that provide a stack trace through the script to show\nwhere the execution failed, with the deepest call first.", "type": "array", "items": { "$ref": "ScriptStackTraceElement" } } }, "id": "ExecutionError" }, "ListUserProcessesResponse": { "description": "Response with the list of\nProcess resources.", "type": "object", "properties": { "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } }, "nextPageToken": { "description": "Token for the next page of results. If empty, there are no more pages\nremaining.", "type": "string" } }, "id": "ListUserProcessesResponse" }, "GoogleAppsScriptTypeUser": { "description": "A simple user profile resource.", "type": "object", "properties": { "email": { "description": "The user's identifying email address.", "type": "string" }, "name": { "description": "The user's display name.", "type": "string" }, "domain": { "description": "The user's domain.", "type": "string" }, "photoUrl": { "description": "The user's photo.", "type": "string" } }, "id": "GoogleAppsScriptTypeUser" }, "EntryPoint": { "id": "EntryPoint", "description": "A configuration that defines how a deployment is accessed externally.", "type": "object", "properties": { "addOn": { "$ref": "GoogleAppsScriptTypeAddOnEntryPoint", "description": "Add-on properties." }, "webApp": { "$ref": "GoogleAppsScriptTypeWebAppEntryPoint", "description": "An entry point specification for web apps." }, "executionApi": { "$ref": "GoogleAppsScriptTypeExecutionApiEntryPoint", "description": "An entry point specification for Apps Script API execution calls." }, "entryPointType": { "description": "The type of the entry point.", "type": "string", "enumDescriptions": ["An unspecified entry point.", "A web application entry point.", "An API executable entry point.", "An Add-On entry point."], "enum": ["ENTRY_POINT_TYPE_UNSPECIFIED", "WEB_APP", "EXECUTION_API", "ADD_ON"] } } }, "ExecutionRequest": { "description": "A request to run the function in a script. The script is identified by the\nspecified `script_id`. Executing a function on a script returns results\nbased on the implementation of the script.", "type": "object", "properties": { "sessionState": { "description": "<b>Deprecated</b>. For use with Android add-ons only. An ID that represents\nthe user's current session in the Android app for Google Docs or Sheets,\nincluded as extra data in the\n[Intent](https://developer.android.com/guide/components/intents-filters.html)\nthat launches the add-on. When an Android add-on is run with a session\nstate, it gains the privileges of a\n[bound](https://developers.google.com/apps-script/guides/bound)\nscript&mdash;that is, it can access information like the user's current\ncursor position (in Docs) or selected cell (in Sheets). To retrieve the\nstate, call\n`Intent.getStringExtra(\"com.google.android.apps.docs.addons.SessionState\")`.\nOptional.", "type": "string" }, "function": { "description": "The name of the function to execute in the given script. The name does not\ninclude parentheses or parameters. It can reference a function in an\nincluded library such as `Library.libFunction1`.", "type": "string" }, "devMode": { "description": "If `true` and the user is an owner of the script, the script runs at the\nmost recently saved version rather than the version deployed for use with\nthe Apps Script API. Optional; default is `false`.", "type": "boolean" }, "parameters": { "description": "The parameters to be passed to the function being executed. The object type\nfor each parameter should match the expected type in Apps Script.\nParameters cannot be Apps Script-specific object types (such as a\n`Document` or a `Calendar`); they can only be primitive types such as\n`string`, `number`, `array`, `object`, or `boolean`. Optional.", "type": "array", "items": { "type": "any" } } }, "id": "ExecutionRequest" }, "Version": { "type": "object", "properties": { "versionNumber": { "description": "The incremental ID that is created by Apps Script when a version is\ncreated. This is system assigned number and is immutable once created.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "createTime": { "description": "When the version was created.", "format": "google-datetime", "type": "string" }, "description": { "description": "The description for this version.", "type": "string" } }, "id": "Version", "description": "A resource representing a script project version. A version is a \"snapshot\"\nof a script project and is similar to a read-only branched release. When\ncreating deployments, the version to use must be specified." }, "Value": { "description": "`Value` represents a dynamically typed value which is the outcome of an\nexecuted script\nBased on Value at:\ngoogle3/apps/maestro/api/struct.proto?q=message%5c%20Value", "type": "object", "properties": { "numberValue": { "description": "Represents a double value.", "format": "double", "type": "number" }, "bytesValue": { "description": "Represents raw byte values.", "format": "byte", "type": "string" }, "protoValue": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Represents a structured proto value.", "type": "object" }, "stringValue": { "description": "Represents a string value.", "type": "string" }, "dateValue": { "description": "Represents a date in ms since the epoch.", "format": "int64", "type": "string" }, "listValue": { "description": "Represents a repeated `Value`.", "$ref": "ListValue" }, "structValue": { "description": "Represents a structured value.", "$ref": "Struct" }, "nullValue": { "enum": ["NULL_VALUE"], "description": "Represents a null value.", "type": "string", "enumDescriptions": ["Null value."] }, "boolValue": { "description": "Represents a boolean value.", "type": "boolean" } }, "id": "Value" }, "GoogleAppsScriptTypeExecutionApiConfig": { "description": "API executable entry point configuration.", "type": "object", "properties": { "access": { "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"], "description": "Who has permission to run the API executable.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."] } }, "id": "GoogleAppsScriptTypeExecutionApiConfig" }, "DeploymentConfig": { "id": "DeploymentConfig", "description": "Metadata the defines how a deployment is configured.", "type": "object", "properties": { "versionNumber": { "description": "The version number on which this deployment is based.", "format": "int32", "type": "integer" }, "scriptId": { "description": "The script project's Drive ID.", "type": "string" }, "manifestFileName": { "description": "The manifest file name for this deployment.", "type": "string" }, "description": { "description": "The description for this deployment.", "type": "string" } } }, "GoogleAppsScriptTypeProcess": { "properties": { "userAccessLevel": { "enumDescriptions": ["User access level unspecified", "The user has no access.", "The user has read-only access.", "The user has write access.", "The user is an owner."], "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "The executing users access level to the script.", "type": "string" }, "processType": { "enumDescriptions": ["Unspecified type.", "The process was started from an add-on entry point.", "The process was started using the Apps Script API.", "The process was started from a time-based trigger.", "The process was started from an event-based trigger.", "The process was started from a web app entry point.", "The process was started using the Apps Script IDE.", "The process was started from a G Suite simple trigger.", "The process was started from a G Suite menu item.", "The process was started as a task in a batch job."], "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "The executions type.", "type": "string" }, "projectName": { "description": "Name of the script being executed.", "type": "string" }, "processStatus": { "type": "string", "enumDescriptions": ["Unspecified status.", "The process is currently running.", "The process has paused.", "The process has completed.", "The process was cancelled.", "The process failed.", "The process timed out.", "Process status unknown.", "The process is delayed, waiting for quota."], "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "The executions status." }, "duration": { "description": "Duration the execution spent executing.", "format": "google-duration", "type": "string" }, "functionName": { "description": "Name of the function the started the execution.", "type": "string" }, "startTime": { "description": "Time the execution started.", "format": "google-datetime", "type": "string" } }, "id": "GoogleAppsScriptTypeProcess", "description": "Representation of a single script process execution that was started from\nthe script editor, a trigger, an application, or using the Apps Script API.\nThis is distinct from the `Operation`\nresource, which only represents executions started via the Apps Script API.", "type": "object" }, "CreateProjectRequest": { "properties": { "parentId": { "description": "The Drive ID of a parent file that the created script project is bound to.\nThis is usually the ID of a Google Doc, Google Sheet, Google Form, or\nGoogle Slides file. If not set, a standalone script project is created.", "type": "string" }, "title": { "description": "The title for the project.", "type": "string" } }, "id": "CreateProjectRequest", "description": "Request to create a script project.", "type": "object" }, "Operation": { "description": "A representation of an execution of an Apps Script function started with run. The execution response does not arrive until the function finishes executing. The maximum execution runtime is listed in the [Apps Script quotas guide](/apps-script/guides/services/quotas#current_limitations). <p>After execution has started, it can have one of four outcomes:</p> <ul> <li> If the script function returns successfully, the\n  response field contains an\n  ExecutionResponse object\n  with the function's return value in the object's `result` field.</li>\n<li> If the script function (or Apps Script itself) throws an exception, the\n  error field contains a\n  Status object. The `Status` object's `details`\n  field contains an array with a single\n  ExecutionError object that\n  provides information about the nature of the error.</li>\n<li> If the execution has not yet completed,\n  the done field is `false` and\n  the neither the `response` nor `error` fields are present.</li>\n<li> If the `run` call itself fails (for example, because of a\n  malformed request or an authorization error), the method returns an HTTP\n  response code in the 4XX range with a different format for the response\n  body. Client libraries automatically convert a 4XX response into an\n  exception class.</li>\n</ul>", "type": "object", "properties": { "error": { "$ref": "Status", "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, this field contains a Status object. The `Status` object's `details` field contains an array with a single ExecutionError object that provides information about the nature of the error." }, "done": { "description": "This field indicates whether the script execution has completed. A completed execution has a populated `response` field containing the ExecutionResponse from function that was executed.", "type": "boolean" }, "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "If the script function returns successfully, this field contains an ExecutionResponse object with the function's return value.", "type": "object" } }, "id": "Operation" }, "Status": { "properties": { "message": { "description": "A developer-facing error message, which is in English. Any user-facing error message is localized and sent in the details field, or localized by the client.", "type": "string" }, "details": { "description": "An array that contains a single ExecutionError object that provides information about the nature of the error.", "type": "array", "items": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "type": "object" } }, "code": { "type": "integer", "description": "The status code. For this API, this value either: <ul> <li> 10, indicating a `SCRIPT_TIMEOUT` error,</li> <li> 3, indicating an `INVALID_ARGUMENT` error, or</li> <li> 1, indicating a `CANCELLED` execution.</li> </ul>", "format": "int32" } }, "id": "Status", "description": "If a `run` call succeeds but the script function (or Apps Script itself) throws an exception, the response body's error field contains this `Status` object.", "type": "object" }, "MetricsValue": { "description": "Metrics value that holds number of executions counted.", "type": "object", "properties": { "endTime": { "description": "Required field indicating the end time of the interval.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Required field indicating the start time of the interval.", "format": "google-datetime", "type": "string" }, "value": { "description": "Indicates the number of executions counted.", "format": "uint64", "type": "string" } }, "id": "MetricsValue" }, "GoogleAppsScriptTypeFunction": { "properties": { "name": { "description": "The function name in the script project.", "type": "string" } }, "id": "GoogleAppsScriptTypeFunction", "description": "Represents a function in a script project.", "type": "object" }, "ScriptExecutionResult": { "properties": { "returnValue": { "$ref": "Value", "description": "The returned value of the execution.\nTODO (johnlattin): Add HtmlResponse\nTODO (johnlattin): Add ExceptionResponse\nTODO (johlnattin): Add TextResponse" } }, "id": "ScriptExecutionResult", "description": "The result of an execution\nBased on ScriptExecutionResult at:\ngoogle3/apps/maestro/api/frontend_execution_common.proto?q=message%5c%20ScriptExecutionResult", "type": "object" }, "Deployment": { "type": "object", "properties": { "entryPoints": { "description": "The deployment's entry points.", "type": "array", "items": { "$ref": "EntryPoint" } }, "deploymentId": { "description": "The deployment ID for this deployment.", "type": "string" }, "deploymentConfig": { "description": "The deployment configuration.", "$ref": "DeploymentConfig" }, "updateTime": { "description": "Last modified date time stamp.", "format": "google-datetime", "type": "string" } }, "id": "Deployment", "description": "Representation of a single script deployment." }, "GoogleAppsScriptTypeAddOnEntryPoint": { "type": "object", "properties": { "title": { "description": "The add-on's required title.", "type": "string" }, "reportIssueUrl": { "description": "The add-on's optional report issue URL.", "type": "string" }, "postInstallTipUrl": { "description": "The add-on's required post install tip URL.", "type": "string" }, "description": { "description": "The add-on's optional description.", "type": "string" }, "addOnType": { "enumDescriptions": ["Default value, unknown add-on type.", "Add-on type for Gmail.", "Add-on type for Data Studio."], "enum": ["UNKNOWN_ADDON_TYPE", "GMAIL", "DATA_STUDIO"], "description": "The add-on's required list of supported container types.", "type": "string" }, "helpUrl": { "description": "The add-on's optional help URL.", "type": "string" } }, "id": "GoogleAppsScriptTypeAddOnEntryPoint", "description": "An add-on entry point." }, "ScriptStackTraceElement": { "id": "ScriptStackTraceElement", "description": "A stack trace through the script that shows where the execution failed.", "type": "object", "properties": { "lineNumber": { "description": "The line number where the script failed.", "format": "int32", "type": "integer" }, "function": { "description": "The name of the function that failed.", "type": "string" } } }, "ListScriptProcessesResponse": { "description": "Response with the list of\nProcess resources.", "type": "object", "properties": { "processes": { "description": "List of processes matching request parameters.", "type": "array", "items": { "$ref": "GoogleAppsScriptTypeProcess" } }, "nextPageToken": { "type": "string", "description": "Token for the next page of results. If empty, there are no more pages\nremaining." } }, "id": "ListScriptProcessesResponse" }, "GoogleAppsScriptTypeWebAppConfig": { "properties": { "access": { "enum": ["UNKNOWN_ACCESS", "MYSELF", "DOMAIN", "ANYONE", "ANYONE_ANONYMOUS"], "description": "Who has permission to run the web app.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "Only the user who deployed the web app or executable can access it.\nNote that this is not necessarily the owner of the script project.", "Only users in the same domain as the user who deployed the web app or\nexecutable can access it.", "Any logged in user can access the web app or executable.", "Any user, logged in or not, can access the web app or executable."] }, "executeAs": { "enum": ["UNKNOWN_EXECUTE_AS", "USER_ACCESSING", "USER_DEPLOYING"], "description": "Who to execute the web app as.", "type": "string", "enumDescriptions": ["Default value, should not be used.", "The script runs as the user accessing the web app.", "The script runs as the user who deployed the web app. Note that this is\nnot necessarily the owner of the script project."] } }, "id": "GoogleAppsScriptTypeWebAppConfig", "description": "Web app entry point configuration.", "type": "object" }, "Project": { "description": "The script project resource.", "type": "object", "properties": { "lastModifyUser": { "description": "User who last modified the script.", "$ref": "GoogleAppsScriptTypeUser" }, "parentId": { "description": "The parent's Drive ID that the script will be attached to. This is usually\nthe ID of a Google Document or Google Sheet. This filed is optional, and\nif not set, a stand-alone script will be created.", "type": "string" }, "createTime": { "type": "string", "description": "When the script was created.", "format": "google-datetime" }, "updateTime": { "description": "When the script was last updated.", "format": "google-datetime", "type": "string" }, "creator": { "$ref": "GoogleAppsScriptTypeUser", "description": "User who originally created the script." }, "scriptId": { "type": "string", "description": "The script project's Drive ID." }, "title": { "type": "string", "description": "The title for the project." } }, "id": "Project" }, "Struct": { "type": "object", "properties": { "fields": { "additionalProperties": { "$ref": "Value" }, "description": "Unordered map of dynamically typed values.", "type": "object" } }, "id": "Struct", "description": "`Struct` represents a structured data value, consisting of fields which map\nto dynamically typed values.\nBased on Struct at:\ngoogle3/apps/maestro/api/struct.proto?q=message%5c%20Struct" }, "ListDeploymentsResponse": { "type": "object", "properties": { "deployments": { "description": "The list of deployments.", "type": "array", "items": { "$ref": "Deployment" } }, "nextPageToken": { "description": "The token that can be used in the next call to get the next page of\nresults.", "type": "string" } }, "id": "ListDeploymentsResponse", "description": "Response with the list of deployments for the specified Apps Script project." }, "File": { "description": "An individual file within a script project.\nA file is a third-party source code created by one or more\ndevelopers. It can be a server-side JS code, HTML, or a\nconfiguration file. Each script project can contain multiple files.", "type": "object", "properties": { "createTime": { "description": "Creation date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "functionSet": { "description": "The defined set of functions in the script file, if any.", "$ref": "GoogleAppsScriptTypeFunctionSet" }, "updateTime": { "description": "Last modified date timestamp.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "format": "google-datetime", "type": "string" }, "name": { "type": "string", "description": "The name of the file. The file extension is not part of the file\nname, which can be identified from the type field." }, "type": { "description": "The type of the file.", "type": "string", "enumDescriptions": ["Undetermined file type; never actually used.", "An Apps Script server-side code file.", "A file containing client-side HTML.", "A file in JSON format. This type is only used for the script\nproject's manifest. The manifest file content must match the\nstructure of a valid\n[ScriptManifest](/apps-script/concepts/manifests)"], "enum": ["ENUM_TYPE_UNSPECIFIED", "SERVER_JS", "HTML", "JSON"] }, "source": { "description": "The file content.", "type": "string" }, "lastModifyUser": { "description": "The user who modified the file most recently.\nThis read-only field is only visible to users who have WRITER\npermission for the script project.", "$ref": "GoogleAppsScriptTypeUser" } }, "id": "File" }, "ExecutionResponse": { "id": "ExecutionResponse", "description": "An object that provides the return value of a function executed using the\nApps Script API. If the script function returns successfully, the response\nbody's response field contains this\n`ExecutionResponse` object.", "type": "object", "properties": { "result": { "description": "The return value of the script function. The type matches the object type\nreturned in Apps Script. Functions called using the Apps Script API cannot\nreturn Apps Script-specific objects (such as a `Document` or a `Calendar`);\nthey can only return primitive types such as a `string`, `number`, `array`,\n`object`, or `boolean`.", "type": "any" } } } }, "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "protocol": "rest", "canonicalName": "Script", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/script.metrics": { "description": "View Google Apps Script project's metrics" }, "https://www.googleapis.com/auth/groups": { "description": "View and manage your Google Groups" }, "https://www.googleapis.com/auth/script.deployments": { "description": "Create and update Google Apps Script deployments" }, "https://www.googleapis.com/auth/forms.currentonly": { "description": "View and manage forms that this application has been installed in" }, "https://www.googleapis.com/auth/script.processes": { "description": "View Google Apps Script processes" }, "https://www.googleapis.com/auth/script.deployments.readonly": { "description": "View Google Apps Script deployments" }, "https://www.googleapis.com/auth/spreadsheets": { "description": "See, edit, create, and delete your spreadsheets in Google Drive" }, "https://www.googleapis.com/auth/admin.directory.group": { "description": "View and manage the provisioning of groups on your domain" }, "https://www.googleapis.com/auth/forms": { "description": "View and manage your forms in Google Drive" }, "https://www.google.com/m8/feeds": { "description": "See, edit, download, and permanently delete your contacts" }, "https://www.googleapis.com/auth/documents": { "description": "View and manage your Google Docs documents" }, "https://www.google.com/calendar/feeds": { "description": "See, edit, share, and permanently delete all the calendars you can access using Google Calendar" }, "https://www.googleapis.com/auth/script.projects.readonly": { "description": "View Google Apps Script projects" }, "https://www.googleapis.com/auth/script.projects": { "description": "Create and update Google Apps Script projects" }, "https://www.googleapis.com/auth/drive": { "description": "See, edit, create, and delete all of your Google Drive files" }, "https://mail.google.com/": { "description": "Read, compose, send, and permanently delete all your email from Gmail" }, "https://www.googleapis.com/auth/admin.directory.user": { "description": "View and manage the provisioning of users on your domain" }, "https://www.googleapis.com/auth/userinfo.email": { "description": "View your email address" } } } }, "rootUrl": "https://script.googleapis.com/", "ownerDomain": "google.com", "name": "script", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Apps Script API", "ownerName": "Google", "resources": { "projects": { "methods": { "create": { "response": { "$ref": "Project" }, "parameterOrder": [], "httpMethod": "POST", "parameters": {}, "scopes": ["https://www.googleapis.com/auth/script.projects"], "flatPath": "v1/projects", "path": "v1/projects", "id": "script.projects.create", "description": "Creates a new, empty script project with no script files and a base\nmanifest file.", "request": { "$ref": "CreateProjectRequest" } }, "getContent": { "description": "Gets the content of the script project, including the code source and\nmetadata for each script file.", "response": { "$ref": "Content" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "parameters": { "versionNumber": { "description": "The version number of the project to retrieve. If not provided, the\nproject's HEAD version is returned.", "format": "int32", "type": "integer", "location": "query" }, "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}/content", "path": "v1/projects/{scriptId}/content", "id": "script.projects.getContent" }, "getMetrics": { "description": "Get metrics data for scripts, such as number of executions and\nactive users.", "httpMethod": "GET", "response": { "$ref": "Metrics" }, "parameterOrder": ["scriptId"], "parameters": { "metricsFilter.deploymentId": { "description": "Optional field indicating a specific deployment to retrieve metrics from.", "type": "string", "location": "query" }, "scriptId": { "description": "Required field indicating the script to get metrics for.", "required": true, "type": "string", "location": "path" }, "metricsGranularity": { "description": "Required field indicating what granularity of metrics are returned.", "type": "string", "location": "query", "enum": ["UNSPECIFIED_GRANULARITY", "WEEKLY", "DAILY"] } }, "scopes": ["https://www.googleapis.com/auth/script.metrics"], "flatPath": "v1/projects/{scriptId}/metrics", "id": "script.projects.getMetrics", "path": "v1/projects/{scriptId}/metrics" }, "get": { "flatPath": "v1/projects/{scriptId}", "path": "v1/projects/{scriptId}", "id": "script.projects.get", "description": "Gets a script project's metadata.", "response": { "$ref": "Project" }, "parameterOrder": ["scriptId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } } }, "updateContent": { "response": { "$ref": "Content" }, "parameterOrder": ["scriptId"], "httpMethod": "PUT", "scopes": ["https://www.googleapis.com/auth/script.projects"], "parameters": { "scriptId": { "required": true, "type": "string", "location": "path", "description": "The script project's Drive ID." } }, "flatPath": "v1/projects/{scriptId}/content", "path": "v1/projects/{scriptId}/content", "id": "script.projects.updateContent", "request": { "$ref": "Content" }, "description": "Updates the content of the specified script project.\nThis content is stored as the HEAD version, and is used when the script is\nexecuted as a trigger, in the script editor, in add-on preview mode, or as\na web app or Apps Script API in development mode. This clears all the\nexisting files in the project." } }, "resources": { "deployments": { "methods": { "create": { "flatPath": "v1/projects/{scriptId}/deployments", "path": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.create", "request": { "$ref": "DeploymentConfig" }, "description": "Creates a deployment of an Apps Script project.", "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/script.deployments"], "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } } }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/script.deployments"], "parameters": { "deploymentId": { "required": true, "type": "string", "location": "path", "description": "The deployment ID to be undeployed." }, "scriptId": { "required": true, "type": "string", "location": "path", "description": "The script project's Drive ID." } }, "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.delete", "description": "Deletes a deployment of an Apps Script project." }, "get": { "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/script.deployments", "https://www.googleapis.com/auth/script.deployments.readonly"], "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" }, "deploymentId": { "location": "path", "description": "The deployment ID.", "required": true, "type": "string" } }, "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.get", "description": "Gets a deployment of an Apps Script project." }, "list": { "httpMethod": "GET", "parameterOrder": ["scriptId"], "response": { "$ref": "ListDeploymentsResponse" }, "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" }, "pageToken": { "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string", "location": "query" }, "pageSize": { "description": "The maximum number of deployments on each returned page. Defaults to 50.", "format": "int32", "type": "integer", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/script.deployments", "https://www.googleapis.com/auth/script.deployments.readonly"], "flatPath": "v1/projects/{scriptId}/deployments", "id": "script.projects.deployments.list", "path": "v1/projects/{scriptId}/deployments", "description": "Lists the deployments of an Apps Script project." }, "update": { "response": { "$ref": "Deployment" }, "parameterOrder": ["scriptId", "deploymentId"], "httpMethod": "PUT", "parameters": { "deploymentId": { "location": "path", "description": "The deployment ID for this deployment.", "required": true, "type": "string" }, "scriptId": { "description": "The script project's Drive ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/script.deployments"], "flatPath": "v1/projects/{scriptId}/deployments/{deploymentId}", "path": "v1/projects/{scriptId}/deployments/{deploymentId}", "id": "script.projects.deployments.update", "description": "Updates a deployment of an Apps Script project.", "request": { "$ref": "UpdateDeploymentRequest" } } } }, "versions": { "methods": { "create": { "description": "Creates a new immutable version using the current code, with a unique\nversion number.", "request": { "$ref": "Version" }, "response": { "$ref": "Version" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.projects"], "flatPath": "v1/projects/{scriptId}/versions", "path": "v1/projects/{scriptId}/versions", "id": "script.projects.versions.create" }, "get": { "response": { "$ref": "Version" }, "parameterOrder": ["scriptId", "versionNumber"], "httpMethod": "GET", "parameters": { "versionNumber": { "location": "path", "description": "The version number.", "format": "int32", "required": true, "type": "integer" }, "scriptId": { "location": "path", "description": "The script project's Drive ID.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "flatPath": "v1/projects/{scriptId}/versions/{versionNumber}", "path": "v1/projects/{scriptId}/versions/{versionNumber}", "id": "script.projects.versions.get", "description": "Gets a version of a script project." }, "list": { "description": "List the versions of a script project.", "httpMethod": "GET", "parameterOrder": ["scriptId"], "response": { "$ref": "ListVersionsResponse" }, "scopes": ["https://www.googleapis.com/auth/script.projects", "https://www.googleapis.com/auth/script.projects.readonly"], "parameters": { "scriptId": { "required": true, "type": "string", "location": "path", "description": "The script project's Drive ID." }, "pageToken": { "type": "string", "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response." }, "pageSize": { "type": "integer", "location": "query", "description": "The maximum number of versions on each returned page. Defaults to 50.", "format": "int32" } }, "flatPath": "v1/projects/{scriptId}/versions", "id": "script.projects.versions.list", "path": "v1/projects/{scriptId}/versions" } } } } }, "processes": { "methods": { "listScriptProcesses": { "path": "v1/processes:listScriptProcesses", "id": "script.processes.listScriptProcesses", "description": "List information about a script's executed processes, such as process type\nand current status.", "response": { "$ref": "ListScriptProcessesResponse" }, "parameterOrder": [], "httpMethod": "GET", "parameters": { "scriptProcessFilter.endTime": { "location": "query", "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string" }, "scriptProcessFilter.userAccessLevels": { "repeated": true, "location": "query", "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string" }, "scriptProcessFilter.statuses": { "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string", "repeated": true, "location": "query", "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"] }, "scriptProcessFilter.startTime": { "location": "query", "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string" }, "scriptProcessFilter.functionName": { "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string", "location": "query" }, "scriptProcessFilter.deploymentId": { "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID.", "type": "string", "location": "query" }, "scriptId": { "description": "The script ID of the project whose processes are listed.", "type": "string", "location": "query" }, "scriptProcessFilter.types": { "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string", "repeated": true }, "pageToken": { "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/script.processes"], "flatPath": "v1/processes:listScriptProcesses" }, "list": { "parameters": { "userProcessFilter.deploymentId": { "type": "string", "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific deployment ID." }, "userProcessFilter.endTime": { "location": "query", "description": "Optional field used to limit returned processes to those that completed\non or before the given timestamp.", "format": "google-datetime", "type": "string" }, "pageToken": { "location": "query", "description": "The token for continuing a previous list request on the next page. This\nshould be set to the value of `nextPageToken` from a previous response.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of returned processes per page of results. Defaults to\n50.", "format": "int32", "type": "integer" }, "userProcessFilter.startTime": { "description": "Optional field used to limit returned processes to those that were\nstarted on or after the given timestamp.", "format": "google-datetime", "type": "string", "location": "query" }, "userProcessFilter.userAccessLevels": { "location": "query", "enum": ["USER_ACCESS_LEVEL_UNSPECIFIED", "NONE", "READ", "WRITE", "OWNER"], "description": "Optional field used to limit returned processes to those having one of\nthe specified user access levels.", "type": "string", "repeated": true }, "userProcessFilter.projectName": { "location": "query", "description": "Optional field used to limit returned processes to those originating from\nprojects with project names containing a specific string.", "type": "string" }, "userProcessFilter.functionName": { "description": "Optional field used to limit returned processes to those originating from\na script function with the given function name.", "type": "string", "location": "query" }, "userProcessFilter.scriptId": { "description": "Optional field used to limit returned processes to those originating from\nprojects with a specific script ID.", "type": "string", "location": "query" }, "userProcessFilter.types": { "repeated": true, "location": "query", "enum": ["PROCESS_TYPE_UNSPECIFIED", "ADD_ON", "EXECUTION_API", "TIME_DRIVEN", "TRIGGER", "WEBAPP", "EDITOR", "SIMPLE_TRIGGER", "MENU", "BATCH_TASK"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process types.", "type": "string" }, "userProcessFilter.statuses": { "enum": ["PROCESS_STATUS_UNSPECIFIED", "RUNNING", "PAUSED", "COMPLETED", "CANCELED", "FAILED", "TIMED_OUT", "UNKNOWN", "DELAYED"], "description": "Optional field used to limit returned processes to those having one of\nthe specified process statuses.", "type": "string", "repeated": true, "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/script.processes"], "flatPath": "v1/processes", "id": "script.processes.list", "path": "v1/processes", "description": "List information about processes made by or on behalf of a user,\nsuch as process type and current status.", "httpMethod": "GET", "parameterOrder": [], "response": { "$ref": "ListUserProcessesResponse" } } } }, "scripts": { "methods": { "run": { "description": "Runs a function in an Apps Script project. The script project must be\ndeployed for use with the Apps Script API and the calling application must\nshare the same Cloud Platform project.\n\nThis method requires authorization with an OAuth 2.0 token that includes at\nleast one of the scopes listed in the [Authorization](#authorization)\nsection; script projects that do not require authorization cannot be\nexecuted through this API. To find the correct scopes to include in the\nauthentication token, open the project in the script editor, then select\n**File > Project properties** and click the **Scopes** tab.\n\nThe error `403, PERMISSION_DENIED: The caller does not have permission`\nindicates that the Cloud Platform project used to authorize the request is\nnot the same as the one used by the script.", "request": { "$ref": "ExecutionRequest" }, "response": { "$ref": "Operation" }, "parameterOrder": ["scriptId"], "httpMethod": "POST", "parameters": { "scriptId": { "description": "The script ID of the script to be executed. To find the script ID, open\nthe project in the script editor and select **File > Project properties**.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://mail.google.com/", "https://www.google.com/calendar/feeds", "https://www.google.com/m8/feeds", "https://www.googleapis.com/auth/admin.directory.group", "https://www.googleapis.com/auth/admin.directory.user", "https://www.googleapis.com/auth/documents", "https://www.googleapis.com/auth/drive", "https://www.googleapis.com/auth/forms", "https://www.googleapis.com/auth/forms.currentonly", "https://www.googleapis.com/auth/groups", "https://www.googleapis.com/auth/spreadsheets", "https://www.googleapis.com/auth/userinfo.email"], "flatPath": "v1/scripts/{scriptId}:run", "path": "v1/scripts/{scriptId}:run", "id": "script.scripts.run" } } } }, "parameters": { "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format." }, "alt": { "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"], "type": "string" }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" } }, "version": "v1", "baseUrl": "https://script.googleapis.com/", "kind": "discovery#restDescription", "description": "Manages and executes Google Apps Script projects.\n", "servicePath": "", "basePath": "", "revision": "20190625", "documentationLink": "https://developers.google.com/apps-script/api/", "id": "script:v1", "discoveryVersion": "v1" };
//# sourceMappingURL=script-v1.js.map