"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "basePath": "", "id": "vault:v1", "documentationLink": "https://developers.google.com/vault", "revision": "20190614", "discoveryVersion": "v1", "version_module": true, "schemas": { "Query": { "description": "A query definition relevant for search & export.", "type": "object", "properties": { "sharedDriveInfo": { "description": "When 'SHARED_DRIVE' is chosen as search method, shared_drive_info needs\nto be specified.", "$ref": "SharedDriveInfo" }, "driveOptions": { "$ref": "DriveOptions", "description": "For Drive search, specify more options in this field." }, "endTime": { "description": "The end time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" }, "dataScope": { "description": "The data source to search from.", "type": "string", "enumDescriptions": ["No data scope specified.", "All available data.", "Data on hold.", "Data not processed."], "enum": ["DATA_SCOPE_UNSPECIFIED", "ALL_DATA", "HELD_DATA", "UNPROCESSED_DATA"] }, "startTime": { "description": "The start time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" }, "searchMethod": { "enumDescriptions": ["A search method must be specified. If a request does not specify a\nsearch method, it will be rejected.", "Will search all accounts provided in account_info.", "Will search all accounts in the OU specified in org_unit_info.", "Will search for all accounts in the Team Drive specified in\nteam_drive_info.", "Will search for all accounts in the organization.\nNo need to set account_info or org_unit_info.", "Will search in the Room specified in\nhangout_chats_info. (read-only)", "Will search for all accounts in the shared drive specified in\nshared_drive_info."], "enum": ["SEARCH_METHOD_UNSPECIFIED", "ACCOUNT", "ORG_UNIT", "TEAM_DRIVE", "ENTIRE_ORG", "ROOM", "SHARED_DRIVE"], "description": "The search method to use.", "type": "string" }, "corpus": { "enum": ["CORPUS_TYPE_UNSPECIFIED", "DRIVE", "MAIL", "GROUPS", "HANGOUTS_CHAT"], "description": "The corpus to search.", "type": "string", "enumDescriptions": ["No corpus specified.", "Drive.", "Mail.", "Groups.", "Hangouts Chat."] }, "hangoutsChatInfo": { "$ref": "HangoutsChatInfo", "description": "When 'ROOM' is chosen as search method, hangout_chats_info needs to be\nspecified. (read-only)" }, "hangoutsChatOptions": { "$ref": "HangoutsChatOptions", "description": "For hangouts chat search, specify more options in this field. (read-only)" }, "orgUnitInfo": { "description": "When 'ORG_UNIT' is chosen as as search method, org_unit_info needs\nto be specified.", "$ref": "OrgUnitInfo" }, "terms": { "type": "string", "description": "The corpus-specific\n<a href=\"https://support.google.com/vault/answer/2474474\">search\noperators</a> used to generate search results." }, "method": { "description": "The search method to use. This field is similar to the search_method field\nbut is introduced to support shared drives. It supports all\nsearch method types. In case the search_method is TEAM_DRIVE the response\nof this field will be SHARED_DRIVE only.", "type": "string", "enumDescriptions": ["A search method must be specified. If a request does not specify a\nsearch method, it will be rejected.", "Will search all accounts provided in account_info.", "Will search all accounts in the OU specified in org_unit_info.", "Will search for all accounts in the Team Drive specified in\nteam_drive_info.", "Will search for all accounts in the organization.\nNo need to set account_info or org_unit_info.", "Will search in the Room specified in\nhangout_chats_info. (read-only)", "Will search for all accounts in the shared drive specified in\nshared_drive_info."], "enum": ["SEARCH_METHOD_UNSPECIFIED", "ACCOUNT", "ORG_UNIT", "TEAM_DRIVE", "ENTIRE_ORG", "ROOM", "SHARED_DRIVE"] }, "mailOptions": { "$ref": "MailOptions", "description": "For mail search, specify more options in this field." }, "timeZone": { "type": "string", "description": "The time zone name.\nIt should be an IANA TZ name, such as \"America/Los_Angeles\".\nFor more information, see\n<a href=\"https://en.wikipedia.org/wiki/List_of_tz_database_time_zones\">Time\nZone</a>." }, "teamDriveInfo": { "$ref": "TeamDriveInfo", "description": "When 'TEAM_DRIVE' is chosen as search method, team_drive_info needs to be\nspecified." }, "accountInfo": { "$ref": "AccountInfo", "description": "When 'ACCOUNT' is chosen as search method,\naccount_info needs to be specified." } }, "id": "Query" }, "CloudStorageSink": { "type": "object", "properties": { "files": { "description": "Output only. The exported files on cloud storage.", "type": "array", "items": { "$ref": "CloudStorageFile" } } }, "id": "CloudStorageSink", "description": "Export sink for cloud storage files." }, "ListMattersResponse": { "id": "ListMattersResponse", "description": "Provides the list of matters.", "type": "object", "properties": { "nextPageToken": { "description": "Page token to retrieve the next page of results in the list.", "type": "string" }, "matters": { "type": "array", "items": { "$ref": "Matter" }, "description": "List of matters." } } }, "SavedQuery": { "type": "object", "properties": { "query": { "$ref": "Query", "description": "The underlying Query object which contains all the information of the saved\nquery." }, "matterId": { "description": "Output only. The matter id of the associated matter.\nThe server does not look at this field during create and always uses matter\nid in the URL.", "type": "string" }, "createTime": { "description": "Output only. The server generated timestamp at which saved query was\ncreated.", "format": "google-datetime", "type": "string" }, "savedQueryId": { "description": "A unique identifier for the saved query.", "type": "string" }, "displayName": { "description": "Name of the saved query.", "type": "string" } }, "id": "SavedQuery", "description": "Definition of the saved query." }, "CloseMatterResponse": { "type": "object", "properties": { "matter": { "$ref": "Matter", "description": "The updated matter, with state CLOSED." } }, "id": "CloseMatterResponse", "description": "Response to a CloseMatterRequest." }, "OrgUnitInfo": { "type": "object", "properties": { "orgUnitId": { "type": "string", "description": "Org unit to search, as provided by the\n<a href=\"https://developers.google.com/admin-sdk/directory/\">Admin SDK\nDirectory API</a>." } }, "id": "OrgUnitInfo", "description": "Org Unit to search" }, "ListSavedQueriesResponse": { "id": "ListSavedQueriesResponse", "description": "Definition of the response for method ListSaveQuery.", "type": "object", "properties": { "savedQueries": { "description": "List of output saved queries.", "type": "array", "items": { "$ref": "SavedQuery" } }, "nextPageToken": { "type": "string", "description": "Page token to retrieve the next page of results in the list.\nIf this is empty, then there are no more saved queries to list." } } }, "AddHeldAccountsRequest": { "description": "Add a list of accounts to a hold.", "type": "object", "properties": { "emails": { "description": "Emails to identify which accounts to add. Only emails or only account_ids\nshould be specified, but not both.", "type": "array", "items": { "type": "string" } }, "accountIds": { "description": "Account ids to identify which accounts to add. Only account_ids or only\nemails should be specified, but not both.", "type": "array", "items": { "type": "string" } } }, "id": "AddHeldAccountsRequest" }, "AddMatterPermissionsRequest": { "type": "object", "properties": { "sendEmails": { "type": "boolean", "description": "True to send notification email to the added account.\nFalse to not send notification email." }, "matterPermission": { "description": "The MatterPermission to add.", "$ref": "MatterPermission" }, "ccMe": { "description": "Only relevant if send_emails is true.\nTrue to CC requestor in the email message.\nFalse to not CC requestor.", "type": "boolean" } }, "id": "AddMatterPermissionsRequest", "description": "Add an account with the permission specified. The role cannot be owner.\nIf an account already has a role in the matter, it will be\noverwritten." }, "ReopenMatterResponse": { "type": "object", "properties": { "matter": { "$ref": "Matter", "description": "The updated matter, with state OPEN." } }, "id": "ReopenMatterResponse", "description": "Response to a ReopenMatterRequest." }, "ExportOptions": { "type": "object", "properties": { "hangoutsChatOptions": { "$ref": "HangoutsChatExportOptions", "description": "Option available for hangouts chat export." }, "groupsOptions": { "description": "Option available for groups export.", "$ref": "GroupsExportOptions" }, "driveOptions": { "$ref": "DriveExportOptions", "description": "Option available for Drive export." }, "mailOptions": { "description": "Option available for mail export.", "$ref": "MailExportOptions" }, "region": { "description": "The requested export location.", "type": "string", "enumDescriptions": ["The region is unspecified. Will be treated the same as ANY.", "Any region.", "US region.", "Europe region."], "enum": ["EXPORT_REGION_UNSPECIFIED", "ANY", "US", "EUROPE"] } }, "id": "ExportOptions", "description": "Export advanced options" }, "TeamDriveInfo": { "id": "TeamDriveInfo", "description": "Team Drives to search", "type": "object", "properties": { "teamDriveIds": { "description": "List of Team Drive ids, as provided by <a\nhref=\"https://developers.google.com/drive\">Drive API</a>.", "type": "array", "items": { "type": "string" } } } }, "UserInfo": { "description": "User's information.", "type": "object", "properties": { "email": { "description": "The email address of the user.", "type": "string" }, "displayName": { "description": "The displayed name of the user.", "type": "string" } }, "id": "UserInfo" }, "UndeleteMatterRequest": { "description": "Undelete a matter by ID.", "type": "object", "properties": {}, "id": "UndeleteMatterRequest" }, "Status": { "description": "The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).", "type": "object", "properties": { "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" }, "message": { "type": "string", "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client." } }, "id": "Status" }, "RemoveMatterPermissionsRequest": { "description": "Remove an account as a matter collaborator.", "type": "object", "properties": { "accountId": { "description": "The account ID.", "type": "string" } }, "id": "RemoveMatterPermissionsRequest" }, "MatterPermission": { "description": "Currently each matter only has one owner, and all others are collaborators.\nWhen an account is purged, its corresponding MatterPermission resources\ncease to exist.", "type": "object", "properties": { "role": { "type": "string", "enumDescriptions": ["No role assigned.", "A collaborator to the matter.", "The owner of the matter."], "enum": ["ROLE_UNSPECIFIED", "COLLABORATOR", "OWNER"], "description": "The user's role in this matter." }, "accountId": { "description": "The account id, as provided by <a\nhref=\"https://developers.google.com/admin-sdk/\">Admin SDK</a>.", "type": "string" } }, "id": "MatterPermission" }, "GroupsExportOptions": { "id": "GroupsExportOptions", "description": "The options for groups export.", "type": "object", "properties": { "exportFormat": { "type": "string", "enumDescriptions": ["No export format specified.", "MBOX as export format.", "PST as export format"], "enum": ["EXPORT_FORMAT_UNSPECIFIED", "MBOX", "PST"], "description": "The export format for groups export." } } }, "DriveExportOptions": { "type": "object", "properties": { "includeAccessInfo": { "description": "Set to true to include access level information for users\nwith <a\nhref=\"https://support.google.com/vault/answer/6099459#metadata\">indirect\naccess</a> to files.", "type": "boolean" } }, "id": "DriveExportOptions", "description": "The options for Drive export." }, "HeldMailQuery": { "description": "Query options for mail holds.", "type": "object", "properties": { "startTime": { "description": "The start time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" }, "terms": { "type": "string", "description": "The search terms for the hold." }, "endTime": { "description": "The end time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" } }, "id": "HeldMailQuery" }, "HeldDriveQuery": { "type": "object", "properties": { "includeTeamDriveFiles": { "description": "If true, include files in Team Drives in the hold.", "type": "boolean" }, "includeSharedDriveFiles": { "description": "If true, include files in shared drives in the hold.", "type": "boolean" } }, "id": "HeldDriveQuery", "description": "Query options for Drive holds." }, "HeldGroupsQuery": { "description": "Query options for group holds.", "type": "object", "properties": { "endTime": { "description": "The end time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "The start time range for the search query. These timestamps are in GMT and\nrounded down to the start of the given date.", "format": "google-datetime", "type": "string" }, "terms": { "description": "The search terms for the hold.", "type": "string" } }, "id": "HeldGroupsQuery" }, "HeldOrgUnit": { "type": "object", "properties": { "holdTime": { "description": "When the org unit was put on hold. This property is immutable.", "format": "google-datetime", "type": "string" }, "orgUnitId": { "description": "The org unit's immutable ID as provided by the Admin SDK.", "type": "string" } }, "id": "HeldOrgUnit", "description": "A organizational unit being held in a particular hold.\nThis structure is immutable." }, "Matter": { "description": "Represents a matter.", "type": "object", "properties": { "matterId": { "description": "The matter ID which is generated by the server.\nShould be blank when creating a new matter.", "type": "string" }, "state": { "description": "The state of the matter.", "type": "string", "enumDescriptions": ["The matter has no specified state.", "This matter is open.", "This matter is closed.", "This matter is deleted."], "enum": ["STATE_UNSPECIFIED", "OPEN", "CLOSED", "DELETED"] }, "name": { "type": "string", "description": "The name of the matter." }, "matterPermissions": { "description": "List of users and access to the matter. Currently there is no programmer\ndefined limit on the number of permissions a matter can have.", "type": "array", "items": { "$ref": "MatterPermission" } }, "description": { "type": "string", "description": "The description of the matter." } }, "id": "Matter" }, "AddHeldAccountsResponse": { "type": "object", "properties": { "responses": { "description": "The list of responses, in the same order as the batch request.", "type": "array", "items": { "$ref": "AddHeldAccountResult" } } }, "id": "AddHeldAccountsResponse", "description": "Response for batch create held accounts." }, "Export": { "description": "An export", "type": "object", "properties": { "requester": { "$ref": "UserInfo", "description": "Output only. The requester of the export." }, "matterId": { "description": "Output only. The matter ID.", "type": "string" }, "id": { "description": "Output only. The generated export ID.", "type": "string" }, "exportOptions": { "$ref": "ExportOptions", "description": "Advanced options of the export." }, "stats": { "description": "Output only. Export statistics.", "$ref": "ExportStats" }, "cloudStorageSink": { "$ref": "CloudStorageSink", "description": "Output only. Export sink for cloud storage files." }, "query": { "$ref": "Query", "description": "The search query being exported." }, "createTime": { "type": "string", "description": "Output only. The time when the export was created.", "format": "google-datetime" }, "status": { "enumDescriptions": ["The status is unspecified.", "The export completed.", "The export failed.", "The export is still being executed."], "enum": ["EXPORT_STATUS_UNSPECIFIED", "COMPLETED", "FAILED", "IN_PROGRESS"], "description": "Output only. The export status.", "type": "string" }, "name": { "description": "The export name.", "type": "string" } }, "id": "Export" }, "CorpusQuery": { "description": "Corpus specific queries.", "type": "object", "properties": { "mailQuery": { "description": "Details pertaining to mail holds. If set, corpus must be mail.", "$ref": "HeldMailQuery" }, "groupsQuery": { "$ref": "HeldGroupsQuery", "description": "Details pertaining to Groups holds. If set, corpus must be Groups." }, "hangoutsChatQuery": { "description": "Details pertaining to Hangouts Chat holds. If set, corpus must be\nHangouts Chat.", "$ref": "HeldHangoutsChatQuery" }, "driveQuery": { "$ref": "HeldDriveQuery", "description": "Details pertaining to Drive holds. If set, corpus must be Drive." } }, "id": "CorpusQuery" }, "Hold": { "type": "object", "properties": { "holdId": { "description": "The unique immutable ID of the hold. Assigned during creation.", "type": "string" }, "name": { "description": "The name of the hold.", "type": "string" }, "accounts": { "description": "If set, the hold applies to the enumerated accounts and org_unit must be\nempty.", "type": "array", "items": { "$ref": "HeldAccount" } }, "orgUnit": { "$ref": "HeldOrgUnit", "description": "If set, the hold applies to all members of the organizational unit and\naccounts must be empty. This property is mutable. For groups holds,\nset the accounts field." }, "query": { "$ref": "CorpusQuery", "description": "The corpus-specific query. If set, the corpusQuery must match corpus\ntype." }, "corpus": { "enum": ["CORPUS_TYPE_UNSPECIFIED", "DRIVE", "MAIL", "GROUPS", "HANGOUTS_CHAT"], "description": "The corpus to be searched.", "type": "string", "enumDescriptions": ["No corpus specified.", "Drive.", "Mail.", "Groups.", "Hangouts Chat."] }, "updateTime": { "description": "The last time this hold was modified.", "format": "google-datetime", "type": "string" } }, "id": "Hold", "description": "Represents a hold within Vault. A hold restricts purging of\nartifacts based on the combination of the query and accounts restrictions.\nA hold can be configured to either apply to an explicitly configured set\nof accounts, or can be applied to all members of an organizational unit." }, "HangoutsChatInfo": { "type": "object", "properties": { "roomId": { "description": "A set of rooms to search.", "type": "array", "items": { "type": "string" } } }, "id": "HangoutsChatInfo", "description": "Accounts to search" }, "HangoutsChatExportOptions": { "description": "The options for hangouts chat export.", "type": "object", "properties": { "exportFormat": { "description": "The export format for hangouts chat export.", "type": "string", "enumDescriptions": ["No export format specified.", "MBOX as export format.", "PST as export format"], "enum": ["EXPORT_FORMAT_UNSPECIFIED", "MBOX", "PST"] } }, "id": "HangoutsChatExportOptions" }, "ListHoldsResponse": { "id": "ListHoldsResponse", "description": "The holds for a matter.", "type": "object", "properties": { "nextPageToken": { "description": "Page token to retrieve the next page of results in the list.\nIf this is empty, then there are no more holds to list.", "type": "string" }, "holds": { "description": "The list of holds.", "type": "array", "items": { "$ref": "Hold" } } } }, "ListHeldAccountsResponse": { "id": "ListHeldAccountsResponse", "description": "Returns a list of held accounts for a hold.", "type": "object", "properties": { "accounts": { "description": "The held accounts on a hold.", "type": "array", "items": { "$ref": "HeldAccount" } } } }, "CloseMatterRequest": { "description": "Close a matter by ID.", "type": "object", "properties": {}, "id": "CloseMatterRequest" }, "ReopenMatterRequest": { "type": "object", "properties": {}, "id": "ReopenMatterRequest", "description": "Reopen a matter by ID." }, "MailExportOptions": { "type": "object", "properties": { "exportFormat": { "type": "string", "enumDescriptions": ["No export format specified.", "MBOX as export format.", "PST as export format"], "enum": ["EXPORT_FORMAT_UNSPECIFIED", "MBOX", "PST"], "description": "The export file format." }, "showConfidentialModeContent": { "description": "Set to true to export confidential mode content.", "type": "boolean" } }, "id": "MailExportOptions", "description": "The options for mail export." }, "DriveOptions": { "description": "Drive search advanced options", "type": "object", "properties": { "includeSharedDrives": { "description": "Set to true to include shared drive.", "type": "boolean" }, "versionDate": { "type": "string", "description": "Search the versions of the Drive file\nas of the reference date. These timestamps are in GMT and\nrounded down to the given date.", "format": "google-datetime" }, "includeTeamDrives": { "description": "Set to true to include Team Drive.", "type": "boolean" } }, "id": "DriveOptions" }, "RemoveHeldAccountsRequest": { "id": "RemoveHeldAccountsRequest", "description": "Remove a list of accounts from a hold.", "type": "object", "properties": { "accountIds": { "type": "array", "items": { "type": "string" }, "description": "Account ids to identify HeldAccounts to remove." } } }, "CloudStorageFile": { "description": "An export file on cloud storage", "type": "object", "properties": { "objectName": { "description": "The cloud storage object name of this export file.\nCan be used in cloud storage JSON/XML API.", "type": "string" }, "bucketName": { "description": "The cloud storage bucket name of this export file.\nCan be used in cloud storage JSON/XML API.", "type": "string" }, "size": { "type": "string", "description": "The size of the export file.", "format": "int64" }, "md5Hash": { "description": "The md5 hash of the file.", "type": "string" } }, "id": "CloudStorageFile" }, "MailOptions": { "description": "Mail search advanced options", "type": "object", "properties": { "excludeDrafts": { "description": "Set to true to exclude drafts.", "type": "boolean" } }, "id": "MailOptions" }, "RemoveHeldAccountsResponse": { "type": "object", "properties": { "statuses": { "description": "A list of statuses for deleted accounts. Results have the\nsame order as the request.", "type": "array", "items": { "$ref": "Status" } } }, "id": "RemoveHeldAccountsResponse", "description": "Response for batch delete held accounts." }, "HangoutsChatOptions": { "description": "Hangouts chat search advanced options", "type": "object", "properties": { "includeRooms": { "type": "boolean", "description": "Set to true to include rooms." } }, "id": "HangoutsChatOptions" }, "HeldHangoutsChatQuery": { "description": "Query options for hangouts chat holds.", "type": "object", "properties": { "includeRooms": { "description": "If true, include rooms the user has participated in.", "type": "boolean" } }, "id": "HeldHangoutsChatQuery" }, "AddHeldAccountResult": { "type": "object", "properties": { "status": { "description": "This represents the success status. If failed, check message.", "$ref": "Status" }, "account": { "$ref": "HeldAccount", "description": "If present, this account was successfully created." } }, "id": "AddHeldAccountResult", "description": "A status detailing the status of each account creation, and the\nHeldAccount, if successful." }, "HeldAccount": { "description": "An account being held in a particular hold. This structure is immutable.\nThis can be either a single user or a google group, depending on the corpus.", "type": "object", "properties": { "lastName": { "type": "string", "description": "Output only. The last name of the account holder." }, "email": { "description": "The primary email address of the account. If used as an input, this takes\nprecedence over account ID.", "type": "string" }, "accountId": { "description": "The account's ID as provided by the\n<a href=\"https://developers.google.com/admin-sdk/\">Admin SDK</a>.", "type": "string" }, "firstName": { "type": "string", "description": "Output only. The first name of the account holder." }, "holdTime": { "description": "Output only. When the account was put on hold.", "format": "google-datetime", "type": "string" } }, "id": "HeldAccount" }, "ExportStats": { "id": "ExportStats", "description": "Stats of an export.", "type": "object", "properties": { "totalArtifactCount": { "description": "The number of documents to be exported.", "format": "int64", "type": "string" }, "sizeInBytes": { "description": "The size of export in bytes.", "format": "int64", "type": "string" }, "exportedArtifactCount": { "description": "The number of documents already processed by the export.", "format": "int64", "type": "string" } } }, "AccountInfo": { "description": "Accounts to search", "type": "object", "properties": { "emails": { "description": "A set of accounts to search.", "type": "array", "items": { "type": "string" } } }, "id": "AccountInfo" }, "ListExportsResponse": { "description": "The holds for a matter.", "type": "object", "properties": { "exports": { "description": "The list of exports.", "type": "array", "items": { "$ref": "Export" } }, "nextPageToken": { "description": "Page token to retrieve the next page of results in the list.", "type": "string" } }, "id": "ListExportsResponse" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {}, "id": "Empty" }, "SharedDriveInfo": { "description": "Shared drives to search", "type": "object", "properties": { "sharedDriveIds": { "description": "List of Shared drive ids, as provided by <a\nhref=\"https://developers.google.com/drive\">Drive API</a>.", "type": "array", "items": { "type": "string" } } }, "id": "SharedDriveInfo" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "canonicalName": "Vault", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/ediscovery.readonly": { "description": "View your eDiscovery data" }, "https://www.googleapis.com/auth/ediscovery": { "description": "Manage your eDiscovery data" } } } }, "rootUrl": "https://vault.googleapis.com/", "ownerDomain": "google.com", "name": "vault", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "G Suite Vault API", "ownerName": "Google", "resources": { "matters": { "methods": { "close": { "httpMethod": "POST", "parameterOrder": ["matterId"], "response": { "$ref": "CloseMatterResponse" }, "parameters": { "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}:close", "id": "vault.matters.close", "path": "v1/matters/{matterId}:close", "description": "Closes the specified matter. Returns matter with updated state.", "request": { "$ref": "CloseMatterRequest" } }, "get": { "parameters": { "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." }, "view": { "location": "query", "enum": ["VIEW_UNSPECIFIED", "BASIC", "FULL"], "description": "Specifies which parts of the Matter to return in the response.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "flatPath": "v1/matters/{matterId}", "path": "v1/matters/{matterId}", "id": "vault.matters.get", "description": "Gets the specified matter.", "response": { "$ref": "Matter" }, "parameterOrder": ["matterId"], "httpMethod": "GET" }, "undelete": { "request": { "$ref": "UndeleteMatterRequest" }, "description": "Undeletes the specified matter. Returns matter with updated state.", "response": { "$ref": "Matter" }, "parameterOrder": ["matterId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." } }, "flatPath": "v1/matters/{matterId}:undelete", "path": "v1/matters/{matterId}:undelete", "id": "vault.matters.undelete" }, "update": { "parameters": { "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}", "id": "vault.matters.update", "path": "v1/matters/{matterId}", "description": "Updates the specified matter.\nThis updates only the name and description of the matter, identified by\nmatter id. Changes to any other fields are ignored.\nReturns the default view of the matter.", "request": { "$ref": "Matter" }, "httpMethod": "PUT", "parameterOrder": ["matterId"], "response": { "$ref": "Matter" } }, "delete": { "description": "Deletes the specified matter. Returns matter with updated state.", "httpMethod": "DELETE", "parameterOrder": ["matterId"], "response": { "$ref": "Matter" }, "parameters": { "matterId": { "location": "path", "description": "The matter ID", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}", "id": "vault.matters.delete", "path": "v1/matters/{matterId}" }, "list": { "flatPath": "v1/matters", "path": "v1/matters", "id": "vault.matters.list", "description": "Lists matters the user has access to.", "response": { "$ref": "ListMattersResponse" }, "parameterOrder": [], "httpMethod": "GET", "parameters": { "pageToken": { "description": "The pagination token as returned in the response.", "type": "string", "location": "query" }, "pageSize": { "type": "integer", "location": "query", "description": "The number of matters to return in the response.\nDefault and maximum are 100.", "format": "int32" }, "view": { "location": "query", "enum": ["VIEW_UNSPECIFIED", "BASIC", "FULL"], "description": "Specifies which parts of the matter to return in response.", "type": "string" }, "state": { "location": "query", "enum": ["STATE_UNSPECIFIED", "OPEN", "CLOSED", "DELETED"], "description": "If set, list only matters with that specific state. The default is listing\nmatters of all states.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"] }, "addPermissions": { "httpMethod": "POST", "parameterOrder": ["matterId"], "response": { "$ref": "MatterPermission" }, "parameters": { "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}:addPermissions", "id": "vault.matters.addPermissions", "path": "v1/matters/{matterId}:addPermissions", "description": "Adds an account as a matter collaborator.", "request": { "$ref": "AddMatterPermissionsRequest" } }, "create": { "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": {}, "flatPath": "v1/matters", "id": "vault.matters.create", "path": "v1/matters", "request": { "$ref": "Matter" }, "description": "Creates a new matter with the given name and description. The initial state\nis open, and the owner is the method caller. Returns the created matter\nwith default view.", "httpMethod": "POST", "parameterOrder": [], "response": { "$ref": "Matter" } }, "removePermissions": { "response": { "$ref": "Empty" }, "parameterOrder": ["matterId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}:removePermissions", "path": "v1/matters/{matterId}:removePermissions", "id": "vault.matters.removePermissions", "request": { "$ref": "RemoveMatterPermissionsRequest" }, "description": "Removes an account as a matter collaborator." }, "reopen": { "response": { "$ref": "ReopenMatterResponse" }, "parameterOrder": ["matterId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}:reopen", "path": "v1/matters/{matterId}:reopen", "id": "vault.matters.reopen", "request": { "$ref": "ReopenMatterRequest" }, "description": "Reopens the specified matter. Returns matter with updated state." } }, "resources": { "savedQueries": { "methods": { "create": { "httpMethod": "POST", "parameterOrder": ["matterId"], "response": { "$ref": "SavedQuery" }, "parameters": { "matterId": { "location": "path", "description": "The matter id of the parent matter for which the saved query is to be\ncreated.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}/savedQueries", "id": "vault.matters.savedQueries.create", "path": "v1/matters/{matterId}/savedQueries", "description": "Creates a saved query.", "request": { "$ref": "SavedQuery" } }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["matterId", "savedQueryId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "description": "The matter id of the parent matter for which the saved query is to be\ndeleted.", "required": true, "type": "string", "location": "path" }, "savedQueryId": { "location": "path", "description": "Id of the saved query to be deleted.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}/savedQueries/{savedQueryId}", "path": "v1/matters/{matterId}/savedQueries/{savedQueryId}", "id": "vault.matters.savedQueries.delete", "description": "Deletes a saved query by Id." }, "get": { "httpMethod": "GET", "parameterOrder": ["matterId", "savedQueryId"], "response": { "$ref": "SavedQuery" }, "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "parameters": { "savedQueryId": { "location": "path", "description": "Id of the saved query to be retrieved.", "required": true, "type": "string" }, "matterId": { "description": "The matter id of the parent matter for which the saved query is to be\nretrieved.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/matters/{matterId}/savedQueries/{savedQueryId}", "id": "vault.matters.savedQueries.get", "path": "v1/matters/{matterId}/savedQueries/{savedQueryId}", "description": "Retrieves a saved query by Id." }, "list": { "response": { "$ref": "ListSavedQueriesResponse" }, "parameterOrder": ["matterId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "parameters": { "pageToken": { "location": "query", "description": "The pagination token as returned in the previous response.\nAn empty token means start from the beginning.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of saved queries to return.", "format": "int32", "type": "integer" }, "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter id of the parent matter for which the saved queries are to be\nretrieved." } }, "flatPath": "v1/matters/{matterId}/savedQueries", "path": "v1/matters/{matterId}/savedQueries", "id": "vault.matters.savedQueries.list", "description": "Lists saved queries within a matter. An empty page token in\nListSavedQueriesResponse denotes no more saved queries to list." } } }, "holds": { "methods": { "create": { "response": { "$ref": "Hold" }, "parameterOrder": ["matterId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}/holds", "path": "v1/matters/{matterId}/holds", "id": "vault.matters.holds.create", "request": { "$ref": "Hold" }, "description": "Creates a hold in the given matter." }, "removeHeldAccounts": { "path": "v1/matters/{matterId}/holds/{holdId}:removeHeldAccounts", "id": "vault.matters.holds.removeHeldAccounts", "request": { "$ref": "RemoveHeldAccountsRequest" }, "description": "Removes HeldAccounts from a hold. Returns a list of statuses in the same\norder as the request. If this request leaves the hold with no held\naccounts, the hold will not apply to any accounts.", "response": { "$ref": "RemoveHeldAccountsResponse" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "holdId": { "description": "The hold ID.", "required": true, "type": "string", "location": "path" }, "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}:removeHeldAccounts" }, "addHeldAccounts": { "path": "v1/matters/{matterId}/holds/{holdId}:addHeldAccounts", "id": "vault.matters.holds.addHeldAccounts", "request": { "$ref": "AddHeldAccountsRequest" }, "description": "Adds HeldAccounts to a hold. Returns a list of accounts that have been\nsuccessfully added. Accounts can only be added to an existing account-based\nhold.", "response": { "$ref": "AddHeldAccountsResponse" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "holdId": { "required": true, "type": "string", "location": "path", "description": "The hold ID." }, "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}:addHeldAccounts" }, "get": { "httpMethod": "GET", "parameterOrder": ["matterId", "holdId"], "response": { "$ref": "Hold" }, "parameters": { "view": { "location": "query", "enum": ["HOLD_VIEW_UNSPECIFIED", "BASIC_HOLD", "FULL_HOLD"], "description": "Specifies which parts of the Hold to return.", "type": "string" }, "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" }, "holdId": { "location": "path", "description": "The hold ID.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "flatPath": "v1/matters/{matterId}/holds/{holdId}", "id": "vault.matters.holds.get", "path": "v1/matters/{matterId}/holds/{holdId}", "description": "Gets a hold by ID." }, "update": { "response": { "$ref": "Hold" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "PUT", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "holdId": { "location": "path", "description": "The ID of the hold.", "required": true, "type": "string" }, "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}", "path": "v1/matters/{matterId}/holds/{holdId}", "id": "vault.matters.holds.update", "request": { "$ref": "Hold" }, "description": "Updates the OU and/or query parameters of a hold. You cannot add accounts\nto a hold that covers an OU, nor can you add OUs to a hold that covers\nindividual accounts. Accounts listed in the hold will be ignored." }, "delete": { "parameters": { "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." }, "holdId": { "required": true, "type": "string", "location": "path", "description": "The hold ID." } }, "scopes": ["https://www.googleapis.com/auth/ediscovery"], "flatPath": "v1/matters/{matterId}/holds/{holdId}", "path": "v1/matters/{matterId}/holds/{holdId}", "id": "vault.matters.holds.delete", "description": "Removes a hold by ID. This will release any HeldAccounts on this Hold.", "response": { "$ref": "Empty" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "DELETE" }, "list": { "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "parameters": { "pageToken": { "description": "The pagination token as returned in the response.\nAn empty token means start from the beginning.", "type": "string", "location": "query" }, "pageSize": { "description": "The number of holds to return in the response, between 0 and 100 inclusive.\nLeaving this empty, or as 0, is the same as page_size = 100.", "format": "int32", "type": "integer", "location": "query" }, "view": { "description": "Specifies which parts of the Hold to return.", "type": "string", "location": "query", "enum": ["HOLD_VIEW_UNSPECIFIED", "BASIC_HOLD", "FULL_HOLD"] }, "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/matters/{matterId}/holds", "path": "v1/matters/{matterId}/holds", "id": "vault.matters.holds.list", "description": "Lists holds within a matter. An empty page token in ListHoldsResponse\ndenotes no more holds to list.", "response": { "$ref": "ListHoldsResponse" }, "parameterOrder": ["matterId"], "httpMethod": "GET" } }, "resources": { "accounts": { "methods": { "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["matterId", "holdId", "accountId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "holdId": { "location": "path", "description": "The hold ID.", "required": true, "type": "string" }, "accountId": { "required": true, "type": "string", "location": "path", "description": "The ID of the account to remove from the hold." }, "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}/accounts/{accountId}", "path": "v1/matters/{matterId}/holds/{holdId}/accounts/{accountId}", "id": "vault.matters.holds.accounts.delete", "description": "Removes a HeldAccount from a hold. If this request leaves the hold with\nno held accounts, the hold will not apply to any accounts." }, "list": { "path": "v1/matters/{matterId}/holds/{holdId}/accounts", "id": "vault.matters.holds.accounts.list", "description": "Lists HeldAccounts for a hold. This will only list individually specified\nheld accounts. If the hold is on an OU, then use\n<a href=\"https://developers.google.com/admin-sdk/\">Admin SDK</a>\nto enumerate its members.", "response": { "$ref": "ListHeldAccountsResponse" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "parameters": { "holdId": { "location": "path", "description": "The hold ID.", "required": true, "type": "string" }, "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}/accounts" }, "create": { "response": { "$ref": "HeldAccount" }, "parameterOrder": ["matterId", "holdId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "holdId": { "description": "The hold ID.", "required": true, "type": "string", "location": "path" }, "matterId": { "description": "The matter ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/matters/{matterId}/holds/{holdId}/accounts", "path": "v1/matters/{matterId}/holds/{holdId}/accounts", "id": "vault.matters.holds.accounts.create", "request": { "$ref": "HeldAccount" }, "description": "Adds a HeldAccount to a hold. Accounts can only be added to a hold that\nhas no held_org_unit set. Attempting to add an account to an OU-based\nhold will result in an error." } } } } }, "exports": { "methods": { "delete": { "description": "Deletes an Export.", "response": { "$ref": "Empty" }, "parameterOrder": ["matterId", "exportId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." }, "exportId": { "description": "The export ID.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/matters/{matterId}/exports/{exportId}", "path": "v1/matters/{matterId}/exports/{exportId}", "id": "vault.matters.exports.delete" }, "get": { "response": { "$ref": "Export" }, "parameterOrder": ["matterId", "exportId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "parameters": { "matterId": { "required": true, "type": "string", "location": "path", "description": "The matter ID." }, "exportId": { "location": "path", "description": "The export ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}/exports/{exportId}", "path": "v1/matters/{matterId}/exports/{exportId}", "id": "vault.matters.exports.get", "description": "Gets an Export." }, "list": { "path": "v1/matters/{matterId}/exports", "id": "vault.matters.exports.list", "description": "Lists Exports.", "response": { "$ref": "ListExportsResponse" }, "parameterOrder": ["matterId"], "httpMethod": "GET", "parameters": { "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" }, "pageToken": { "location": "query", "description": "The pagination token as returned in the response.", "type": "string" }, "pageSize": { "description": "The number of exports to return in the response.", "format": "int32", "type": "integer", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/ediscovery", "https://www.googleapis.com/auth/ediscovery.readonly"], "flatPath": "v1/matters/{matterId}/exports" }, "create": { "response": { "$ref": "Export" }, "parameterOrder": ["matterId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/ediscovery"], "parameters": { "matterId": { "location": "path", "description": "The matter ID.", "required": true, "type": "string" } }, "flatPath": "v1/matters/{matterId}/exports", "path": "v1/matters/{matterId}/exports", "id": "vault.matters.exports.create", "request": { "$ref": "Export" }, "description": "Creates an Export." } } } } } }, "parameters": { "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "$.xgafv": { "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"] }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "callback": { "description": "JSONP", "type": "string", "location": "query" }, "alt": { "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"] }, "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "type": "string", "location": "query", "description": "OAuth access token." }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true", "location": "query" }, "quotaUser": { "type": "string", "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters." } }, "version": "v1", "baseUrl": "https://vault.googleapis.com/", "servicePath": "", "description": "Archiving and eDiscovery for G Suite.", "kind": "discovery#restDescription" };
//# sourceMappingURL=vault-v1.js.map