export default {"schemas":{"Operation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"error":{"$ref":"Status","description":"The error result of the operation in case of failure or cancellation."},"metadata":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object"},"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`."},"name":{"description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`.","type":"string"}},"id":"Operation"},"LookupMembershipNameResponse":{"type":"object","properties":{"name":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nMembership being looked up.\n\nFormat: `groups/{group_id}/memberships/{member_id}`, where `group_id` is\nthe unique ID assigned to the Group to which Membership belongs to, and\n`member_id` is the unique ID assigned to the member.","type":"string"}},"id":"LookupMembershipNameResponse"},"MembershipRole":{"properties":{"name":{"description":"MembershipRole in string format.\n\nCurrently supported MembershipRoles: `\"MEMBER\"`.","type":"string"}},"id":"MembershipRole","description":"Resource representing a role within a Membership.","type":"object"},"SearchGroupsResponse":{"type":"object","properties":{"groups":{"description":"List of Groups satisfying the search query.","type":"array","items":{"$ref":"Group"}},"nextPageToken":{"type":"string","description":"Token to retrieve the next page of results, or empty if there are no\nmore results available for specified query."}},"id":"SearchGroupsResponse"},"EntityKey":{"properties":{"id":{"description":"The ID of the entity within the given namespace. The ID must be unique\nwithin its namespace.","type":"string"},"namespace":{"description":"Namespaces provide isolation for IDs, so an ID only needs to be unique\nwithin its namespace.\n\nNamespaces are currently only created as part of IdentitySource creation\nfrom Admin Console. A namespace `\"identitysources/{identity_source_id}\"` is\ncreated corresponding to every Identity Source `identity_source_id`.","type":"string"}},"id":"EntityKey","description":"An EntityKey uniquely identifies an Entity. Namespaces are used to provide\nisolation for IDs. A single ID can be reused across namespaces but the\ncombination of a namespace and an ID must be unique.","type":"object"},"LookupGroupNameResponse":{"type":"object","properties":{"name":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup in the format: `groups/{group_id}`, where `group_id` is the unique ID\nassigned to the Group.","type":"string"}},"id":"LookupGroupNameResponse"},"Status":{"type":"object","properties":{"code":{"type":"integer","description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"},"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}}}},"id":"Status","description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors)."},"ListMembershipsResponse":{"type":"object","properties":{"memberships":{"description":"List of Memberships.","type":"array","items":{"$ref":"Membership"}},"nextPageToken":{"description":"Token to retrieve the next page of results, or empty if there are no\nmore results available for listing.","type":"string"}},"id":"ListMembershipsResponse"},"ListGroupsResponse":{"description":"Response message for ListGroups operation.","type":"object","properties":{"groups":{"description":"Groups returned in response to list request.\nThe results are not sorted.","type":"array","items":{"$ref":"Group"}},"nextPageToken":{"description":"Token to retrieve the next page of results, or empty if there are no\nmore results available for listing.","type":"string"}},"id":"ListGroupsResponse"},"Membership":{"description":"Resource representing a Membership within a Group","type":"object","properties":{"updateTime":{"description":"Last updated timestamp of the Membership. Output only.","format":"google-datetime","type":"string"},"roles":{"description":"Roles for a member within the Group.\n\nCurrently supported MembershipRoles: `\"MEMBER\"`.","type":"array","items":{"$ref":"MembershipRole"}},"name":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nMembership in the format: `groups/{group_id}/memberships/{member_id}`,\nwhere group_id is the unique ID assigned to the Group to which Membership\nbelongs to, and member_id is the unique ID assigned to the member\n\nMust be left blank while creating a Membership.","type":"string"},"preferredMemberKey":{"description":"EntityKey of the entity to be added as the member. Must be set while\ncreating a Membership, read-only afterwards.\n\nCurrently allowed entity types: `Users`, `Groups`.","$ref":"EntityKey"},"createTime":{"description":"Creation timestamp of the Membership. Output only.","format":"google-datetime","type":"string"}},"id":"Membership"},"Group":{"id":"Group","description":"Resource representing a Group.","type":"object","properties":{"updateTime":{"type":"string","description":"The time when the Group was last updated.\nOutput only.","format":"google-datetime"},"name":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup in the format: `groups/{group_id}`, where group_id is the unique ID\nassigned to the Group.\n\nMust be left blank while creating a Group.","type":"string"},"groupKey":{"$ref":"EntityKey","description":"EntityKey of the Group.\n\nMust be set when creating a Group, read-only afterwards."},"description":{"description":"An extended description to help users determine the purpose of a Group. For\nexample, you can include information about who should join the Group, the\ntypes of messages to send to the Group, links to FAQs about the Group, or\nrelated Groups. Maximum length is 4,096 characters.","type":"string"},"displayName":{"type":"string","description":"The Group's display name."},"parent":{"description":"The entity under which this Group resides in Cloud Identity resource\nhierarchy. Must be set when creating a Group, read-only afterwards.\n\nCurrently allowed types: `identitysources`.","type":"string"},"labels":{"type":"object","additionalProperties":{"type":"string"},"description":"`Required`. Labels for Group resource.\nFor creating Groups under a namespace, set label key to\n'labels/system/groups/external' and label value as empty."},"createTime":{"type":"string","description":"The time when the Group was created.\nOutput only.","format":"google-datetime"}}}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"Cloud Identity","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-identity.groups.readonly":{"description":"See any Cloud Identity Groups that you can access, including group members and their emails"},"https://www.googleapis.com/auth/cloud-identity.groups":{"description":"See, change, create, and delete any of the Cloud Identity Groups that you can access, including the members of each group"}}}},"rootUrl":"https://cloudidentity.googleapis.com/","ownerDomain":"google.com","name":"cloudidentity","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud Identity API","ownerName":"Google","resources":{"groups":{"methods":{"search":{"id":"cloudidentity.groups.search","path":"v1/groups:search","description":"Searches for Groups.","httpMethod":"GET","parameterOrder":[],"response":{"$ref":"SearchGroupsResponse"},"parameters":{"pageToken":{"location":"query","description":"The next_page_token value returned from a previous search request, if any.","type":"string"},"pageSize":{"description":"The default page size is 200 (max 1000) for the BASIC view, and 50\n(max 500) for the FULL view.","format":"int32","type":"integer","location":"query"},"query":{"location":"query","description":"`Required`. Query string for performing search on groups. Users can search\non parent and label attributes of groups.\nEXACT match ('==') is supported on parent, and CONTAINS match ('in') is\nsupported on labels.","type":"string"},"view":{"location":"query","enum":["VIEW_UNSPECIFIED","BASIC","FULL"],"description":"Group resource view to be returned. Defaults to [View.BASIC]().","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups:search"},"patch":{"flatPath":"v1/groups/{groupsId}","id":"cloudidentity.groups.patch","path":"v1/{+name}","description":"Updates a Group.","request":{"$ref":"Group"},"httpMethod":"PATCH","parameterOrder":["name"],"response":{"$ref":"Operation"},"parameters":{"name":{"required":true,"type":"string","pattern":"^groups/[^/]+$","location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup in the format: `groups/{group_id}`, where group_id is the unique ID\nassigned to the Group.\n\nMust be left blank while creating a Group."},"updateMask":{"location":"query","description":"Editable fields: `display_name`, `description`","format":"google-fieldmask","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups"]},"get":{"description":"Retrieves a Group.","response":{"$ref":"Group"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup in the format: `groups/{group_id}`, where `group_id` is the unique ID\nassigned to the Group.","required":true,"type":"string","pattern":"^groups/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups/{groupsId}","path":"v1/{+name}","id":"cloudidentity.groups.get"},"delete":{"httpMethod":"DELETE","response":{"$ref":"Operation"},"parameterOrder":["name"],"parameters":{"name":{"pattern":"^groups/[^/]+$","location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup in the format: `groups/{group_id}`, where `group_id` is the unique ID\nassigned to the Group.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups"],"flatPath":"v1/groups/{groupsId}","id":"cloudidentity.groups.delete","path":"v1/{+name}","description":"Deletes a Group."},"list":{"description":"List groups within a customer or a domain.","httpMethod":"GET","parameterOrder":[],"response":{"$ref":"ListGroupsResponse"},"parameters":{"pageToken":{"location":"query","description":"The next_page_token value returned from a previous list request, if any.","type":"string"},"pageSize":{"description":"The default page size is 200 (max 1000) for the BASIC view, and 50\n(max 500) for the FULL view.","format":"int32","type":"integer","location":"query"},"view":{"type":"string","location":"query","enum":["VIEW_UNSPECIFIED","BASIC","FULL"],"description":"Group resource view to be returned. Defaults to [View.BASIC]()."},"parent":{"location":"query","description":"`Required`. May be made Optional in the future.\nCustomer ID to list all groups from.","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups","id":"cloudidentity.groups.list","path":"v1/groups"},"create":{"response":{"$ref":"Operation"},"parameterOrder":[],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-identity.groups"],"parameters":{},"flatPath":"v1/groups","path":"v1/groups","id":"cloudidentity.groups.create","request":{"$ref":"Group"},"description":"Creates a Group."},"lookup":{"httpMethod":"GET","parameterOrder":[],"response":{"$ref":"LookupGroupNameResponse"},"parameters":{"groupKey.namespace":{"location":"query","description":"Namespaces provide isolation for IDs, so an ID only needs to be unique\nwithin its namespace.\n\nNamespaces are currently only created as part of IdentitySource creation\nfrom Admin Console. A namespace `\"identitysources/{identity_source_id}\"` is\ncreated corresponding to every Identity Source `identity_source_id`.","type":"string"},"groupKey.id":{"description":"The ID of the entity within the given namespace. The ID must be unique\nwithin its namespace.","type":"string","location":"query"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups:lookup","id":"cloudidentity.groups.lookup","path":"v1/groups:lookup","description":"Looks up [resource\nname](https://cloud.google.com/apis/design/resource_names) of a Group by\nits EntityKey."}},"resources":{"memberships":{"methods":{"delete":{"httpMethod":"DELETE","parameterOrder":["name"],"response":{"$ref":"Operation"},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups"],"parameters":{"name":{"pattern":"^groups/[^/]+/memberships/[^/]+$","location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nMembership to be deleted.\n\nFormat: `groups/{group_id}/memberships/{member_id}`, where `group_id` is\nthe unique ID assigned to the Group to which Membership belongs to, and\nmember_id is the unique ID assigned to the member.","required":true,"type":"string"}},"flatPath":"v1/groups/{groupsId}/memberships/{membershipsId}","id":"cloudidentity.groups.memberships.delete","path":"v1/{+name}","description":"Deletes a Membership."},"get":{"description":"Retrieves a Membership.","response":{"$ref":"Membership"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"required":true,"type":"string","pattern":"^groups/[^/]+/memberships/[^/]+$","location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nMembership to be retrieved.\n\nFormat: `groups/{group_id}/memberships/{member_id}`, where `group_id` is\nthe unique id assigned to the Group to which Membership belongs to, and\n`member_id` is the unique ID assigned to the member."}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups/{groupsId}/memberships/{membershipsId}","path":"v1/{+name}","id":"cloudidentity.groups.memberships.get"},"list":{"httpMethod":"GET","parameterOrder":["parent"],"response":{"$ref":"ListMembershipsResponse"},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"parameters":{"pageToken":{"description":"The next_page_token value returned from a previous list request, if any.","type":"string","location":"query"},"pageSize":{"location":"query","description":"The default page size is 200 (max 1000) for the BASIC view, and 50\n(max 500) for the FULL view.","format":"int32","type":"integer"},"view":{"location":"query","enum":["VIEW_UNSPECIFIED","BASIC","FULL"],"description":"Membership resource view to be returned. Defaults to View.BASIC.","type":"string"},"parent":{"description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup to list Memberships within.\n\nFormat: `groups/{group_id}`, where `group_id` is the unique ID assigned to\nthe Group.","required":true,"type":"string","pattern":"^groups/[^/]+$","location":"path"}},"flatPath":"v1/groups/{groupsId}/memberships","id":"cloudidentity.groups.memberships.list","path":"v1/{+parent}/memberships","description":"List Memberships within a Group."},"create":{"id":"cloudidentity.groups.memberships.create","path":"v1/{+parent}/memberships","description":"Creates a Membership.","request":{"$ref":"Membership"},"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"Operation"},"parameters":{"parent":{"location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup to create Membership within. Format: `groups/{group_id}`, where\n`group_id` is the unique ID assigned to the Group.","required":true,"type":"string","pattern":"^groups/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups"],"flatPath":"v1/groups/{groupsId}/memberships"},"lookup":{"response":{"$ref":"LookupMembershipNameResponse"},"parameterOrder":["parent"],"httpMethod":"GET","parameters":{"memberKey.id":{"type":"string","location":"query","description":"The ID of the entity within the given namespace. The ID must be unique\nwithin its namespace."},"memberKey.namespace":{"location":"query","description":"Namespaces provide isolation for IDs, so an ID only needs to be unique\nwithin its namespace.\n\nNamespaces are currently only created as part of IdentitySource creation\nfrom Admin Console. A namespace `\"identitysources/{identity_source_id}\"` is\ncreated corresponding to every Identity Source `identity_source_id`.","type":"string"},"parent":{"pattern":"^groups/[^/]+$","location":"path","description":"[Resource name](https://cloud.google.com/apis/design/resource_names) of the\nGroup to lookup Membership within.\n\nFormat: `groups/{group_id}`, where `group_id` is the unique ID assigned to\nthe Group.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-identity.groups","https://www.googleapis.com/auth/cloud-identity.groups.readonly"],"flatPath":"v1/groups/{groupsId}/memberships:lookup","path":"v1/{+parent}/memberships:lookup","id":"cloudidentity.groups.memberships.lookup","description":"Looks up [resource\nname](https://cloud.google.com/apis/design/resource_names) of a Membership\nwithin a Group by member's EntityKey."}}}}}},"parameters":{"alt":{"default":"json","enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response."},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string"},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"description":"Returns response with indentations and line breaks.","type":"boolean","default":"true","location":"query"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"},"callback":{"location":"query","description":"JSONP","type":"string"},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"$.xgafv":{"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"]}},"version":"v1","baseUrl":"https://cloudidentity.googleapis.com/","kind":"discovery#restDescription","description":"API for provisioning and managing identity resources.","servicePath":"","basePath":"","revision":"20190625","documentationLink":"https://cloud.google.com/identity/","id":"cloudidentity:v1","discoveryVersion":"v1","version_module":true};